﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;


namespace NeAdmin.Body.MngPages.NBUtilAdmin
{
	/// <summary>
	///		DBBackup에 대한 요약 설명입니다.
	/// </summary>
	public class DBBackup : UserControl
	{
		protected Literal ltr_tbl_cnt;
		protected Literal ltr_index_size;
		protected Literal ltr_total_size;
		protected Literal ltr_database_name;
		protected Literal ltr_data;
		protected TextBox txt_backup_file;
		protected DataGrid dBackupList;
		protected CheckBox chk_bkname_addtime;
		protected ImageButton ibtn_backup_start;
		BoardMng.BoardMng objParentPage;

		private void Page_Load(object sender, EventArgs e)
		{
			objParentPage = (BoardMng.BoardMng)this.Parent.Page;

			NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "DB 백업", false);

			DBStateLoad();

			BackupListLoad();

			Panel pnlError = (Panel)objParentPage.FindControl ("pnl_auth_deny");
			NBAdminUtil.DisplayAdminAuth ("", NBLib.MngAuthRole.DBBackUp, ibtn_backup_start, pnlError);
		}

		// 페이지의 버튼 이벤트를 정의 한다.
		private void DoPageEventSet()
		{
			this.dBackupList.DeleteCommand += new DataGridCommandEventHandler(this.dBackupList_DeleteCommand);
			this.dBackupList.ItemDataBound += new DataGridItemEventHandler(this.dBackupList_ItemDataBound);
			this.ibtn_backup_start.Click += new ImageClickEventHandler(this.ibtn_backup_start_Click);
		}

		private void BackupListLoad()
		{
			SqlConnection dbSqlConn = null;
		
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet dsDBBackupList = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.DBBackupList());

				if (dsDBBackupList != null)
				{
					DataRow[] BackupListRow = dsDBBackupList.Tables[0].Select("description like '%backup%'", "device_name asc");

                    DataTable dtBackupList = new DataTable("BackupList");

					dtBackupList.Columns.Add("device_name", typeof(string));
					dtBackupList.Columns.Add("physical_name", typeof(string));

					DataRow drRows;
					
					foreach (DataRow drItem in BackupListRow)
					{
                        drRows = dtBackupList.NewRow();
                        
						drRows["device_name"] = drItem["device_name"].ToString();
						drRows["physical_name"] = drItem["physical_name"].ToString();

						dtBackupList.Rows.Add(drRows);
					}

					dBackupList.DataSource = dtBackupList;
					dBackupList.DataBind();
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		private void dBackupList_ItemDataBound(object sender, DataGridItemEventArgs e)
		{
			foreach (TableCell oCell in e.Item.Cells)
			{
				foreach (Control oCont in oCell.Controls)
				{
					if (oCont is Button)
					{
						Button oBtn = (Button)oCont;

						oBtn.CssClass = "GridButton";
					}
				}
			}
		}

		private void dBackupList_DeleteCommand(object source, DataGridCommandEventArgs e)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				string sSelDeviceName = e.Item.Cells[0].Text.Trim();

				if (sSelDeviceName.Trim().Length > 0)
				{
					SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, AdminQryLib.DBBackupDelete(sSelDeviceName));

                    BackupListLoad();

					DoInputInit();
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		private void DBStateLoad()
		{
			SqlConnection dbSqlConn = null;
		
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet dsDBBackupState = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.DBBackupState());

				if (dsDBBackupState != null)
				{
					DataTable dtBK1 = dsDBBackupState.Tables[0];
					DataTable dtBK2 = dsDBBackupState.Tables[1];
					DataTable dtTblCnt = dsDBBackupState.Tables[2];

					string sDatabaseName = dtBK1.Rows[0][0].ToString();
					int nTblCnt = int.Parse(dtTblCnt.Rows[0][0].ToString());
					long nDataSize = long.Parse(dtBK2.Rows[0][1].ToString().Split(' ')[0]); // KB
					long nIndexSize = long.Parse(dtBK2.Rows[0][2].ToString().Split(' ')[0]); // KB
					long nTotalSize = nDataSize + nIndexSize;

                    ltr_database_name.Text = sDatabaseName;
					ltr_tbl_cnt.Text = nTblCnt.ToString("#,##0");
					ltr_data.Text = nDataSize.ToString("#,##0");
					ltr_index_size.Text = nIndexSize.ToString("#,##0");
					ltr_total_size.Text = nTotalSize.ToString("#,##0");
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			DoPageEventSet();
			
			this.Load += new EventHandler(this.Page_Load);

		}
		#endregion

		private string DeviceNameAddTime(string sSrcValue, string sDeviceName)
		{
			string sDevicePath = string.Empty;

			if (sSrcValue != null && sSrcValue.Trim().Length > 0 && sDeviceName != null && sDeviceName.Trim().Length > 0)
			{
				if (sSrcValue.LastIndexOf("\\") > 0 && sSrcValue.LastIndexOf(".") > 0)
				{
					string sPrePath = sSrcValue.Substring(0, sSrcValue.LastIndexOf("\\"));
					string sExt = sSrcValue.Substring(sSrcValue.LastIndexOf("."), sSrcValue.Length - sSrcValue.LastIndexOf("."));

					sDevicePath = sPrePath + "\\"+ sDeviceName + sExt;
				}
			}

			return sDevicePath;           
		}

		private string GetDeviceName(string sSrcValue, bool bTimeAddChk)
		{
			string sDeviceName = string.Empty;

			if (sSrcValue != null && sSrcValue.Trim().Length > 0)
			{
				string[] arrSrcValue = sSrcValue.Split('\\');

				if (arrSrcValue.Length > 0)
				{
					string sDeviceNameAddExt = arrSrcValue[arrSrcValue.Length - 1];

					if (sDeviceNameAddExt.Trim().Length > 0)
					{
						sDeviceName = sDeviceNameAddExt.Substring(0, sDeviceNameAddExt.LastIndexOf("."));

						if (sDeviceName.Trim().Length > 0)
						{
							if (bTimeAddChk)
							{
								sDeviceName += DateTime.Now.ToString("yyyyMMddHHmmss");
							}
						}
					}
				}
			}

			return sDeviceName;
		}

		private void DoInputInit()
		{
			txt_backup_file.Text = string.Empty;
			chk_bkname_addtime.Checked = false;
		}

		private void ibtn_backup_start_Click(object sender, ImageClickEventArgs e)
		{
			if (txt_backup_file.Text.Trim().Length > 0)
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					string sTxtBKFile = txt_backup_file.Text.Trim();

					string sDeviceName = GetDeviceName(sTxtBKFile, chk_bkname_addtime.Checked);

					string sDevicePath = DeviceNameAddTime(sTxtBKFile, sDeviceName);

					if (sDeviceName.Trim().Length > 0 && sDevicePath.Trim().Length > 0)
					{
						SqlHelper.ExecuteNonQuery(
							dbSqlConn, CommandType.Text, AdminQryLib.DBBackupMake(BoardLib.NBUtil.GetDBName(), sDeviceName, sDevicePath));
					}

					BackupListLoad();

					DoInputInit();
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg(Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}                                
			}		
		}
	}
}
