﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;


namespace NeAdmin.Body.MngPages.NBUtilAdmin
{
	/// <summary>
	///		FileArrange에 대한 요약 설명입니다.
	/// </summary>
	public class FileArrange : UserControl
	{
		protected Literal ltr_fileup_root_path;
		protected Literal ltr_total_size;

		BoardMng.BoardMng objParentPage;
		protected ImageButton imgbtn_arrange_start;
		protected Literal ltr_dbclear_result;
		protected Literal ltr_folderclear_result;
		protected PlaceHolder PlaceHolder1;

		protected long nFileSize = 0;

		private void Page_Load(object sender, EventArgs e)
		{
			objParentPage = (BoardMng.BoardMng)this.Parent.Page;

			NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "첨부 파일 정리", false);

			GetUploadStateLoad();

			Panel pnlError = (Panel)objParentPage.FindControl ("pnl_auth_deny");
			NBAdminUtil.DisplayAdminAuth ("", NBLib.MngAuthRole.AttachArrang, imgbtn_arrange_start, pnlError);
		}

		// 페이지의 버튼 이벤트를 정의 한다.
		private void DoPageEventSet()
		{
			this.imgbtn_arrange_start.Click += new ImageClickEventHandler(this.imgbtn_arrange_start_Click);
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.imgbtn_arrange_start.Click += new System.Web.UI.ImageClickEventHandler(this.imgbtn_arrange_start_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void GetUploadStateLoad()
		{
			string sUploadRootPath = BoardLib.NBUtil.GetUploadRootPath();
            ltr_fileup_root_path.Text = sUploadRootPath;

			DirectoryInfo dirFileUp = new DirectoryInfo(sUploadRootPath);

			if (dirFileUp != null)
			{
				nFileSize = 0;

                GetFolderSize(dirFileUp.GetDirectories());

				if (nFileSize > 0)
				{
					double nTotalSize = (nFileSize / 1024.0) / 1024.0;
					ltr_total_size.Text = Math.Round(nTotalSize, 2).ToString("#,###.##") + " MB";
				}
				else
				{
					ltr_total_size.Text = "0 MB";
				}
			}
		}

		private void GetFolderSize(DirectoryInfo[] dirSrc)
		{
			foreach (DirectoryInfo dirItem in  dirSrc)
			{
				foreach(FileInfo fileItem in dirItem.GetFiles())
				{
                    nFileSize += fileItem.Length;
				}

				if (dirItem.GetDirectories().Length > 0)
				{
                    GetFolderSize(dirItem.GetDirectories());
				}
			}
		}

		private void imgbtn_arrange_start_Click(object sender, ImageClickEventArgs e)
		{
			// 첨부 파일 정리

			SqlConnection dbSqlConn = null;
		
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet dsBoardTblList = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.GetFileTableList());

				DataTable dtBoardTblList = dsBoardTblList.Tables[0];

				dbSqlConn.Close();

				int nDBClearCnt = 0;
				int nFileClearCnt = 0;

				
				// 게시판의 수 만큼 루프를 돈다.
				foreach (DataRow drBoardTblList in dtBoardTblList.Rows)
				{
					int nQryResult = 0;

					string sBoardName = drBoardTblList["name"].ToString();
					string sFileDirName = sBoardName.Replace("_FileData_", "_BoardData_");

					DataSet dsBoardFileList = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.GetBoardFiles(sBoardName));

					DataTable dtBoardFileList = dsBoardFileList.Tables[0];

					dbSqlConn.Close();


					string[] arrFiles = Directory.GetFiles(BoardLib.NBUtil.GetUploadRootPath() + "\\" + sFileDirName);
					
					// DB에서 잘못된 링크 제거
					foreach (DataRow drBoardFileList in dtBoardFileList.Rows)
					{
						bool bFileExist = false;
						string sIdxNo = drBoardFileList["idx_no"].ToString();
						string sFIdxNo = drBoardFileList["fidx_no"].ToString();
					
						foreach (string sFile in arrFiles)
						{
							if (drBoardFileList["fname"].ToString().ToUpper().Trim().Equals(Path.GetFileName(sFile).ToUpper()))
							{
								bFileExist = true;
								break;
							}
						}

						if (!bFileExist)
						{
							nQryResult =SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, AdminQryLib.DoBoardFileClear(sBoardName, sIdxNo, sFIdxNo));

							if (nQryResult > 0)
								nDBClearCnt++;
						}
					}

					
					// 폴더에서 잘못된 파일 제거
					foreach (string sFile in arrFiles)
					{
						bool bFileExist2 = false;

						foreach (DataRow drBoardFileList in dtBoardFileList.Rows)
						{
							if (Path.GetFileName(sFile).ToUpper().Equals(drBoardFileList["fname"].ToString().ToUpper().Trim()))
							{
								bFileExist2 = true;
								break;								
							}
						}

						if (!bFileExist2)
						{
							File.Delete(NBUtil.GetUploadRootPath() + "\\" + sFileDirName + "\\" + Path.GetFileName(sFile));

							if (nQryResult > 0)
								nFileClearCnt++;
						}
					}
				}

				// 정리가 끝나면 결과를 보여 준다.
				ltr_dbclear_result.Text = nDBClearCnt.ToString();
				ltr_folderclear_result.Text = nFileClearCnt.ToString();

				NBCmnUtil.ViewAlertMsg(Page, "첨부 파일 정리가 완료되었습니다.");
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}		
		}
	}
}
