﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;


namespace NeAdmin.Body.MngPages.CommonPage
{
	public class TotalState : UserControl
	{
		protected DataGrid dBoardState;
		protected Literal ltr_db_use_size;
		protected Literal ltr_file_use_size;
		protected Literal ltr_guest_join_cnt;
		protected Literal ltr_file_up_path;
		
		protected long nFileSize = 0;

		BoardMng.BoardMng objParentPage;

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				// 타이틀 설정
				objParentPage = (BoardMng.BoardMng)this.Parent.Page;
				NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "전체 게시판 사용 현황", false);

				// DB 사용 상태
				DBStateLoad();

				// 파일 업로드 상태
				GetUploadStateLoad();

				// 회원 가입 상태
				MemStateLoad();
			
				// 현재 등록된 게시판 표시
				BoardStateLoad();
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}
        
		private void DBStateLoad()
		{
			DataSet dsDBBackupState = DBUtil.RunDBToDataSet (CommandType.Text, AdminQryLib.DBBackupState());

			if (dsDBBackupState != null)
			{
				DataTable dtBK2 = dsDBBackupState.Tables[1];

				if (dtBK2 != null)
				{
					long nDataSize = long.Parse(dtBK2.Rows[0][1].ToString().Split(' ')[0]); // KB
					long nIndexSize = long.Parse(dtBK2.Rows[0][2].ToString().Split(' ')[0]); // KB
					long nTotalSize = nDataSize + nIndexSize;

					ltr_db_use_size.Text = nTotalSize.ToString("#,##0 KB");
				}
			}
		}

		private void BoardStateLoad()
		{
			DataSet dsBoardList = DBUtil.RunDBToDataSet (CommandType.Text, AdminQryLib.GetBoardListAtBoardCfg());

			DataTable dtBoardList = dsBoardList.Tables[0];


			DataTable dtBoardState = new DataTable();

			dtBoardState.Columns.Add("board_no", typeof(string));
			dtBoardState.Columns.Add("group_name", typeof(string));
			dtBoardState.Columns.Add("board_name", typeof(string));
			dtBoardState.Columns.Add("write_cnt", typeof(string));
			dtBoardState.Columns.Add("visit_cnt", typeof(string));

			DataRow drBoardState;

			foreach(DataRow drBoardListItem in dtBoardList.Rows)
			{
				drBoardState = dtBoardState.NewRow();

				drBoardState["board_no"] = drBoardListItem["board_no"].ToString();

				drBoardState["group_name"] = drBoardListItem["group_name"].ToString();
	            
				string sBoardLink = "<a href=";
				sBoardLink += "'" + NBUtil.GetBoardTransLink (drBoardListItem["board_no"].ToString(), "LIST") + "' ";
				sBoardLink += "target='_blank' class='link001' title='게시판 보기 Click!!!'>";
				sBoardLink += drBoardListItem["board_name"].ToString();
				sBoardLink += "</a>";

				drBoardState["board_name"] = sBoardLink;

				DataSet dsBoardWriteCnt = DBUtil.RunDBToDataSet (CommandType.Text, AdminQryLib.BoardVisitState(drBoardListItem["board_no"].ToString()));

				drBoardState["write_cnt"] = dsBoardWriteCnt.Tables[0].Rows[0][0].ToString() + " / " + dsBoardWriteCnt.Tables[1].Rows[0][0].ToString();

				drBoardState["visit_cnt"] = dsBoardWriteCnt.Tables[2].Rows[0][0].ToString() + " / " + dsBoardWriteCnt.Tables[3].Rows[0][0].ToString();;

				dtBoardState.Rows.Add(drBoardState);
			}

			dBoardState.DataSource = dtBoardState;
			dBoardState.DataBind();
		}

		private void MemStateLoad()
		{
			DataSet dsMemJoinState = DBUtil.RunDBToDataSet (CommandType.Text, AdminQryLib.MemberJoinState());

			if (dsMemJoinState != null)
			{
				DataTable dtTodayMem = dsMemJoinState.Tables[0];
				DataTable dtTotalMem = dsMemJoinState.Tables[1];

				ltr_guest_join_cnt.Text = dtTodayMem.Rows[0][0].ToString() + " / " + dtTotalMem.Rows[0][0].ToString();
			}
		}

		private void GetUploadStateLoad()
		{
			string sUploadRootPath = BoardLib.NBUtil.GetUploadRootPath();

			DirectoryInfo dirFileUp = new DirectoryInfo(sUploadRootPath);

			if (dirFileUp != null)
			{
				nFileSize = 0;

				GetFolderSize(dirFileUp.GetDirectories());

				if (nFileSize > 0)
				{
					double nTotalSize = (nFileSize / 1024.0) / 1024.0;
					ltr_file_use_size.Text = Math.Round(nTotalSize, 2).ToString("#,##0.##") + " MB";
				}
				else
				{
					ltr_file_use_size.Text = "0 MB";
				}

				ltr_file_up_path.Text = " (" + sUploadRootPath + ")";
			}
		}

		private void GetFolderSize(DirectoryInfo[] dirSrc)
		{
			foreach (DirectoryInfo dirItem in  dirSrc)
			{
				foreach(FileInfo fileItem in dirItem.GetFiles())
				{
					nFileSize += fileItem.Length;
				}

				if (dirItem.GetDirectories().Length > 0)
				{
					GetFolderSize(dirItem.GetDirectories());
				}
			}
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.Load += new EventHandler(this.Page_Load);

		}
		#endregion
	}
}
