﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Xml;
using BoardLib;


namespace NeAdmin.Body.MngPages.GroupPage
{
	/// <summary>
	///		BoardCreate에 대한 요약 설명입니다.
	/// </summary>
	public class BoardCreate : UserControl
	{
		#region Controls
		protected TextBox txt_board_name;
		protected RadioButtonList rdo_init_cfg;
		protected DropDownList ddl_board_list;
		protected DropDownList ddl_cfg_xml;
		protected ImageButton imgbtn_create;
		
		string sGroupCode = string.Empty;

		BoardMng.BoardMng objParentPage;
		#endregion

		private void Page_Load(object sender, EventArgs e)
		{
			sGroupCode = NBCmnUtil.QStrLoad("gno");

			objParentPage = (BoardMng.BoardMng)this.Parent.Page;

			NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "그룹 관리 : <font color='#FFC0C0'>" + NBAdminUtil.GetGroupName(sGroupCode) + "</font> 게시판 생성", false);

			InitSetting();

			Panel pnlError = (Panel)objParentPage.FindControl ("pnl_auth_deny");
			NBAdminUtil.DisplayAdminAuth (sGroupCode, NBLib.MngAuthRole.BoardCreate, imgbtn_create, pnlError);
		}
		
		// 페이지의 버튼 이벤트를 정의 한다.
		private void DoPageEventSet()
		{
			this.rdo_init_cfg.SelectedIndexChanged += new EventHandler(this.rdo_init_cfg_SelectedIndexChanged);
			this.imgbtn_create.Click += new ImageClickEventHandler(this.imgbtn_create_Click);
		}

		private void InitSetting()
		{
			rdo_init_cfg.Items.Remove(new ListItem("다른 게시판 설정 적용", "1"));
			rdo_init_cfg.Items.Remove(new ListItem("설정 XML 파일", "2"));

			// 기본 설정 세팅
			CfgMethod_CtrlChk();
		}

		private void CfgMethod_CtrlChk()
		{
			// All Control Disable
			ddl_board_list.Enabled = false;
			ddl_board_list.Visible = false;
			ddl_cfg_xml.Enabled = false;
			ddl_cfg_xml.Visible = false;			

			switch(rdo_init_cfg.SelectedValue)
			{
				case "1":
					ddl_board_list.Enabled = true;
					ddl_board_list.Visible = true;
					break;
				case "2":
					ddl_cfg_xml.Enabled = true;
					ddl_cfg_xml.Visible = true;
					break;
				default:
					break;
			}
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.imgbtn_create.Click += new System.Web.UI.ImageClickEventHandler(this.imgbtn_create_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void rdo_init_cfg_SelectedIndexChanged(object sender, EventArgs e)
		{
            CfgMethod_CtrlChk();		
		}

		private bool InputValidChk()
		{
			if (NBUtil.StrEmptyChk (sGroupCode))
			{
				NBCmnUtil.ViewMsgGoBack (Page, "그룹을 선택해 주세요.");
				return false;
			}

			if (txt_board_name.Text.Trim().Length == 0)
			{
				NBCmnUtil.ViewMsgGoBack (Page, "게시판 이름을 입력해 주세요.");
				return false;
			}

			return true;
		}

		private void DoCreateBoardDataFolder(string sBoardNo)
		{
			string sPath = BoardLib.NBUtil.GetUploadRootPath() + "\\NB_BoardData_" + sBoardNo;
			
			if (Directory.Exists (sPath))
				Directory.Delete (sPath, true);

			Directory.CreateDirectory(sPath);
		}

		private bool DefaultSettingCreate(SqlConnection dbSqlConn, string sBoardNo, string sBoardName)
		{
			bool bResult = false;

			if (sBoardNo.Trim().Length > 0 && sBoardName.Trim().Length > 0)
			{
				XmlDocument xmlDoc = new XmlDocument();
				XmlNodeList xmlNodeList;


				// /////////////////////////////////////
				// 게시판 관련 테이블 생성 부분
				xmlDoc.Load(Server.MapPath("../../CfgXml/TableCreate.xml"));

				xmlNodeList = xmlDoc.GetElementsByTagName("Script");

				if (xmlNodeList.Count > 0)
				{
					foreach (XmlNode xNode in  xmlNodeList)
					{
                        string sTblCreateQry = xNode.InnerText;

						if (sTblCreateQry.Length > 0)
						{
                            sTblCreateQry = Server.HtmlDecode(ReplaceString(sTblCreateQry, sBoardNo, sBoardName));

							SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sTblCreateQry);                            
						}
					}
				}
				
				
				xmlDoc.Load(Server.MapPath("../../CfgXml/BoardDefaultData.xml"));

				xmlNodeList = xmlDoc.GetElementsByTagName("DefaultData");

				if (xmlNodeList.Count > 0)
				{
					string sTblDefaulteQry = xmlNodeList[0].InnerText;

					if (sTblDefaulteQry.Length > 0)
					{
						sTblDefaulteQry = ReplaceString(sTblDefaulteQry, sBoardNo, sBoardName);

						SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sTblDefaulteQry);                            
					}
				}
                
				
				bResult = true;
			}

			return bResult;
		}

		private string ReplaceString(string sOriginStr, string sBoardNo, string sBoardName)
		{
			// #BoardNo#, #BoardName#
			
			string sResult = sOriginStr.Replace("#BoardNo#", sBoardNo);
			sResult = sResult.Replace("#BoardName#", sBoardName);

			return sResult;

		}

		private void imgbtn_create_Click(object sender, ImageClickEventArgs e)
		{
			if (NBAdminUtil.ChkAdminAuth(sGroupCode, NBLib.MngAuthRole.BoardCreate))
			{
				if (InputValidChk())
				{
					string sNewBoardNo = "";
					string sBoardName = txt_board_name.Text.Trim();

					SqlConnection dbSqlConn = null;

					try
					{
						DBUtil.DBConnection(ref dbSqlConn);

						sNewBoardNo = SqlHelper.ExecuteScalar(dbSqlConn, CommandType.Text, AdminQryLib.NewBoardNo(sGroupCode)).ToString();

						dbSqlConn.Close();

						if (sNewBoardNo.Trim().Length > 0 && sBoardName.Trim().Length > 0)
						{
							sNewBoardNo = sNewBoardNo.PadLeft(6, '0');

							switch(rdo_init_cfg.SelectedValue)
							{
								case "0":
									// 기본 설정
									DefaultSettingCreate(dbSqlConn, sNewBoardNo, sBoardName);

									break;
								case "1":
									// 다른 게시판의설정 사용
									break;
								case "2":
									// 환경 설정 XML 파일
									break;
								default:
									break;
							}

							DoCreateBoardDataFolder(sNewBoardNo);

							objParentPage.DisplayBoardMenu();

							
							string sRedirectUrl = "../BoardMng/BoardMng.aspx";

							if (Request.QueryString["vm"] != null)
							{
								sRedirectUrl += "?vm=s";
							}

							Response.Redirect (sRedirectUrl, false);
						}
					}
					catch(Exception E)
					{
						NBCmnUtil.ViewAlertMsg (Page, E.Message);
					}
					finally
					{
						DBUtil.DBConnDispose(ref dbSqlConn);
					}				
				}
			}
			else
			{
				NBCmnUtil.ViewAlertMsg (Page, "권한이 없습니다.");
			}

		}
	}
}
