﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;


namespace NeAdmin.Body.MngPages.GroupPage
{
	/// <summary>
	///		GroupBoardState에 대한 요약 설명입니다.
	/// </summary>
	public class GroupBoardState : UserControl
	{

		protected DataGrid dBoardState;
		protected Literal ltr_db_use_size;
		protected Literal ltr_file_use_size;
		protected Literal ltr_guest_join_cnt;
		
		protected long nFileSize = 0;

		BoardMng.BoardMng objParentPage;

		protected string gGroupNo = string.Empty;

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				NBAdminUtil.GetReqStr(ref gGroupNo);

				objParentPage = (BoardMng.BoardMng)this.Parent.Page;

				NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "그룹 관리 : <font color='#FFC0C0'>" + NBAdminUtil.GetGroupName(gGroupNo) + "</font> 그룹 사용 현황", false);

				DBStateLoad();

				GetUploadStateLoad();

				MemStateLoad();

				BoardStateLoad();
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{

			}
		}

		

		private void BoardStateLoad()
		{
			SqlConnection dbSqlConn = null;
		
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				
				DataSet dsBoardList = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.GetGroupBoardListAtBoardCfg(gGroupNo));

				DataTable dtBoardList = dsBoardList.Tables[0];

				dbSqlConn.Close();


				DataTable dtBoardState = new DataTable();

				dtBoardState.Columns.Add("board_no", typeof(string));
				dtBoardState.Columns.Add("group_name", typeof(string));
				dtBoardState.Columns.Add("board_name", typeof(string));
				dtBoardState.Columns.Add("write_cnt", typeof(string));
				dtBoardState.Columns.Add("visit_cnt", typeof(string));
				dtBoardState.Columns.Add("over_cnt", typeof(string));

				DataRow drBoardState;

				foreach(DataRow drBoardListItem in dtBoardList.Rows)
				{
					drBoardState = dtBoardState.NewRow();

					drBoardState["board_no"] = drBoardListItem["board_no"].ToString();

					drBoardState["group_name"] = drBoardListItem["group_name"].ToString();
                    
					string sBoardLink = "<a href=";
					sBoardLink += "'" + NBUtil.GetBoardTransLink(drBoardListItem["board_no"].ToString(), "LIST") + "' ";
					sBoardLink += "target='_blank' class='link001' title='게시판 보기'>";
					sBoardLink += drBoardListItem["board_name"].ToString();
					sBoardLink += "</a>";

					drBoardState["board_name"] = sBoardLink;

					DataSet dsBoardWriteCnt = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.BoardVisitState(drBoardListItem["board_no"].ToString()));

					dbSqlConn.Close();

					drBoardState["write_cnt"] = dsBoardWriteCnt.Tables[0].Rows[0][0].ToString() + " / " + dsBoardWriteCnt.Tables[1].Rows[0][0].ToString();

					drBoardState["visit_cnt"] = dsBoardWriteCnt.Tables[2].Rows[0][0].ToString() + " / " + dsBoardWriteCnt.Tables[3].Rows[0][0].ToString();

					drBoardState["over_cnt"] = dsBoardWriteCnt.Tables[4].Rows[0][0].ToString();

					dtBoardState.Rows.Add(drBoardState);
				}

				dBoardState.DataSource = dtBoardState;
				dBoardState.DataBind();
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		private void DBStateLoad()
		{
			SqlConnection dbSqlConn = null;
		
			try
			{
				long nDataSize = 0;
				long nIndexSize = 0;
				long nTotalSize = 0;

				
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet dsRefTableNames = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.Text, AdminQryLib.GroupBoardRefTableName(gGroupNo));

				if (dsRefTableNames != null)
				{
					DataTable dtRefTableNames = dsRefTableNames.Tables[0];

					foreach (DataRow drRefTableNames in dtRefTableNames.Rows)
					{
						DataSet dsBoardDataState = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.DBObjectSpaceUsed(drRefTableNames["name"].ToString()));

						if (dsBoardDataState != null)
						{
							DataTable dtBK2 = dsBoardDataState.Tables[0];

							nDataSize += long.Parse(dtBK2.Rows[0][1].ToString().Split(' ')[0]); // KB
							nIndexSize += long.Parse(dtBK2.Rows[0][2].ToString().Split(' ')[0]); // KB
					
						}
					}
				}

				
				nTotalSize = nDataSize + nIndexSize;

				ltr_db_use_size.Text = nTotalSize.ToString("#,##0 KB");

			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}


		private void MemStateLoad()
		{
			SqlConnection dbSqlConn = null;
		
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet dsMemJoinState = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.MemberJoinState());

				if (dsMemJoinState != null)
				{
					DataTable dtTodayMem = dsMemJoinState.Tables[0];
					DataTable dtTotalMem = dsMemJoinState.Tables[1];

					ltr_guest_join_cnt.Text = dtTodayMem.Rows[0][0].ToString() + " / " + dtTotalMem.Rows[0][0].ToString();
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		private void GetUploadStateLoad()
		{
			string sUploadRootPath = BoardLib.NBUtil.GetUploadRootPath();

			DirectoryInfo dirFileUp = new DirectoryInfo(sUploadRootPath);

			if (dirFileUp != null)
			{
				nFileSize = 0;

				foreach (DirectoryInfo dirFileUpSub in dirFileUp.GetDirectories("NB_BoardData_" + gGroupNo + "*"))
				{
					GetFolderSize(dirFileUpSub);
				}

				if (nFileSize > 0)
				{
					double nTotalSize = (nFileSize / 1024.0) / 1024.0;
					ltr_file_use_size.Text = Math.Round(nTotalSize, 2).ToString("#,##0.##") + " MB";
				}
				else
				{
					ltr_file_use_size.Text = "0 MB";
				}
			}
		}


		private void GetFolderSize(DirectoryInfo dirSrc)
		{
			foreach(FileInfo fileItem in dirSrc.GetFiles())
			{
				nFileSize += fileItem.Length;
			}
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.Load += new EventHandler(this.Page_Load);

		}
		#endregion
	}
}
