﻿using System;
using System.Collections;
using System.Data;
using System.Data.SqlClient;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Xml;
using BoardLib;


namespace NeAdmin.Body.MngPages.GroupPage
{
	/// <summary>
	///		GroupMng에 대한 요약 설명입니다.
	/// </summary>
	public class GroupMng : UserControl
	{
		protected DataGrid dGroupList;
		protected DropDownList ddl_group_open_edit;
		protected TextBox txt_group_code;
		protected TextBox txt_group_name;
		protected ImageButton ibtn_group_add;
		protected System.Web.UI.WebControls.PlaceHolder plc_GroupAdd;

		BoardMng.BoardMng objParentPage;

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				objParentPage = (BoardMng.BoardMng)this.Parent.Page;

				NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "그룹 관리 : 그룹 추가/수정", false);

				DoGroupDataBind();

				DoAuthSet();
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}

		private void DoAuthSet()
		{
			if ( NBAdminUtil.isSuperAdmin())
				plc_GroupAdd.Visible = true;
			else
                plc_GroupAdd.Visible = false;
		}

		private void GetNewGroupCode()
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				string sNewGroupCode = SqlHelper.ExecuteScalar(dbSqlConn, CommandType.Text, AdminQryLib.NewGroupCode()).ToString();

				if (sNewGroupCode.Length > 0 && int.Parse(sNewGroupCode) < 1000)
				{
					txt_group_code.Text = sNewGroupCode.PadLeft(3, '0');
					ibtn_group_add.Enabled = true;
				}
				else
				{
					ibtn_group_add.Enabled = false;
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		private void DoGroupDataBind()
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet ds = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.GroupList());

				dGroupList.DataSource = ds;
				dGroupList.DataKeyField = "group_code";
				dGroupList.DataBind();

				GetNewGroupCode();
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.ibtn_group_add.Click += new System.Web.UI.ImageClickEventHandler(this.ibtn_group_add_Click);
			this.dGroupList.CancelCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_CancelCommand);
			this.dGroupList.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_EditCommand);
			this.dGroupList.UpdateCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_UpdateCommand);
			this.dGroupList.DeleteCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_DeleteCommand);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void dGroupList_DeleteCommand(object source, DataGridCommandEventArgs e)
		{
			if (NBAdminUtil.ChkAdminAuth(e.Item.Cells[0].Text, NBLib.MngAuthRole.GrpInfoMod))
			{
				SqlConnection dbSqlConn = null;

				try
				{
					if (int.Parse(e.Item.Cells[2].Text) < 1)
					{
						DBUtil.DBConnection(ref dbSqlConn);

						string sSelGroupCode = e.Item.Cells[0].Text.Trim();

						if (sSelGroupCode.Trim().Length > 0)
						{
							SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, AdminQryLib.GroupDelete(sSelGroupCode));

							DoGroupDataBind();

							objParentPage.DisplayBoardMenu();					
						}
					}
					else
					{
						throw new Exception("그룹에 포함된 게시판이 있습니다. 그룹을 삭제하시려면 포함된 게시판을 먼저 삭제 하셔야 합니다.");
					}
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}
			}
			else
			{
				NBCmnUtil.ViewAlertMsg (Page, "권한이 없습니다.");
			}
		}

		

		private bool GroupAddValidChk()
		{
			if (txt_group_code.Text.Trim().Length == 0)
			{				
				NBCmnUtil.ViewAlertMsg (Page, "그룹 코드가 없습니다.");
                return false;
			}

			if (txt_group_name.Text.Trim().Length == 0)
			{	
				NBCmnUtil.ViewAlertMsg (Page, "그룹 이름이 없습니다.");
				return false;
			}

			return true;
		}

		private void dGroupList_EditCommand(object source, DataGridCommandEventArgs e)
		{
			if (NBAdminUtil.ChkAdminAuth(e.Item.Cells[0].Text, NBLib.MngAuthRole.GrpInfoMod))
			{
				dGroupList.EditItemIndex = e.Item.ItemIndex;
				dGroupList.DataBind();
			}
			else
			{
				NBCmnUtil.ViewAlertMsg (Page, "권한이 없습니다.");
			}
		}

		private void dGroupList_CancelCommand(object source, DataGridCommandEventArgs e)
		{
            dGroupList.EditItemIndex = -1;
			dGroupList.DataBind();
		}

		private void dGroupList_UpdateCommand(object source, DataGridCommandEventArgs e)
		{
			if (GroupAddValidChk(e.Item))
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					ArrayList UpdateParam = new ArrayList();

                    TextBox txtGroupName = (TextBox)e.Item.FindControl("txt_group_name_edit");
					UpdateParam.Add(DBUtil.InsertParamItem("group_name", NBLib.FieldQryType.Char, txtGroupName.Text));

					string sUpdateQry = DBUtil.CreateUpdateQry("NB_GroupInfo", UpdateParam, "group_code='" + dGroupList.DataKeys[e.Item.ItemIndex].ToString() + "'");

					if (sUpdateQry.Trim().Length > 0)
					{
						SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sUpdateQry);

						dGroupList.EditItemIndex = -1;
						DoGroupDataBind();
					}
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}
			}		
		}

		private bool GroupAddValidChk(DataGridItem GridItem)
		{
			TextBox objText;

			objText = (TextBox)GridItem.FindControl("txt_group_name_edit");

			if (objText.Text.Trim().Length == 0)
			{
				NBCmnUtil.ViewAlertMsg (Page, "그룹 이름이 없습니다.");
				return false;
			}

			return true;
		}

		private void ibtn_group_add_Click(object sender, ImageClickEventArgs e)
		{
			if (GroupAddValidChk())
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					ArrayList InsertParam = new ArrayList();

					InsertParam.Add(DBUtil.InsertParamItem("group_code", NBLib.FieldQryType.Char, txt_group_code.Text));
					InsertParam.Add(DBUtil.InsertParamItem("group_name", NBLib.FieldQryType.Char, txt_group_name.Text));

					string sInsertQry = DBUtil.CreateInsertQry("NB_GroupInfo", InsertParam);


					if (sInsertQry.Trim().Length > 0)
					{
						int nExecResult = SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sInsertQry);

						if (nExecResult > 0)
						{
							DefaultSettingCreate(dbSqlConn, txt_group_code.Text);

							DoGroupDataBind();

							objParentPage.DisplayBoardMenu();

							string sRedirectUrl = "../BoardMng/BoardMng.aspx?pgc=GroupPage/GroupMng.ascx";

							if (Request.QueryString["vm"] != null)
							{
								sRedirectUrl += "&vm=s";
							}

							Response.Redirect (sRedirectUrl, false);
						}
						else
						{
							throw new Exception ("그룹 생성 중 오류가 있었습니다.");
						}
					}					
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}
			}	
		}

		private bool DefaultSettingCreate(SqlConnection dbSqlConn, string sGroupCode)
		{
			bool bResult = false;

			if (sGroupCode.Trim().Length > 0)
			{
				XmlDocument xmlDoc = new XmlDocument();
				XmlNodeList xmlNodeList;

				xmlDoc.Load(Server.MapPath("../../CfgXml/GroupDefaultData.xml"));

				xmlNodeList = xmlDoc.GetElementsByTagName("DefaultData");

				if (xmlNodeList.Count > 0)
				{
					string sTblDefaulteQry = xmlNodeList[0].InnerText;

					if (sTblDefaulteQry.Length > 0)
					{
						sTblDefaulteQry = ReplaceString(sTblDefaulteQry, sGroupCode);

						SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sTblDefaulteQry);
					}
				}


				
				bResult = true;
			}

			return bResult;
		}

		private string ReplaceString(string sOriginStr, string sGroupCode)
		{
			string sResult = sOriginStr.Replace("#GroupCode#", sGroupCode);

			return sResult;

		}
	}
}
