﻿using System;
using System.Configuration;
using System.Collections;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;

namespace NeAdmin.Body.MngPages.MemberPage
{
	/// <summary>
	///		JoinDesignSet에 대한 요약 설명입니다.
	/// </summary>
	public class JoinDesignSet : UserControl
	{
		#region Page Controls
		protected LinkButton lnk_basic_set;
		protected LinkButton lnk_display_set;
		protected LinkButton lnk_design_set;
		protected LinkButton lnk_level_set;
		protected LinkButton lnk_category_mng;
		protected Literal xltr_header_type;
		protected Literal xltr_copyright_type;
		protected Literal xltr_tail_type;
		protected DropDownList ddl_joinskin_path;
		protected DropDownList ddl_joinheader_type;
		protected TextBox txt_joinheader_cont;
		protected DropDownList ddl_joincopyright_type;
		protected TextBox txt_joincopyright_cont;
		protected DropDownList ddl_jointail_type;
		protected TextBox txt_jointail_cont;
		protected TextBox txt_joinsbar_style;
		protected DropDownList ddl_jointitle_view;
		protected TextBox txt_jointitle_cont;
		protected TextBox txt_joinbg_color;
		protected TextBox txt_joinbg_img;
		protected Literal xltr_title_view;
		protected ImageButton imgbtn_design_save;
		#endregion
		protected System.Web.UI.WebControls.ImageButton imbbtn_design_preview;

		BoardMng.BoardMng objParentPage;

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				objParentPage = (BoardMng.BoardMng)this.Parent.Page;

				NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "게시판 관리 : 회원가입 디자인 변경", false);

				CfgOldDataLoad();

				if (!NBCmnUtil.GetCookieValue ("NEADMIN_MBNO").Equals (NBLib.SuperAdmin))
				{
					Panel pnlError = (Panel)objParentPage.FindControl ("pnl_auth_deny");
					pnlError.Visible = true;
					imgbtn_design_save.Visible = false;
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}

		private void CfgOldDataLoad()
		{
			SqlConnection dbSqlConn = null;
			
			try
			{
				ddl_joinskin_path.Items.Clear();

				// 스킨 폴더에서 스킨 리스트 검색
				ddl_joinskin_path.Items.Add(new ListItem("선택 안됨", ""));

				DirectoryInfo fsSkinDir = new DirectoryInfo(Server.MapPath(ConfigurationSettings.AppSettings["NeBoardPath"] + "/SkinTemplates/JoinSkin/"));

				if (fsSkinDir.GetDirectories().Length > 0)
				{
					foreach (DirectoryInfo dirInfo in fsSkinDir.GetDirectories())
					{
						ddl_joinskin_path.Items.Add(new ListItem(dirInfo.Name, dirInfo.Name));
					}
				}


				DBUtil.DBConnection(ref dbSqlConn);

				// 선택 게시판의 디자인 설정
				DataSet dsBoardCfg = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.GetJoinDesignCfgData());

				if (dsBoardCfg != null)
				{
					DataTable dtBoardCfg = dsBoardCfg.Tables[0];

					if (dtBoardCfg.Rows.Count > 0)
					{
						NBCmnUtil.DataTbl_to_Control(dtBoardCfg.Rows[0], this.Controls);
					}
					else
					{
						// 데이타가 없으면 일단 Insert
						string sQry = "INSERT NB_JoinDesignCfg (jd_idx) VALUES (1)";
						SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sQry);
					}
				}


				// 머리말 / 카피라이트 / 꼬리말 형태에 따라서 TextBox의 TextMode 변경
				SetTextModeChg (ddl_joinheader_type, xltr_header_type, txt_joinheader_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\header.htm)");
				SetTextModeChg (ddl_joincopyright_type, xltr_copyright_type, txt_joincopyright_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\copyright.htm)");
				SetTextModeChg (ddl_jointail_type, xltr_tail_type, txt_jointail_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\tail.htm)");
				SetTextModeChg (ddl_jointitle_view, xltr_title_view, txt_jointitle_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\tail.htm)");
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}		

		private void SetTextModeChg(DropDownList objDdl, Literal ltrHelp, TextBox txtInputBox, string sHelpTxt)
		{
			if (objDdl.SelectedIndex > -1)
			{
				if (objDdl.SelectedValue.CompareTo("3") == 0)
				{
					ltrHelp.Text = sHelpTxt;
					txtInputBox.CssClass = "box";
					txtInputBox.TextMode = TextBoxMode.SingleLine;
				}
				else
				{
					ltrHelp.Text = string.Empty;
					txtInputBox.CssClass = "box_txtarea";
					txtInputBox.TextMode = TextBoxMode.MultiLine;;
				}
			}
		}

		private void imgbtn_design_save_Click(object sender, ImageClickEventArgs e)
		{
			SqlConnection dbSqlConn = null;
		
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				ArrayList UpdateFields = NBCmnUtil.GetUpdateFields(this.Controls);

				if (UpdateFields.Count > 0)
				{
					string Qry = DBUtil.CreateUpdateQry("NB_JoinDesignCfg", UpdateFields, "jd_idx = 1");

					if (Qry.Trim().Length > 0)
					{
						int nUpdate = SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, Qry);

						if (nUpdate > 0)
							NBCmnUtil.ViewAlertMsg (Page, "수정 완료");
					}
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.ddl_jointitle_view.SelectedIndexChanged += new System.EventHandler(this.ddl_jointitle_view_SelectedIndexChanged);
			this.ddl_joinheader_type.SelectedIndexChanged += new System.EventHandler(this.ddl_joinheader_type_SelectedIndexChanged);
			this.ddl_joincopyright_type.SelectedIndexChanged += new System.EventHandler(this.ddl_joincopyright_type_SelectedIndexChanged);
			this.ddl_jointail_type.SelectedIndexChanged += new System.EventHandler(this.ddl_jointail_type_SelectedIndexChanged);
			this.imgbtn_design_save.Click += new System.Web.UI.ImageClickEventHandler(this.imgbtn_design_save_Click);
			this.imbbtn_design_preview.Click += new System.Web.UI.ImageClickEventHandler(this.imbbtn_design_preview_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void ddl_joinheader_type_SelectedIndexChanged(object sender, EventArgs e)
		{
			SetTextModeChg (ddl_joinheader_type, xltr_header_type, txt_joinheader_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\header.htm)");
		}

		private void ddl_joincopyright_type_SelectedIndexChanged(object sender, EventArgs e)
		{
			SetTextModeChg (ddl_joincopyright_type, xltr_copyright_type, txt_joincopyright_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\copyright.htm)");
		}

		private void ddl_jointail_type_SelectedIndexChanged(object sender, EventArgs e)
		{
            SetTextModeChg (ddl_jointail_type, xltr_tail_type, txt_jointail_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\tail.htm)");		
		}

		private void xddl_group_code_SelectedIndexChanged(object sender, EventArgs e)
		{
            CfgOldDataLoad();		
		}

		private void ddl_jointitle_view_SelectedIndexChanged(object sender, EventArgs e)
		{
			SetTextModeChg (ddl_jointitle_view, xltr_title_view, txt_jointitle_cont, "표시할 파일의 절대 경로를 입력해 주세요. (예: c:\\Inetpub\\wwwroot\\neboard\\tail.htm)");
		}

		private string GetLoadFirstBoard()
		{
			string sFirstBoard = string.Empty;

			SqlConnection dbSqlConn = null;
			
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				string sQry = "select top 1 board_no from nb_boardset order by board_no asc";

				object sBoardNo = SqlHelper.ExecuteScalar (dbSqlConn, CommandType.Text, sQry);

				if (sBoardNo != null)
				{
					if (!NBUtil.StrEmptyChk(sBoardNo.ToString()))
					{
						sFirstBoard = sBoardNo.ToString();
					}
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}

			return sFirstBoard;
		}

		private void imbbtn_design_preview_Click(object sender, System.Web.UI.ImageClickEventArgs e)
		{
			SqlConnection dbSqlConn = null;
		
			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				ArrayList UpdateFields = NBCmnUtil.GetUpdateFields(this.Controls);

				if (UpdateFields.Count > 0)
				{
					string Qry = "IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'NB_JoinDesignCfg_PV') AND OBJECTPROPERTY(id, N'IsUserTable') = 1) \r\n";
					Qry += "DROP TABLE NB_JoinDesignCfg_PV \r\n";
					Qry += "SELECT * INTO NB_JoinDesignCfg_PV FROM NB_JoinDesignCfg \r\n";
					Qry += DBUtil.CreateUpdateQry("NB_JoinDesignCfg_PV", UpdateFields, "jd_idx = 1");

					if (Qry.Trim().Length > 0)
					{
						int nUpdate = SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, Qry);

						if (nUpdate > 0)
						{
							string sViewBoardNo = GetLoadFirstBoard();

							if (NBUtil.StrEmptyChk(sViewBoardNo))
							{
								NBCmnUtil.ViewAlertMsg (Page, @"게시판이 1개 이상 생성되어 있어야 합니다.");
							}
							else
							{
								StringWriter swScript = new StringWriter();

								swScript.WriteLine ("<script language=\"javascript\">");
								swScript.WriteLine ("<!--");
								swScript.WriteLine ("	var objPrevWin = window.open ('/NeBoard/BoardPreview.aspx?bno=" + sViewBoardNo + "&mode=JOIN', 'NBPrevWin', 'width=800,height=600,scrollbars=yes');");
								swScript.WriteLine ("	if (objPrevWin == null)");
								swScript.WriteLine ("		alert ('새창 띄우기가 차단되어 있습니다.');");
								swScript.WriteLine ("	else");
								swScript.WriteLine ("		objPrevWin.window.focus();");
								swScript.WriteLine ("//-->");
								swScript.WriteLine ("</script>");

								Page.RegisterStartupScript ("NBPrevWin", swScript.ToString());
							}
						}							
					}
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}
	}
}
