﻿using System;
using System.Collections;
using System.Data;
using System.Data.SqlClient;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;


namespace NeAdmin.Body.MngPages.MemberPage
{
	/// <summary>
	///		MaillingList에 대한 요약 설명입니다.
	/// </summary>
	public class MaillingList : UserControl
	{
		protected DataGrid dGroupList;
		protected TextBox txt_mail_code;
		protected TextBox txt_mail_name;
		protected DropDownList ddl_mail_body_type;
		protected TextBox txt_mail_subject;
		protected TextBox txt_mail_bcc;
		protected TextBox txt_mail_body;
		protected TextBox txt_mail_sender;
		protected HyperLink hyp_get_rplstr;
		protected ImageButton imgbtn_mailling_save;
		protected System.Web.UI.WebControls.HyperLink hyp_pre_view;
		BoardMng.BoardMng objParentPage;

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				objParentPage = (BoardMng.BoardMng)this.Parent.Page;

				NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "회원 관리 : 메일링 리스트", false);

				DoMaillingDataBind();

				hyp_get_rplstr.NavigateUrl = "javascript:OpenRplStrWin('" + txt_mail_body.ClientID + "');";

				GetNewMailCode();

				Panel pnlError = (Panel)objParentPage.FindControl ("pnl_auth_deny");
				NBAdminUtil.DisplayAdminAuth ("", NBLib.MngAuthRole.MaillingMod, imgbtn_mailling_save, pnlError);
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}

		private void GetNewMailCode()
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				string sNewMailCode = SqlHelper.ExecuteScalar(dbSqlConn, CommandType.Text, AdminQryLib.NewMailCode()).ToString();

				if (sNewMailCode.Length > 0 && int.Parse(sNewMailCode) < 1000)
				{
					txt_mail_code.Text = sNewMailCode.PadLeft(3, '0');
					imgbtn_mailling_save.Enabled = true;
				}
				else
				{
					imgbtn_mailling_save.Enabled = false;
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		private void DoMaillingDataBind()
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet ds = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.MaillingListData());

				dGroupList.DataSource = ds;
				dGroupList.DataKeyField = "mail_code";
				dGroupList.DataBind();
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}		
		}

		private void dGroupList_ItemDataBound(object sender, DataGridItemEventArgs e)
		{
			foreach (TableCell oCell in e.Item.Cells)
			{
				foreach (Control oCont in oCell.Controls)
				{
					if (oCont is Button)
					{
						Button oBtn = (Button)oCont;

						oBtn.CssClass = "GridButton";
					}
				}
			}
		}

		private void dGroupList_EditCommand(object source, DataGridCommandEventArgs e)
		{
			if (NBAdminUtil.ChkAdminAuth("", NBLib.MngAuthRole.MaillingMod))
			{
				dGroupList.EditItemIndex = e.Item.ItemIndex;
				dGroupList.DataBind();

				SqlConnection dbSqlConn = null;
			
				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					DataSet dsMaillingData = SqlHelper.ExecuteDataset(dbSqlConn, CommandType.Text, AdminQryLib.MaillingData(e.Item.Cells[0].Text.Trim()));

					if (dsMaillingData != null)
					{
						DataTable dtMaillingData = dsMaillingData.Tables[0];

						if (dtMaillingData.Rows.Count > 0)
						{
							NBCmnUtil.DataTbl_to_Control(dtMaillingData.Rows[0], this.Controls);

							SetEditMode();
						}
					}
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}
			}
			else
			{
                NBCmnUtil.ViewAlertMsg (Page, "권한이 없습니다.");
			}
		}

		private void SetEditMode()
		{
			imgbtn_mailling_save.Enabled = false;
			imgbtn_mailling_save.Visible = false;
		}

		private void SetEditModeEnd()
		{
			InputBoxInit();

			GetNewMailCode();

			imgbtn_mailling_save.Enabled = true;
			imgbtn_mailling_save.Visible = true;
		}

		private void dGroupList_CancelCommand(object source, DataGridCommandEventArgs e)
		{
			dGroupList.EditItemIndex = -1;
			dGroupList.DataBind();

			SetEditModeEnd();
		}

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다. 이 메서드의 내용을
		///		코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.dGroupList.PageIndexChanged += new System.Web.UI.WebControls.DataGridPageChangedEventHandler(this.dGroupList_PageIndexChanged);
			this.dGroupList.CancelCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_CancelCommand);
			this.dGroupList.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_EditCommand);
			this.dGroupList.UpdateCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_UpdateCommand);
			this.dGroupList.DeleteCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.dGroupList_DeleteCommand);
			this.dGroupList.ItemDataBound += new System.Web.UI.WebControls.DataGridItemEventHandler(this.dGroupList_ItemDataBound);
			this.imgbtn_mailling_save.Click += new System.Web.UI.ImageClickEventHandler(this.imgbtn_mailling_save_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void dGroupList_UpdateCommand(object source, DataGridCommandEventArgs e)
		{
			if (MaillingAddValidChk())
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					ArrayList UpdateParam = new ArrayList();

					UpdateParam.Add(DBUtil.InsertParamItem("mail_name", NBLib.FieldQryType.Char, txt_mail_name.Text));
					UpdateParam.Add(DBUtil.InsertParamItem("mail_subject", NBLib.FieldQryType.Char, txt_mail_subject.Text));
					UpdateParam.Add(DBUtil.InsertParamItem("mail_sender", NBLib.FieldQryType.Char, txt_mail_sender.Text));
					UpdateParam.Add(DBUtil.InsertParamItem("mail_bcc", NBLib.FieldQryType.Char, txt_mail_bcc.Text));
					UpdateParam.Add(DBUtil.InsertParamItem("mail_body", NBLib.FieldQryType.Char, txt_mail_body.Text));
					UpdateParam.Add(DBUtil.InsertParamItem("mail_body_type", NBLib.FieldQryType.Char, ddl_mail_body_type.SelectedValue));

					string sUpdateQry = DBUtil.CreateUpdateQry("NB_MaillingData", UpdateParam, "mail_code='" + txt_mail_code.Text.Trim() + "'");

					if (sUpdateQry.Trim().Length > 0)
					{
						SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sUpdateQry);

						dGroupList.EditItemIndex = -1;

						// dGroupList.DataBind();

						DoMaillingDataBind();

						GetNewMailCode();

						InputBoxInit();

						SetEditModeEnd();
					}
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}
			}		
		}

		private bool MaillingAddValidChk()
		{
			if (txt_mail_code.Text.Trim().Length == 0)
			{
				NBCmnUtil.ViewAlertMsg (Page, "메일 코드가 없습니다.");
				return false;
			}

			if (txt_mail_name.Text.Trim().Length == 0)
			{	
				NBCmnUtil.ViewAlertMsg (Page, "메일 이름이 없습니다.");
				return false;
			}

			if (txt_mail_subject.Text.Trim().Length == 0)
			{	
				NBCmnUtil.ViewAlertMsg (Page, "메일 제목이 없습니다.");
				return false;
			}

			if (txt_mail_sender.Text.Trim().Length == 0)
			{				
				NBCmnUtil.ViewAlertMsg (Page, "보내는 사람이 없습니다.");
				return false;
			}

			return true;
		}

		private void dGroupList_DeleteCommand(object source, DataGridCommandEventArgs e)
		{
			if (NBAdminUtil.ChkAdminAuth("", NBLib.MngAuthRole.MaillingMod))
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					string sSelMailCode = e.Item.Cells[0].Text.Trim();

					if (sSelMailCode.Trim().Length > 0)
					{
						int nExecResult = SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, AdminQryLib.MaillingDelete(sSelMailCode));

						if (nExecResult > 0)
						{
							DoMaillingDataBind();

							GetNewMailCode();

							InputBoxInit();
						}
					}
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}
			}
			else
			{
				NBCmnUtil.ViewAlertMsg (Page, "권한이 없습니다.");
			}
		}

		private void InputBoxInit()
		{
			txt_mail_name.Text = string.Empty;
			txt_mail_subject.Text = string.Empty;
			txt_mail_sender.Text = string.Empty;
			txt_mail_bcc.Text=  string.Empty;
			txt_mail_body.Text = string.Empty;
			ddl_mail_body_type.SelectedIndex = -1;
		}

		private void imgbtn_mailling_save_Click(object sender, ImageClickEventArgs e)
		{
			if (MaillingAddValidChk())
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					ArrayList InsertParam = new ArrayList();

					InsertParam.Add(DBUtil.InsertParamItem("mail_code", NBLib.FieldQryType.Char, txt_mail_code.Text));
					InsertParam.Add(DBUtil.InsertParamItem("mail_name", NBLib.FieldQryType.Char, txt_mail_name.Text));
					InsertParam.Add(DBUtil.InsertParamItem("mail_subject", NBLib.FieldQryType.Char, txt_mail_subject.Text));
					InsertParam.Add(DBUtil.InsertParamItem("mail_sender", NBLib.FieldQryType.Char, txt_mail_sender.Text));
					InsertParam.Add(DBUtil.InsertParamItem("mail_bcc", NBLib.FieldQryType.Char, txt_mail_bcc.Text));
					InsertParam.Add(DBUtil.InsertParamItem("mail_body", NBLib.FieldQryType.Char, txt_mail_body.Text));
					InsertParam.Add(DBUtil.InsertParamItem("mail_body_type", NBLib.FieldQryType.Char, ddl_mail_body_type.SelectedValue));

					string sInsertQry = DBUtil.CreateInsertQry("NB_MaillingData", InsertParam);

					if (sInsertQry.Trim().Length > 0)
					{
						SqlHelper.ExecuteNonQuery(dbSqlConn, CommandType.Text, sInsertQry);

						DoMaillingDataBind();

						GetNewMailCode();

						InputBoxInit();
					}
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}
			}
		}

		private void dGroupList_PageIndexChanged(object source, System.Web.UI.WebControls.DataGridPageChangedEventArgs e)
		{
			dGroupList.CurrentPageIndex = e.NewPageIndex;
			dGroupList.DataBind();		
		}
	}
}
