using System;
using System.Data;
using System.Data.SqlClient;
using System.Drawing;
using System.Web;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.IO;
using BoardLib;

namespace NeAdmin.Body.MngPages.Report
{
	public class BoardReport : System.Web.UI.UserControl
	{
		protected System.Web.UI.WebControls.Label lblCurrMonth;
		protected System.Web.UI.WebControls.LinkButton lnkPrevMonth;
		protected System.Web.UI.WebControls.LinkButton lnkNextMonth;
		protected System.Web.UI.HtmlControls.HtmlTable tblMonthView;
		protected System.Web.UI.WebControls.DropDownList ddlBoardList;

		public string pbSelMonth = "";
		protected System.Web.UI.WebControls.Literal ltrTotalCount;
		protected System.Web.UI.WebControls.Literal ltrTodayWrite;
		protected System.Web.UI.WebControls.Literal ltrTodayRead;
		protected System.Web.UI.WebControls.Literal ltrMonthWrite;
		protected System.Web.UI.WebControls.Literal ltrMonthRead;
		
		BoardMng.BoardMng objParentPage;

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				objParentPage = (BoardMng.BoardMng)this.Parent.Page;

				NBAdminUtil.view_pagetitle((Label)objParentPage.FindControl("lbl_page_name"), "Խ ", false);

				if (!IsPostBack)
				{
					DoBoardListBind();

					pbSelMonth = DateTime.Now.ToString ("yyyy.MM");
					lblCurrMonth.Text = pbSelMonth;

					GetBoardReport();
					MonthViewDayRender();
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}

		private void DoBoardListBind()
		{
			string sQry = "select board_no, board_name from nb_boardset order by board_no asc";

			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet dsData = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.Text, sQry);

				if (dsData != null)
				{
					ddlBoardList.DataSource = dsData;
					ddlBoardList.DataTextField = "board_name";
					ddlBoardList.DataValueField = "board_no";
					ddlBoardList.DataBind();
				}

				ddlBoardList.SelectedIndex = 0;
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}

		private void GetBoardReport()
		{
			StringWriter sw = new StringWriter();			

			if (ddlBoardList.SelectedIndex > -1)
			{
				string sBoardNo = ddlBoardList.SelectedValue;

				sw.WriteLine ("declare ");
				sw.WriteLine ("	@total_count int, @today_write_count int, @today_read_count int, ");
				sw.WriteLine ("	@month_write_count int, @month_read_count int	");
				//  Խù 
				sw.WriteLine ("select @total_count = count(*) from nb_boarddata_{0}", sBoardNo);
				//  ۼ 
				sw.WriteLine ("select @today_write_count = count (*) ");
				sw.WriteLine ("from nb_boarddata_{0} ", sBoardNo);
				sw.WriteLine ("where convert (char(10), write_date, 102) = convert (char(10), getdate(), 102)");
				//  ۼ 
				sw.WriteLine ("select @today_read_count = isnull(sum (isnull (hit_cnt, 0)), 0) ");
				sw.WriteLine ("from nb_boarddata_{0} ", sBoardNo);
				sw.WriteLine ("where convert (char(10), write_date, 102) = convert (char(10), getdate(), 102)");
				//  
				sw.WriteLine ("select @month_write_count = count (*) ");
				sw.WriteLine ("from nb_boarddata_{0} ", sBoardNo);
				sw.WriteLine ("where convert (char(7), write_date, 102) = '{0}'", pbSelMonth);
				//  
				sw.WriteLine ("select @month_read_count = isnull(sum (isnull (hit_cnt, 0)), 0) ");
				sw.WriteLine ("from nb_boarddata_{0} ", sBoardNo);
				sw.WriteLine ("where convert (char(7), write_date, 102) = '{0}'", pbSelMonth);
			
				sw.WriteLine ("select ");
				sw.WriteLine ("	@total_count as total_count, @today_write_count as today_write_count, @today_read_count as today_read_count, ");
				sw.WriteLine ("	@month_write_count as month_write_count, @month_read_count as month_read_count");
            
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection(ref dbSqlConn);

					SqlDataReader drData = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sw.ToString());

					if (drData.Read())
					{
						ltrTotalCount.Text = long.Parse (drData["total_count"].ToString()).ToString ("#,0");
						ltrTodayWrite.Text = long.Parse (drData["today_write_count"].ToString()).ToString ("#,0");
						ltrTodayRead.Text = long.Parse (drData["today_read_count"].ToString()).ToString ("#,0");
						ltrMonthWrite.Text = long.Parse (drData["month_write_count"].ToString()).ToString ("#,0");
						ltrMonthRead.Text = long.Parse (drData["month_read_count"].ToString()).ToString ("#,0");
					}
				}
				catch(Exception E)
				{
					NBCmnUtil.ViewAlertMsg (Page, E.Message);
				}
				finally
				{
					DBUtil.DBConnDispose(ref dbSqlConn);
				}	
			}
		}

		private double GetPercent(double nTotal, double nVal)
		{
			if (nVal != 0.0)
			{
				double nTmpVal = (nVal / nTotal) * 100.0;
				double nResult = Math.Round (nTmpVal, 1);

				if (nResult == 0.0)
				{
					nResult = 1.0;
				}

				return nResult;
			}
			else
			{
                return 0.0;
			}
		}

		private void MonthViewDayRender()
		{
			string[] arrDate = pbSelMonth.Split ('.');
			string sCurrDate = string.Empty;
			double nPercentJoin = 0.0;
			double nPercentContact = 0.0;

			int nMonthDays = DateTime.DaysInMonth (int.Parse(arrDate[0]), int.Parse(arrDate[1]));

			double nMonthWriteTotal = double.Parse (ltrMonthWrite.Text.Replace (",", ""));
			double nMonthReadTotal = double.Parse (ltrMonthRead.Text.Replace (",", ""));
			double nMaxCnt = 0.0;

			if (nMonthWriteTotal > nMonthReadTotal)
			{
				nMaxCnt = nMonthWriteTotal;              
			}
			else
			{
				nMaxCnt = nMonthReadTotal;
			}

			int nWriteCount;
			int nReadCount;

			MonthViewLoad();


			for (int i=1; i <= nMonthDays; i++)
			{
				nWriteCount = 0;
				nReadCount = 0;

				sCurrDate = pbSelMonth + "." + i.ToString().PadLeft (2, '0');

				DataRow[] drJoin = dtMonthWrite.Select ("dt = '" + sCurrDate + "'");

				if (drJoin.Length > 0)
				{
					nWriteCount = int.Parse (drJoin[0][1].ToString());
					nPercentJoin = GetPercent (nMaxCnt, double.Parse (drJoin[0][1].ToString()));
				}
				else
				{
					nPercentJoin = 0.0;
				}

				DataRow[] drContact = dtMonthRead.Select ("dt = '" + sCurrDate + "'");

				if (drContact.Length > 0)
				{
					nReadCount = int.Parse (drContact[0][1].ToString());
					nPercentContact = GetPercent (nMaxCnt, double.Parse (drContact[0][1].ToString()));
				}
				else
				{
					nPercentContact = 0.0;
				}

				
				HtmlTableRow htRow = null;
				HtmlTableCell htCell = null;

                
				htRow = new HtmlTableRow();

				htCell = new HtmlTableCell();
				htCell.RowSpan = 2;
				htCell.Align = "center";
				htCell.Width = "90";
				htCell.Attributes["class"] = "graph_header_font";
				htCell.InnerHtml = sCurrDate;
				htRow.Cells.Add (htCell);

				htCell = new HtmlTableCell();
				htCell.Align = "center";
				htCell.Width = "80";
				htCell.Attributes["class"] = "graph_title_font";
				htCell.InnerHtml = "ۼ ";
				htRow.Cells.Add (htCell);

				htCell = new HtmlTableCell();
				htCell.Align = "left";
				htCell.Attributes["class"] = "graph_font";
				htCell.InnerHtml = "<div style='width : " + nPercentJoin.ToString() + "%' class='graph_color' title='" + nWriteCount.ToString("#,0") + "'><img src='../../Images/tran.gif' width='1' height='1' border='0'></div>";
				htRow.Cells.Add (htCell);

				tblMonthView.Rows.Add (htRow);

				htRow = new HtmlTableRow();

				htCell = new HtmlTableCell();
				htCell.Align = "center";
				htCell.Width = "80";
				htCell.Attributes["class"] = "graph_title_font";
				htCell.InnerHtml = " ";
				htRow.Cells.Add (htCell);

				htCell = new HtmlTableCell();
				htCell.Align = "left";
				htCell.Attributes["class"] = "graph_font";
				htCell.InnerHtml = "<div style='width : " + nPercentContact.ToString() + "%' class='graph_color2' title='" + nReadCount.ToString("#,0") + "'><img src='../../Images/tran.gif' width='1' height='1' border='0'></div>";
				htRow.Cells.Add (htCell);

				tblMonthView.Rows.Add (htRow);
			}

			MonthViewUnLoad();
		}

		DataTable dtMonthWrite = null;
		DataTable dtMonthRead = null;

		private void MonthViewLoad()
		{
			StringWriter sw = new StringWriter();

			string sBoardNo = ddlBoardList.SelectedValue;

			// Ϻ 
			sw.WriteLine ("select convert (char(10), write_date, 102) as dt, count (write_date) as cnt");
			sw.WriteLine ("from nb_boarddata_{0}", sBoardNo);
			sw.WriteLine ("where convert (char(7), write_date, 102) = '{0}'", pbSelMonth);
			sw.WriteLine ("group by convert (char(10), write_date, 102)");
			sw.WriteLine ("order by convert (char(10), write_date, 102) asc");
			// Ϻ 
			sw.WriteLine ("select convert (char(10), write_date, 102) as dt, sum (hit_cnt) as cnt");
			sw.WriteLine ("from nb_boarddata_{0}", sBoardNo);
			sw.WriteLine ("where convert (char(7), write_date, 102) = '{0}'", pbSelMonth);
			sw.WriteLine ("group by convert (char(10), write_date, 102)");
			sw.WriteLine ("order by convert (char(10), write_date, 102) asc");


			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection(ref dbSqlConn);

				DataSet dsData = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.Text, sw.ToString());

				if (dsData != null)
				{
					dtMonthWrite = dsData.Tables[0];
					dtMonthRead = dsData.Tables[1];
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}            		
		}

		private void MonthViewUnLoad()
		{
			if (dtMonthWrite != null)
			{
				dtMonthWrite.Dispose();
			}

			if (dtMonthRead != null)
			{
				dtMonthRead.Dispose();
			}
		}

		private void lnkPrevMonth_Click(object sender, System.EventArgs e)
		{
			MoveMonth (-1);		
		}

		private void lnkNextMonth_Click(object sender, System.EventArgs e)
		{
			MoveMonth (1);		
		}

		private void MoveMonth(int nMove)
		{
			string sCurMon = lblCurrMonth.Text;

			DateTime dtCur = DateTime.Parse (sCurMon + ".01");

			pbSelMonth = dtCur.AddMonths(nMove).ToString ("yyyy.MM");
            
			lblCurrMonth.Text = pbSelMonth;

			ddlBoardList.SelectedIndex = ddlBoardList.SelectedIndex;

			GetBoardReport();
			MonthViewDayRender();
		}

		#region Web Form ̳ʿ  ڵ
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN:  ȣ ASP.NET Web Form ̳ʿ ʿմϴ.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		̳  ʿ ޼Դϴ.  ޼ 
		///		ڵ   ʽÿ.
		/// </summary>
		private void InitializeComponent()
		{
			this.ddlBoardList.SelectedIndexChanged += new System.EventHandler(this.ddlBoardList_SelectedIndexChanged);
			this.lnkPrevMonth.Click += new System.EventHandler(this.lnkPrevMonth_Click);
			this.lnkNextMonth.Click += new System.EventHandler(this.lnkNextMonth_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void ddlBoardList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			pbSelMonth = lblCurrMonth.Text;

			GetBoardReport();
			MonthViewDayRender();		
		}
	}
}
