﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web;
using System.Xml;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;

namespace NeAdmin
{
	public class Login : Page
	{
		#region Controls
		protected CheckBox chk_id_save;
		protected TextBox txt_mem_id;
		protected TextBox txt_mem_pwd;
		protected Label lbl_login_msg;
		protected ImageButton ibtn_login_ok;
		protected System.Web.UI.HtmlControls.HtmlGenericControl body_login_form;
		#endregion
		
		protected const string sDefaultMainPage = "Body/BoardMng/BoardMng.aspx";
	
		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				if (AppVersionChk())
				{
					if (!File.Exists (NBLib.NeBoardSettingFilePath()))
					{
						CreateBoardSetting();
					}

					if (!NBAdminUtil.isAdminLogin ())
					{
						/* Input From Initial Setting */
						ArrayList objValidChkCont = new ArrayList();
						NBCmnUtil.PageTextBoxControls(objValidChkCont, Page.Controls);
						NBCmnUtil.FieldInputValidSetting("NB_MemberData", objValidChkCont);

						if (!IsPostBack)
						{
							PrivDisplayLoginID();
							ButtonScript();
						}
					}
					else
					{
						NBCmnUtil.ViewMsgGoUrl (Page, sDefaultMainPage, "");
					}
				}
			}
			catch(Exception E)
			{
                NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}
		
		private void CreateBoardSetting()
		{
			try
			{
				XmlTextWriter xWriter = new XmlTextWriter (NBLib.NeBoardSettingFilePath(), System.Text.Encoding.UTF8);
            
				// document Start
				xWriter.WriteStartDocument ();

				// SMTP Start
				xWriter.WriteStartElement ("SMTP");

				// ServerName Element
				xWriter.WriteStartElement ("ServerName");
				xWriter.WriteString ("127.0.0.1");
				xWriter.WriteEndElement ();

				// SMTP End
				xWriter.WriteEndElement();

				// document End
				xWriter.WriteEndDocument();

				xWriter.Flush();
				xWriter.Close();
			}
			catch {}
		}

		/// <summary>
		/// 웹 컨트롤의 클라이언트 스크립트 설정
		/// </summary>
		private void ButtonScript()
		{
			ibtn_login_ok.Attributes.Add("onclick","return Validation(this.form." + txt_mem_id.ClientID + ", this.form." + txt_mem_pwd.ClientID + ")");
            body_login_form.Attributes.Add ("onload", "ErrInputProc(document.Login." + txt_mem_id.ClientID + ");");
		}

		/// <summary>
		/// 내보드의 버전을 체크하여 업그레이드 작업을 실행
		/// </summary>
		/// <returns></returns>
		private bool AppVersionChk()
		{
			bool bResult = false;
			string sTarUrl = string.Empty;
			string sBoardCfgUrl = "NeBoardUpgrade/NeBoardConfig.aspx";
			string sDBUpgradeUrl = "NeBoardUpgrade/SysUpgrade.aspx";

			try
			{
				// BoardConfig 파일에 내용이 있는지 검사
				if (NBUtil.ValidBoardCfgFile ())
				{
					// 파일 업로드 폴더 유무와 쓰기 권한 체크
					if (Directory.Exists (NBUtil.GetUploadRootPath()))
					{
						// DB 접속을 테스트 해서 DB 접속 가능인지 검사
						if (DBUtil.bTestDbConnection ())
						{
							// DB에 테이블이 생성 되었는지 검사
							if ( VersionInfo.GetTableExist() )
							{
								if (!NBUtil.StrEmptyChk(ConfigurationSettings.AppSettings["DB_Ver_Check"]) && 
									!ConfigurationSettings.AppSettings["DB_Ver_Check"].Equals("1"))
								{
									// 버전 체크를 안해도 되는 상황
									txt_mem_id.Enabled = true;
									txt_mem_pwd.Enabled = true;
									bResult = true;
								}
								else
								{
									// 버전 체크를 하는 상황
									VerCheck.VerCheck oVerChk = null;
									
									try
									{
										oVerChk = new VerCheck.VerCheck();
									}
									catch
									{
									}

									if (oVerChk != null)
									{
										string sVerChk = oVerChk.VersionCheck (VersionInfo.GetAppVersion(), VersionInfo.GetDbVersion());
										oVerChk.Dispose();

										if ( sVerChk.ToUpper().EndsWith (":OK") )
										{
											txt_mem_id.Enabled = true;
											txt_mem_pwd.Enabled = true;
											bResult = true;
										}
										else
										{
											sTarUrl = sDBUpgradeUrl;										
										}
									}
									else
									{
										txt_mem_id.Enabled = true;
										txt_mem_pwd.Enabled = true;
										bResult = true;
									}
								}
							}
							else
							{
								Response.Redirect ("NeBoardUpgrade/SysInstall.aspx", false);
							}
						}
						else
							sTarUrl = sBoardCfgUrl;
					}
					else
						sTarUrl = sBoardCfgUrl;
				}
				else
					sTarUrl = sBoardCfgUrl;



				if (!NBUtil.StrEmptyChk (sTarUrl))
					Response.Redirect (sTarUrl, false);
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}

			return bResult;
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// 디자이너 지원에 필요한 메서드입니다.
		/// 이 메서드의 내용을 코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{    
			this.ibtn_login_ok.Click += new System.Web.UI.ImageClickEventHandler(this.ibtn_login_ok_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion
		
		/// <summary>
		/// 로그인 아이디가 저장되어 있을경우 저장된 아이디 보여주기
		/// </summary>
		private void PrivDisplayLoginID()
		{
			if(Request.Cookies["LID"] != null)
			{
				txt_mem_id.Text = Request.Cookies["LID"].Value;
				chk_id_save.Checked = true;
			}
			else
			{
				txt_mem_id.Text = string.Empty;
				chk_id_save.Checked = false;
			}
		}

		/// <summary>
		/// 쿠키 저장 설정에 따라서 ID를 쿠키에 저장
		/// </summary>
		private void SaveLoginID()
		{
			if(chk_id_save.Checked)
				NBCmnUtil.SaveCookiValue ("LID", txt_mem_id.Text.Trim(), 60 * 30);
			else
				NBCmnUtil.RemoveCookiValue ("LID");
		}		



        /// <summary>
        /// 입력값 유효성 검사
        /// </summary>
        /// <returns></returns>
		private bool DoFieldValidChk()
		{
			bool bResult = false;

			if (txt_mem_id.Text.Trim().Length > 0 && txt_mem_pwd.Text.Trim().Length > 0)
				bResult = true;

			return bResult;
		}


		/// <summary>
		/// 로그인 버튼 이벤트
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void ibtn_login_ok_Click(object sender, ImageClickEventArgs e)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				if (DoFieldValidChk())
				{
					DBUtil.DBConnection(ref dbSqlConn);

					bool bChkUser = false;
					string
						sGuestNo = string.Empty,
						sMemPwd = string.Empty;
					int nSessOut = 0;
						
					StringWriter swQry = null;

					swQry = new StringWriter();

					swQry.WriteLine ("SELECT guest_no, mem_pwd");
					swQry.WriteLine ("FROM NB_MemberData ");
					swQry.WriteLine ("WHERE mem_id = " + DBUtil.QryConvStr (txt_mem_id.Text, false));

					SqlDataReader drMemInfo = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, swQry.ToString());
		
					if (drMemInfo.Read())
					{
						sGuestNo = drMemInfo["guest_no"].ToString();
						sMemPwd = drMemInfo["mem_pwd"].ToString();
					}

					dbSqlConn.Close();

					if (!NBUtil.StrEmptyChk (sGuestNo))
					{
						if (!NBUtil.StrEmptyChk (sMemPwd) && sMemPwd.Equals(txt_mem_pwd.Text))
						{
							// 최고 관리자 
							if (sGuestNo.Equals(NBLib.SuperAdmin))
							{
								bChkUser = true;
							}
								// 일반 관리자 검사
							else
							{
								swQry = new StringWriter();

								swQry.WriteLine ("SELECT COUNT(*) FROM NB_GroupAdminInfo WHERE guest_no = '" + sGuestNo + "'");

								int nCnt = int.Parse(SqlHelper.ExecuteScalar (dbSqlConn, CommandType.Text, swQry.ToString()).ToString());

								if (nCnt > 0)
									bChkUser = true;
							}
						}

						if (bChkUser)
						{
							NBCmnUtil.SaveCookiValue ("NEADMIN_MBNO", sGuestNo, nSessOut);

							if (sGuestNo.Equals(NBLib.SuperAdmin))
							{
								NBCmnUtil.SaveCookiValue ("NEADMIN_ADMINGROUP", "ALL", nSessOut);
							}
							else
							{
								string[] arrAdminGroup = NBAdminUtil.GetAdminGroup(sGuestNo);
								NBCmnUtil.SaveCookiValue ("NEADMIN_ADMINGROUP", string.Join(",", arrAdminGroup), nSessOut);
							}

							SaveLoginID();

							NBCmnUtil.ViewMsgGoUrl (Page, sDefaultMainPage, "");
						}
						else
						{
							txt_mem_pwd.Text = string.Empty;

							lbl_login_msg.Text = "아이디 / 비밀번호가 틀리거나, 관리자로 등록된 사용자가 아닙니다.";
						}
					}
					else
					{
					}
				}
				else
				{
					lbl_login_msg.Text = "아이디 / 비밀번호를 입력해 주세요.";
				}				
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose(ref dbSqlConn);
			}
		}
	}
}
