﻿using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Xml;
using System.IO;
using System.Data.SqlClient;
using System.Data;
using BoardLib;

namespace NeAdmin.NeBoardUpgrade
{
	/// <summary>
	/// NeBoardConfig에 대한 요약 설명입니다.
	/// </summary>
	public class NeBoardConfig : Page
	{
		protected TextBox txt_fileupload_path;
		protected TextBox txt_dbsvr_name;
		protected TextBox txt_db_name;
		protected TextBox txt_db_uid;
		protected TextBox txt_db_upwd;
		protected ImageButton imgbtn_start_proc;
		
		public string WebRootPhyPath;
	
		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				WebRootPhyPath = Server.MapPath ("/");

				if (!IsPostBack)
				{
					LoadBoardConfigFile();
				}
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}

		private void LoadBoardConfigFile()
		{
			XmlDocument xmlDoc = NBUtil.GetFileToXmlDoc (NBLib.BoardCfgFilePath());

			if (xmlDoc != null)
			{
				XmlNodeList xmlNodeList;

				xmlNodeList = xmlDoc.GetElementsByTagName("uploadRootPath");
				txt_fileupload_path.Text = xmlNodeList.Item(0).Attributes["value"].Value;
		
				xmlNodeList = xmlDoc.GetElementsByTagName("dbserver");
				txt_dbsvr_name.Text = xmlNodeList.Item(0).Attributes["value"].Value;

				xmlNodeList = xmlDoc.GetElementsByTagName("dbname");
				txt_db_name.Text = xmlNodeList.Item(0).Attributes["value"].Value;

				xmlNodeList = xmlDoc.GetElementsByTagName("dbuid");
				txt_db_uid.Text = xmlNodeList.Item(0).Attributes["value"].Value;
			}
		}

		

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// 디자이너 지원에 필요한 메서드입니다.
		/// 이 메서드의 내용을 코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{    
			this.imgbtn_start_proc.Click += new ImageClickEventHandler(this.imgbtn_start_proc_Click);
			this.Load += new EventHandler(this.Page_Load);

		}
		#endregion

		private void imgbtn_start_proc_Click(object sender, ImageClickEventArgs e)
		{
			try
			{
				// NeBoardConfig.aspx 파일의 쓰기 여부를 알기 위해서 Write 모드로 Open 해보고 Close 한다.
				FileStream fsBoardCfg = new FileStream(NBLib.BoardCfgFilePath(), FileMode.OpenOrCreate, FileAccess.Write);
				fsBoardCfg.Close();

				if (bValidForm())
				{
					// BoardConfig.xml 저장
					if (NBUtil.MKBoardCfgFile (txt_fileupload_path.Text, txt_dbsvr_name.Text, txt_db_name.Text, txt_db_uid.Text, txt_db_upwd.Text, true))
						NBCmnUtil.ViewMsgGoUrl (Page, "../Default.aspx", "저장되었습니다.");
					else
						throw new Exception ("환경설정 파일 저장 중 오류가 있습니다.");
				}
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}

		private bool bValidForm()
		{
			// 입력값이 올바른지 체크
			if (NBUtil.StrEmptyChk (txt_fileupload_path.Text))
			{
				NBCmnUtil.ViewAlertMsg (Page, "파일 업로드 디렉터리 경로를 입력해 주세요.");
				return false;
			}

			if (NBUtil.StrEmptyChk (txt_dbsvr_name.Text))
			{
				NBCmnUtil.ViewAlertMsg (Page, "데이타베이스 서버를 입력해 주세요.");
				return false;
			}

			if (NBUtil.StrEmptyChk (txt_db_name.Text))
			{
				NBCmnUtil.ViewAlertMsg (Page, "데이타베이스 이름을 입력해 주세요.");
				return false;
			}

			if (NBUtil.StrEmptyChk (txt_db_uid.Text))
			{
				NBCmnUtil.ViewAlertMsg (Page, "데이타베이스 로그인 계정 아이디를 입력해 주세요.");
				return false;
			}

			if (NBUtil.StrEmptyChk (txt_db_upwd.Text))
			{
				NBCmnUtil.ViewAlertMsg (Page, "데이타베이스 로그인 계정 비밀번호를 입력해 주세요.");
				return false;
			}

			// 업로드 폴더 존재 여부 체크
			if (!Directory.Exists (txt_fileupload_path.Text))
			{
				NBCmnUtil.ViewAlertMsg (Page, "입력하신 업로드 디렉터리를 찾을 수 없습니다.");
				return false;
			}

            // DB 연결 테스트
			SqlConnection dbSqlConn = new SqlConnection();
			dbSqlConn.ConnectionString = "server=" + txt_dbsvr_name.Text + ";database=" + txt_db_name.Text + ";uid=" + txt_db_uid.Text + ";pwd=" + txt_db_upwd.Text;

			try
			{
				dbSqlConn.Open();
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
				return false;
			}
			finally
			{
				dbSqlConn.Close();
				dbSqlConn.Dispose();
			}

			return true;
		}
	}
}
