﻿/* ***************************************************************
 * 제목 : 게시판 시작 페이지
 * 
 * 제작 : 닷넷피아 - www.dotnetpia.co.kr
 *        이정호 (potato@dotnetpia.co.kr) 
 * 
 * ***************************************************************/

using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Xml;
using BoardLib;
using EeekSoft.Web;
using NeBoard.Common;

namespace NeBoard
{
	public class NBBoardMain : Page
	{
		#region Declare Field
		protected PopupWin popupWin;
		protected PlaceHolder ControlHolder;
		protected Literal LtrRightStamp;
		protected HtmlTable HTTblRightStamp;

		// Page Binding String
		public string
			BrowserTitle,				// 브라우져 타이틀
            PageBackColor,				// 페이지 배경색
			PageBackImg,				// 페이지 배경 이미지
			PageHeaderContent,			// 페이지 헤더 내용
			PageCopyRightContent,		// 카피라이트 내용
			PageTailContent,			// 페이지 꼬리말 내용
			ScrollBarStyle,				// 페이지 스크롤 바 스타일
			CurrSkinPath,				// 현재 스킨 경로
			UserCtrl_PreFix,			// 사용자 정의 컨트롤 PreFix
			gBoardNo,					// 게시판 코드
			gViewMode;					// 게시판 작동 모드

		// 게시판 설정
		public NBLib.CurBoardCfg mBoardCfg;
		#endregion
		
		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				InitDataLoad();

				if (NBUtil.SetLicenseStamp(mBoardCfg, gViewMode, ref HTTblRightStamp, ref LtrRightStamp))
				{
					if(!NBUtil.DoIPChk(mBoardCfg, gBoardNo))
						NBPreProc.ShowMemoPopup (mBoardCfg, gBoardNo, popupWin);
					else
						throw new Exception ("접속하신 IP (" + Request.UserHostAddress + ")는 차단된 IP입니다.");
				}

				SetPageDataBind();
			}
			catch(Exception E)
			{
				Response.Clear();
                NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
		}

		/// <summary>
		/// 게시판 초기 설정 값을 로드 한다.
		/// </summary>
		public void InitDataLoad()
		{
			gBoardNo = NBCmnUtil.QStrLoad ("bno");
			gViewMode = NBCmnUtil.QStrLoad ("mode");

			if (NBUtil.StrEmptyChk (gBoardNo))
				throw new Exception (@"설정된 게시판 코드가 없습니다.\n\n게시판을 선택해 주세요.");

			if (NBUtil.StrEmptyChk (gViewMode))
				gViewMode = "LIST";

			NBUtil.GetData_BoardCfg (ref mBoardCfg, gBoardNo, gViewMode, "0");

			DoLoadControl();
		}

		public void DoLoadControl()
		{
			string sControlPath = string.Empty;

			switch (gViewMode.ToUpper())
			{
				case "LIST":
					sControlPath = mBoardCfg.bnd_skin_path + "/" + "BoardList.ascx";
					break;
				case "WRITE":
					sControlPath = mBoardCfg.bnd_skin_path + "/" + "BoardWrite.ascx";
					break;
				case "MODIFY":
					sControlPath = mBoardCfg.bnd_skin_path + "/" + "BoardModify.ascx";
					break;		
				case "VIEW":
					sControlPath = mBoardCfg.bnd_skin_path + "/" + "BoardView.ascx";
					break;
				case "DELETE":
					sControlPath = mBoardCfg.bnd_skin_path + "/" + "Delete.ascx";
					break;
				case "LOGIN":
					sControlPath = mBoardCfg.bld_loginskin_path + "/" + "Login.ascx";
					break;
				case "MYINFO":
					sControlPath = mBoardCfg.bld_loginskin_path + "/" + "MyInfo.ascx";
					break;
				case "JOIN":
					sControlPath = mBoardCfg.bjd_joinskin_path + "/" + "Signup.ascx";
					break;
				default:
					sControlPath = mBoardCfg.bnd_skin_path + "/" + "BoardList.ascx";
					break;
			}

			UserCtrl_PreFix = "NBUC";
			
			using (UserControl oBoardControl = (UserControl)this.LoadControl(sControlPath))
			{
				oBoardControl.ID = UserCtrl_PreFix;
				oBoardControl.EnableViewState = false;
				ControlHolder.Controls.Add(oBoardControl);
			}
		}

		private void SetPageDataBind()
		{
			if (!NBUtil.StrEmptyChk (mBoardCfg.bnd_browser_title))
				BrowserTitle = mBoardCfg.bnd_browser_title;

			if (gViewMode.ToUpper().Equals("LOGIN") || gViewMode.ToUpper().Equals("MYINFO"))
			{
				CurrSkinPath = mBoardCfg.bld_loginskin_path;

				PageBackColor = mBoardCfg.bld_loginbg_color;
				PageBackImg = mBoardCfg.bld_loginbg_img;

				NBUtil.SetDisplayType(ref PageHeaderContent, mBoardCfg.bld_loginheader_type, mBoardCfg.bld_loginheader_cont);
				NBUtil.SetDisplayType(ref PageCopyRightContent, mBoardCfg.bld_logincopyright_type, mBoardCfg.bld_logincopyright_cont);
				NBUtil.SetDisplayType(ref PageTailContent, mBoardCfg.bld_logintail_type, mBoardCfg.bld_logintail_cont);

				if (!NBUtil.StrEmptyChk (mBoardCfg.bld_loginsbar_style))
					ScrollBarStyle = "body {" + mBoardCfg.bld_loginsbar_style + "}";
			}
			else if (gViewMode.ToUpper().Equals("JOIN"))
			{
				CurrSkinPath = mBoardCfg.bjd_joinskin_path;

				PageBackColor = mBoardCfg.bjd_joinbg_color;
				PageBackImg = mBoardCfg.bjd_joinbg_img;

				NBUtil.SetDisplayType(ref PageHeaderContent, mBoardCfg.bjd_joinheader_type, mBoardCfg.bjd_joinheader_cont);
				NBUtil.SetDisplayType(ref PageCopyRightContent, mBoardCfg.bjd_joincopyright_type, mBoardCfg.bjd_joincopyright_cont);
				NBUtil.SetDisplayType(ref PageTailContent, mBoardCfg.bjd_jointail_type, mBoardCfg.bjd_jointail_cont);

				if (!NBUtil.StrEmptyChk (mBoardCfg.bjd_joinsbar_style))
					ScrollBarStyle = "body {" + mBoardCfg.bjd_joinsbar_style + "}";
			}
			else
			{
				CurrSkinPath = mBoardCfg.bnd_skin_path;
				
				PageBackColor = mBoardCfg.bnd_pagebg_color;
				PageBackImg = mBoardCfg.bnd_pagebg_img;

				NBUtil.SetDisplayType(ref PageHeaderContent, mBoardCfg.bnd_header_type, mBoardCfg.bnd_header_cont);
				NBUtil.SetDisplayType(ref PageCopyRightContent, mBoardCfg.bnd_copyright_type, mBoardCfg.bnd_copyright_cont);
				NBUtil.SetDisplayType(ref PageTailContent, mBoardCfg.bnd_tail_type, mBoardCfg.bnd_tail_cont);

				if (!NBUtil.StrEmptyChk (mBoardCfg.bnd_sbar_style))
					ScrollBarStyle = "body {" + mBoardCfg.bnd_sbar_style + "}";
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// 디자이너 지원에 필요한 메서드입니다.
		/// 이 메서드의 내용을 코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion
	}
}
