﻿using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;
using NeBoard.Common;

namespace NeBoard.Common
{
	public class BoardListMng : Page
	{
		protected Button WNBtnAgreeYes;
		protected Button WNBtnAgreeNo;
		protected Button WNBtnDelete;
		protected CheckBox WNChkAlertUse;

		private string mBoardNo = string.Empty;
		protected System.Web.UI.WebControls.DropDownList WNDdlGroupList;
		protected System.Web.UI.WebControls.DropDownList WNDdlBoardList;
		protected System.Web.UI.WebControls.Button WNRdoMCStart;
		protected System.Web.UI.WebControls.CheckBox ChkAlert;
		protected System.Web.UI.WebControls.Button WNRdoMMStart;
		private string mChkList;

		private void Page_Load(object sender, EventArgs e)
		{
			DoQueryStringLoad();

			if (!IsPostBack)
			{
				InitSetting();
			}
		}

		#region 게시판 초기 설정
        /// <summary>
        /// 쿼리스트링값 읽기
        /// </summary>
		private void DoQueryStringLoad()
		{
			if (!NBUtil.StrEmptyChk (Request.QueryString["bno"]))
				mBoardNo = Request.QueryString["bno"].Trim();

			if (!NBUtil.StrEmptyChk (Request.QueryString["chkid"]))
			{
                string[] aChkList = Request.QueryString["chkid"].Trim().Split('|');

				mChkList = string.Empty;

				foreach (string sChkItem in aChkList)
				{
					if (!NBUtil.StrEmptyChk (sChkItem))
                        mChkList += "," + sChkItem;
				}

				if (mChkList.Length > 0)
				{
					if (mChkList.StartsWith(","))
                        mChkList = mChkList.Substring(1, mChkList.Length - 1);
				}
			}
		}


		/// <summary>
		/// 초기 세팅
		/// </summary>
		private void InitSetting()
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				// 그룹 리스트 바인
				DoGroupListBind (dbSqlConn);

				if (!NBUtil.StrEmptyChk(WNDdlGroupList.Items[0].Value))
                    DoBoardListBind (dbSqlConn, WNDdlGroupList.Items[0].Value.Trim());
			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}
		#endregion

		#region 그룹과 게시판 리스트를 드롭다운 리스트에 바인딩
		/// <summary>
		/// 그룹 리스트 바인딩
		/// </summary>
		/// <param name="dbSqlConn"></param>
		private void DoGroupListBind(SqlConnection dbSqlConn)
		{
			try
			{
				string Qry = "SELECT group_code, group_name FROM NB_GroupInfo ORDER BY group_code";

				DataSet dsGroupLists = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.Text, Qry);

				if (dsGroupLists.Tables[0].Rows.Count > 0)
				{
					WNDdlGroupList.DataSource = dsGroupLists;
					WNDdlGroupList.DataTextField = "group_name";
					WNDdlGroupList.DataValueField = "group_code";
					WNDdlGroupList.DataBind();

					WNRdoMCStart.Enabled = true;
					WNRdoMMStart.Enabled = true;
				}
				else
				{
					WNRdoMCStart.Enabled = false;
					WNRdoMMStart.Enabled = false;
				}
			}
			catch (Exception E)
			{
				throw E;
			}
			finally
			{
				dbSqlConn.Close();
			} 
		}


		/// <summary>
		/// 게시판 리스트 바인딩
		/// </summary>
		/// <param name="dbSqlConn"></param>
		/// <param name="sGroupCode"></param>
		private void DoBoardListBind(SqlConnection dbSqlConn, string sGroupCode)
		{
			try
			{
				string Qry = "SELECT board_no, board_name FROM NB_BoardSet WHERE board_no LIKE '" + sGroupCode + "%' AND board_no != '" + mBoardNo + "' ORDER BY board_no";

                DataSet dsBoardLists = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.Text, Qry);

				if (dsBoardLists.Tables[0].Rows.Count > 0)
				{
					WNDdlBoardList.DataSource = dsBoardLists;
					WNDdlBoardList.DataTextField = "board_name";
					WNDdlBoardList.DataValueField = "board_no";
					WNDdlBoardList.DataBind();

					WNRdoMCStart.Enabled = true;
				}
				else
				{
					WNRdoMCStart.Enabled = false;
				}
			}
			catch (Exception E)
			{
				throw E;
			}
			finally
			{
				dbSqlConn.Close();
			}
		}

		/// <summary>
		/// 게시판 그룹 변경 이벤트
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void WNDdlGroupList_SelectedIndexChanged(object sender, EventArgs e)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				DoBoardListBind (dbSqlConn, WNDdlGroupList.SelectedValue.Trim());
			}
			catch (Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}
		#endregion

		#region Web Form 디자이너에서 생성한 코드
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// 디자이너 지원에 필요한 메서드입니다.
		/// 이 메서드의 내용을 코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{    
			this.WNBtnAgreeYes.Click += new System.EventHandler(this.WNBtnAgreeYes_Click);
			this.WNBtnAgreeNo.Click += new System.EventHandler(this.WNBtnAgreeNo_Click);
			this.WNDdlGroupList.SelectedIndexChanged += new System.EventHandler(this.WNDdlGroupList_SelectedIndexChanged);
			this.WNRdoMCStart.Click += new System.EventHandler(this.WNRdoMCStart_Click);
			this.WNBtnDelete.Click += new System.EventHandler(this.WNBtnDelete_Click);
			this.WNRdoMMStart.Click += new System.EventHandler(this.WNRdoMMStart_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		#region 게시물 승인/미승인 처리
		/// <summary>
		/// 게시물 승인 이벤트
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void WNBtnAgreeYes_Click(object sender, EventArgs e)
		{
			string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

			if (ChkAlert.Checked && NBUtil.StrEmptyChk (sMngEmail))
			{
				NBCmnUtil.ViewAlertMsg(Page, "관리자 메일이 설정 되어 있어야 작업 후 글쓴이에게 메일로 알림 기능이 가능 합니다.");
			}
			else
			{
				if (DoChgAgreeYN("1"))
					NBCmnUtil.ViewMsgOpenerReLoad (Page, "변경 완료", true);
				else
					NBCmnUtil.ViewAlertMsg (Page, "변경 실패");
			}
		}

		/// <summary>
		/// 게시물 미승인 이벤트
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void WNBtnAgreeNo_Click(object sender, EventArgs e)
		{
			string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

			if (ChkAlert.Checked && NBUtil.StrEmptyChk (sMngEmail))
			{
				NBCmnUtil.ViewAlertMsg(Page, "관리자 메일이 설정 되어 있어야 작업 후 글쓴이에게 메일로 알림 기능이 가능 합니다.");
			}
			else
			{
				if (DoChgAgreeYN("0"))
					NBCmnUtil.ViewMsgOpenerReLoad (Page, "변경 완료", true);
				else
					NBCmnUtil.ViewAlertMsg (Page, "변경 실패");
			}
		}

		/// <summary>
		/// 게시물 승인/미승인 처리
		/// </summary>
		/// <param name="sFlag"></param>
		/// <returns></returns>
		private bool DoChgAgreeYN(string sFlag)
		{
			SqlConnection dbSqlConn = null;
			bool bResult = false;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				string sQry = "UPDATE NB_BoardData_" + mBoardNo + " SET agree_yn = '" + sFlag + "' WHERE idx_no in (" + mChkList + ")";

				if (SqlHelper.ExecuteNonQuery (dbSqlConn, CommandType.Text, sQry) > 0)
				{
					bResult = true;		// 변경 성공

					if (ChkAlert.Checked)
					{
						foreach (string idx in mChkList.Split(','))
						{
							DoSendAlertMsgAgree (idx, sFlag);
						}
					}
				}
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}

			return bResult;
		}
		#endregion

		#region 게시물 삭제
		/// <summary>
		/// 게시물 삭제 이벤트
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void WNBtnDelete_Click(object sender, EventArgs e)
		{
			string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

			if (ChkAlert.Checked && NBUtil.StrEmptyChk (sMngEmail))
			{
				NBCmnUtil.ViewAlertMsg(Page, "관리자 메일이 설정 되어 있어야 작업 후 글쓴이에게 메일로 알림 기능이 가능 합니다.");
			}
			else
			{
				if (DoDeleteItem())
				{
					NBCmnUtil.ViewMsgOpenerReLoad (Page, "삭제 완료", true);
				}
				else
				{
					NBCmnUtil.ViewAlertMsg (Page, "삭제 실패");
				}
			}
		}

		/// <summary>
		/// 게시물 삭제 처리
		/// </summary>
		/// <param name="bFlag"></param>
		/// <returns></returns>
		private bool DoDeleteItem()
		{
			SqlConnection dbSqlConn = null;

			bool bResult = false;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);
				
				string sQry = string.Empty;

				sQry = "select idx_no from NB_BoardData_" + mBoardNo + " where idx_no in (" + mChkList + ") order by idx_no asc";

				SqlDataReader drDelIdx = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sQry);

				while (drDelIdx.Read())
				{
					DoSendAlertMsgDel (drDelIdx["idx_no"].ToString());

					NBUtil.DeleteOk (mBoardNo, drDelIdx["idx_no"].ToString());
				}

				// 변경 성공
				bResult = true;
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewMsgOpenerReLoad (Page, E.Message, false);
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}

			return bResult;
		}
		#endregion

		
		// 게시물 복사
		private bool DoCopyItem(string sTarBoard)
		{
			SqlConnection dbSqlConn = null;

			bool bResult = true;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				string sQry = "SELECT * FROM NB_BoardData_" + mBoardNo + " WHERE idx_no in (" + mChkList + ") ";
				sQry += "ORDER BY ref_no ASC, level_no2 DESC, level_no1 DESC ";


				DataSet dsBoardItem = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.Text, sQry);

				DataTable dtBoardItem = dsBoardItem.Tables[0];

				dbSqlConn.Close();

				if (dtBoardItem.Rows.Count > 0)
				{
					foreach (DataRow drItem in dtBoardItem.Rows)
					{
						DoTransBoard 
							(
							mBoardNo, sTarBoard, drItem["idx_no"].ToString(), drItem["guest_no"].ToString(), drItem["writer"].ToString(),
                            drItem["cat_code"].ToString(), drItem["pwd"].ToString(), drItem["level_no1"].ToString(), drItem["level_no2"].ToString(),
							drItem["agree_yn"].ToString(), drItem["private_yn"].ToString(), drItem["vote_yn"].ToString(), drItem["sum_yn"].ToString(), 
							drItem["sum_html_use"].ToString(), drItem["sum_content"].ToString(), drItem["ref_no"].ToString(), drItem["email"].ToString(),
							drItem["homepage"].ToString(), drItem["writer_ip"].ToString(), drItem["subject"].ToString(), drItem["content"].ToString(), 
							drItem["html_use"].ToString(), drItem["replymail_yn"].ToString(), drItem["cmmtmail_yn"].ToString(), drItem["notice_yn"].ToString(),
							drItem["link1"].ToString(), drItem["link2"].ToString(), drItem["vote_start"].ToString(), drItem["vote_end"].ToString(),
							drItem["disp_start_date"].ToString(), drItem["disp_end_date"].ToString()
							);

						string sFileQry = "select (file_name + file_ext) as fname from NB_FileData_" + mBoardNo + " where idx_no = " + drItem["idx_no"].ToString() + " and rtrim(file_name) != ''";

						SqlDataReader drFiles = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sFileQry);

						while (drFiles.Read())
						{
							string sSourceFile = "";
							string sTargetFile = "";
							string sFileName = drFiles["fname"].ToString();

							// 파일이 있을경우 파일 이동
							if (!NBUtil.StrEmptyChk(sFileName))
							{
								sSourceFile = NBUtil.GetUploadRootPath() + "\\NB_BoardData_" + mBoardNo + "\\" + sFileName;
								sTargetFile = NBUtil.GetUploadRootPath() + "\\NB_BoardData_" + sTarBoard + "\\" + sFileName;
								File.Copy (sSourceFile, sTargetFile, true);
							}
						}

						dbSqlConn.Close();

						DoSendAlertMsgCopy (drItem["idx_no"].ToString());
					}
				}

				NBCmnUtil.ViewMsgOpenerReLoad (Page, "복사 되었습니다.", true);
			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}

			return bResult;
		}

		// 게시물 복사
		private bool DoMoveItem(string sTarBoard)
		{
			SqlConnection dbSqlConn = null;

			bool bResult = true;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				string sQry = "SELECT * FROM NB_BoardData_" + mBoardNo + " WHERE idx_no in (" + mChkList + ") ";
				sQry += "ORDER BY ref_no ASC, level_no2 DESC, level_no1 DESC ";


				DataSet dsBoardItem = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.Text, sQry);

				DataTable dtBoardItem = dsBoardItem.Tables[0];

				dbSqlConn.Close();

				if (dtBoardItem.Rows.Count > 0)
				{
					foreach (DataRow drItem in dtBoardItem.Rows)
					{
						DoTransBoard 
							(
							mBoardNo, sTarBoard, drItem["idx_no"].ToString(), drItem["guest_no"].ToString(), drItem["writer"].ToString(),
							drItem["cat_code"].ToString(), drItem["pwd"].ToString(), drItem["level_no1"].ToString(), drItem["level_no2"].ToString(),
							drItem["agree_yn"].ToString(), drItem["private_yn"].ToString(), drItem["vote_yn"].ToString(), drItem["sum_yn"].ToString(), 
							drItem["sum_html_use"].ToString(), drItem["sum_content"].ToString(), drItem["ref_no"].ToString(), drItem["email"].ToString(),
							drItem["homepage"].ToString(), drItem["writer_ip"].ToString(), drItem["subject"].ToString(), drItem["content"].ToString(), 
							drItem["html_use"].ToString(), drItem["replymail_yn"].ToString(), drItem["cmmtmail_yn"].ToString(), drItem["notice_yn"].ToString(),
							drItem["link1"].ToString(), drItem["link2"].ToString(), drItem["vote_start"].ToString(), drItem["vote_end"].ToString(),
							drItem["disp_start_date"].ToString(), drItem["disp_end_date"].ToString()
							);

						string sFileQry = "select (file_name + file_ext) as fname from NB_FileData_" + mBoardNo + " where idx_no = " + drItem["idx_no"].ToString() + " and rtrim(file_name) != ''";

						SqlDataReader drFiles = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sFileQry);

						while (drFiles.Read())
						{
							string sSourceFile = "";
							string sTargetFile = "";
							string sFileName = drFiles["fname"].ToString();

							// 파일이 있을경우 파일 이동
							if (!NBUtil.StrEmptyChk(sFileName))
							{
								sSourceFile = NBUtil.GetUploadRootPath() + "\\NB_BoardData_" + mBoardNo + "\\" + sFileName;
								sTargetFile = NBUtil.GetUploadRootPath() + "\\NB_BoardData_" + sTarBoard + "\\" + sFileName;
								File.Copy (sSourceFile, sTargetFile, true);
							}
						}

						DoSendAlertMsgMove (drItem["idx_no"].ToString());

						NBUtil.DeleteOk (mBoardNo, drItem["idx_no"].ToString());

						dbSqlConn.Close();
					}
				}

				NBCmnUtil.ViewMsgOpenerReLoad (Page, "이동 되었습니다.", true);
			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}

			return bResult;
		}

		private void DoSendAlertMsgDel(string sIdxNo)
		{
			if (ChkAlert.Checked)
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection (ref dbSqlConn);
					StringWriter Qry = new StringWriter();

					Qry.WriteLine ("DECLARE @nLevelNo1 int,");
					Qry.WriteLine ("	@nLevelNo2 int,");
					Qry.WriteLine ("	@nRefNo int ");
					Qry.WriteLine ("SELECT @nLevelNo1 = level_no1, @nLevelNo2 = level_no2, @nRefNo = ref_no");
					Qry.WriteLine ("	FROM NB_BoardData_{0}", mBoardNo);
					Qry.WriteLine ("	WHERE idx_no = {0}", sIdxNo);
					Qry.WriteLine ("SELECT COUNT(idx_no)");
					Qry.WriteLine ("	FROM NB_BoardData_{0}", mBoardNo);
					Qry.WriteLine ("	WHERE ref_no = @nRefNo AND level_no1 = @nLevelNo1 + 1 AND level_no2 = @nLevelNo2 + 1");

					string sCntRef = SqlHelper.ExecuteScalar (dbSqlConn, CommandType.Text, Qry.ToString()).ToString();

					Qry.Close();

					if ( int.Parse(sCntRef) > 0 )
					{
					}
					else
					{
						string sQry = "";
						string sActionStr = "";

						// 삭제
						sQry = "select isnull(email, '') as email, write_date, subject, writer, content, isnull(html_use, '') as html_use from NB_BoardData_" + mBoardNo + " where idx_no = " + sIdxNo;
						sActionStr = "삭제";

						string sAlertMailStr = NBUtil.getAlertMailStr(Server.MapPath(ConfigurationSettings.AppSettings["NeBoardPath"] + "/Common/AlertMail.xml"), "/MailMsg/BoardMngMail");
                
						SqlDataReader drWriterData = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sQry);

						if (drWriterData.Read())
						{
							string sTmpContent = string.Empty;

							if (drWriterData["html_use"].ToString().Equals("1"))
							{
								sTmpContent = drWriterData["content"].ToString();
							}
							else
							{
								sTmpContent = Server.HtmlEncode (drWriterData["content"].ToString()).Replace("\r\n", "<br>");
							}
							
							drWriterData["content"].ToString();

							sAlertMailStr = sAlertMailStr.Replace("$$WRITEDAY$$", DateTime.Parse(drWriterData["write_date"].ToString()).ToString("yyyy년 MM월 dd일"));
							sAlertMailStr = sAlertMailStr.Replace("$$ACTION$$", sActionStr);
							sAlertMailStr = sAlertMailStr.Replace("$$WRITER$$", drWriterData["writer"].ToString());
							sAlertMailStr = sAlertMailStr.Replace("$$SUBJECT$$", drWriterData["subject"].ToString());
							sAlertMailStr = sAlertMailStr.Replace("$$DESC$$", "<작성 글 본문 내용> <br><br>" + sTmpContent);

							if (Request.Cookies["MBEMAIL"] != null && drWriterData["email"].ToString().Length > 0)
							{
								string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

								NBUtil.SendMail (sMngEmail, drWriterData["email"].ToString(), "", "", 
									"[" + drWriterData["subject"].ToString() + "] 제목의 글이 " + sActionStr + " 되었습니다.", sAlertMailStr, "1");
							}
						}
					}
				}
				catch (Exception E)
				{
					throw E;
				}
				finally
				{
					DBUtil.DBConnDispose (ref dbSqlConn);
				}
			}
		}

		private void DoSendAlertMsgCopy(string sIdxNo)
		{
			if (ChkAlert.Checked)
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection (ref dbSqlConn);
					string sQry = "";
					string sActionStr = "";

					sQry = "select isnull(email, '') as email, write_date, subject, writer, content, isnull(html_use, '') as html_use from NB_BoardData_" + mBoardNo + " where idx_no = " + sIdxNo;
					sActionStr = "[" + WNDdlBoardList.SelectedItem.Text + "] 게시판 으로 복사";

					string sAlertMailStr = NBUtil.getAlertMailStr(Server.MapPath(ConfigurationSettings.AppSettings["NeBoardPath"] + "/Common/AlertMail.xml"), "/MailMsg/BoardMngMail");
            
					SqlDataReader drWriterData = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sQry);

					if (drWriterData.Read())
					{
						string sTmpContent = string.Empty;

						if (drWriterData["html_use"].ToString().Equals("1"))
						{
							sTmpContent = drWriterData["content"].ToString();
						}
						else
						{
							sTmpContent = Server.HtmlEncode (drWriterData["content"].ToString()).Replace("\r\n", "<br>");
						}
						
						drWriterData["content"].ToString();

						sAlertMailStr = sAlertMailStr.Replace("$$WRITEDAY$$", DateTime.Parse(drWriterData["write_date"].ToString()).ToString("yyyy년 MM월 dd일"));
						sAlertMailStr = sAlertMailStr.Replace("$$ACTION$$", sActionStr);
						sAlertMailStr = sAlertMailStr.Replace("$$WRITER$$", drWriterData["writer"].ToString());
						sAlertMailStr = sAlertMailStr.Replace("$$SUBJECT$$", drWriterData["subject"].ToString());
						sAlertMailStr = sAlertMailStr.Replace("$$DESC$$", "<작성 글 본문 내용> <br><br>" + sTmpContent);

						if (Request.Cookies["MBEMAIL"] != null && drWriterData["email"].ToString().Length > 0)
						{
							string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

							NBUtil.SendMail (sMngEmail, drWriterData["email"].ToString(), "", "",  
								"[" + drWriterData["subject"].ToString() + "] 제목의 글이 " + sActionStr + " 되었습니다.", sAlertMailStr, "1");
						}
					}
				}
				catch (Exception E)
				{
					throw E;
				}
				finally
				{
					DBUtil.DBConnDispose (ref dbSqlConn);
				}
			}
		}

		private void DoSendAlertMsgMove(string sIdxNo)
		{
			if (ChkAlert.Checked)
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection (ref dbSqlConn);
					string sQry = "";
					string sActionStr = "";

					sQry = "select isnull(email, '') as email, write_date, subject, writer, content, isnull(html_use, '') as html_use from NB_BoardData_" + mBoardNo + " where idx_no = " + sIdxNo;
					sActionStr = "[" + WNDdlBoardList.SelectedItem.Text + "] 게시판 으로 이동";

					string sAlertMailStr = NBUtil.getAlertMailStr(Server.MapPath(ConfigurationSettings.AppSettings["NeBoardPath"] + "/Common/AlertMail.xml"), "/MailMsg/BoardMngMail");
            
					SqlDataReader drWriterData = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sQry);

					if (drWriterData.Read())
					{
						string sTmpContent = string.Empty;

						if (drWriterData["html_use"].ToString().Equals("1"))
						{
							sTmpContent = drWriterData["content"].ToString();
						}
						else
						{
							sTmpContent = Server.HtmlEncode (drWriterData["content"].ToString()).Replace("\r\n", "<br>");
						}
						
						drWriterData["content"].ToString();

						sAlertMailStr = sAlertMailStr.Replace("$$WRITEDAY$$", DateTime.Parse(drWriterData["write_date"].ToString()).ToString("yyyy년 MM월 dd일"));
						sAlertMailStr = sAlertMailStr.Replace("$$ACTION$$", sActionStr);
						sAlertMailStr = sAlertMailStr.Replace("$$WRITER$$", drWriterData["writer"].ToString());
						sAlertMailStr = sAlertMailStr.Replace("$$SUBJECT$$", drWriterData["subject"].ToString());
						sAlertMailStr = sAlertMailStr.Replace("$$DESC$$", "<작성 글 본문 내용> <br><br>" + sTmpContent);

						if (Request.Cookies["MBEMAIL"] != null && drWriterData["email"].ToString().Length > 0)
						{
							string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

							NBUtil.SendMail (sMngEmail, drWriterData["email"].ToString(), "", "",  
								"[" + drWriterData["subject"].ToString() + "] 제목의 글이 " + sActionStr + " 되었습니다.", sAlertMailStr, "1");
						}
					}
				}
				catch (Exception E)
				{
					throw E;
				}
				finally
				{
					DBUtil.DBConnDispose (ref dbSqlConn);
				}
			}
		}

		private void DoSendAlertMsgAgree(string sIdxNo, string sAgreeType)
		{
			if (ChkAlert.Checked)
			{
				SqlConnection dbSqlConn = null;

				try
				{
					DBUtil.DBConnection (ref dbSqlConn);
					string sQry = "";
					string sActionStr = "";

					sQry = "select isnull(email, '') as email, write_date, subject, writer, content, isnull(html_use, '') as html_use from NB_BoardData_" + mBoardNo + " where idx_no = " + sIdxNo;

					if (sAgreeType == "1")
                        sActionStr = "승인 상태로 변경 ";
					else
						sActionStr = "미승인 상태로 변경 ";

					string sAlertMailStr = NBUtil.getAlertMailStr(Server.MapPath(ConfigurationSettings.AppSettings["NeBoardPath"] + "/Common/AlertMail.xml"), "/MailMsg/BoardMngMail");
            
					SqlDataReader drWriterData = SqlHelper.ExecuteReader (dbSqlConn, CommandType.Text, sQry);

					if (drWriterData.Read())
					{
						string sTmpContent = string.Empty;

						if (drWriterData["html_use"].ToString().Equals("1"))
						{
							sTmpContent = drWriterData["content"].ToString();
						}
						else
						{
							sTmpContent = Server.HtmlEncode (drWriterData["content"].ToString()).Replace("\r\n", "<br>");
						}
						
						drWriterData["content"].ToString();

						sAlertMailStr = sAlertMailStr.Replace("$$WRITEDAY$$", DateTime.Parse(drWriterData["write_date"].ToString()).ToString("yyyy년 MM월 dd일"));
						sAlertMailStr = sAlertMailStr.Replace("$$ACTION$$", sActionStr);
						sAlertMailStr = sAlertMailStr.Replace("$$WRITER$$", drWriterData["writer"].ToString());
						sAlertMailStr = sAlertMailStr.Replace("$$SUBJECT$$", drWriterData["subject"].ToString());
						sAlertMailStr = sAlertMailStr.Replace("$$DESC$$", "<작성 글 본문 내용> <br><br>" + sTmpContent);

						if (Request.Cookies["MBEMAIL"] != null && drWriterData["email"].ToString().Length > 0)
						{
							string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

							NBUtil.SendMail (sMngEmail, drWriterData["email"].ToString(), "", "",  
								"[" + drWriterData["subject"].ToString() + "] 제목의 글이 " + sActionStr + " 되었습니다.", sAlertMailStr, "1");
						}
					}
				}
				catch (Exception E)
				{
					throw E;
				}
				finally
				{
					DBUtil.DBConnDispose (ref dbSqlConn);
				}
			}
		}

		private void WNRdoMCStart_Click(object sender, System.EventArgs e)
		{
			if (WNDdlGroupList.SelectedIndex > -1 && WNDdlBoardList.SelectedIndex > -1)
			{
				string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

				if (ChkAlert.Checked && NBUtil.StrEmptyChk (sMngEmail))
				{
                    NBCmnUtil.ViewAlertMsg(Page, "관리자 메일이 설정 되어 있어야 작업 후 글쓴이에게 메일로 알림 기능이 가능 합니다.");
				}
				else
				{
					DoCopyItem (WNDdlBoardList.SelectedValue);
				}
			}
			else
			{
				NBCmnUtil.ViewAlertMsg(Page, "복사할 게시판을 선택해 주세요.");
			}
		}



		private void DoTransBoard
			(
			string sSrcBoardNo, 
			string sTarBoardNo, 
			string sIdxNo,
			string sGuestNo,
			string sWriter,
			string sCatCode,
			string sPwd,
			string sLevelNo1,
			string sLevelNo2,
			string sAgreeYN,
			string sPrivateYN,
			string sVoteYN,
			string sSumYN,
			string sSumHtmlUse,
			string sSumContent,
			string sCurrRefNo,
			string sEmail,
			string sHomePage,
			string sWriteIP,
			string sSubject,
			string sContent,
			string sChkHtml,
			string sChkAlert,
			string sChkCmmtAlert,
			string sChkNotice,
			string sLink1,
			string sLink2,
			string sVoteStart,
			string sVoteEnd,
			string sParmStartDate,
			string sParmEndData
			)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				string
					parmNewIdxNo = string.Empty,
					parmGuestNo = string.Empty,
					parmWriter = string.Empty,
					parmCatCode = string.Empty,
					parmPwd = string.Empty,
					parmAgreeYN = string.Empty,
					parmPrivateYN = string.Empty,
					parmVoteYN = string.Empty,
					parmSumYn = string.Empty,
					parmSumHtmlUse = string.Empty,
					parmSumContent = string.Empty;
				int 
					parmLevelNo1 = 0,
					parmLevelNo2 = 0;


				DBUtil.DBConnection (ref dbSqlConn);

				parmNewIdxNo = SqlHelper.ExecuteScalar(dbSqlConn, CommandType.StoredProcedure, "nbsp_get_new_idx_" + sTarBoardNo).ToString();

				
				parmGuestNo = sGuestNo;
				parmWriter = sWriter;
				parmCatCode = sCatCode;
				parmPwd = sPwd;
				parmLevelNo1 = NBUtil.ConvStrToInt (sLevelNo1);
				parmLevelNo2 = NBUtil.ConvStrToInt (sLevelNo2);
				parmAgreeYN = sAgreeYN;
				parmPrivateYN = sPrivateYN;
				parmVoteYN = sVoteYN;
				parmSumYn = sSumYN;
				parmSumHtmlUse = sSumHtmlUse;
				parmSumContent = sSumContent;
                
                
				int nTmpArrIdx = 0;
				SqlParameter[] sqlParm = new SqlParameter[32];
				sqlParm[nTmpArrIdx] = new SqlParameter("@new_idx_no", int.Parse(parmNewIdxNo));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@reply_yn", "0");
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@curr_ref_no", sCurrRefNo);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@curr_level_no2", "");
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@guest_no", parmGuestNo);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@writer", parmWriter);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@email", sEmail);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@homepage", sHomePage);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@writer_ip", sWriteIP);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@cat_code", parmCatCode);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@subject", sSubject);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@content", sContent);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@html_use", sChkHtml);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@pwd", parmPwd);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@level_no1", parmLevelNo1);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@level_no2", parmLevelNo2);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@replymail_yn", sChkAlert);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@cmmtmail_yn", sChkCmmtAlert);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@agree_yn", parmAgreeYN);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@private_yn", parmPrivateYN);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@notice_yn", sChkNotice);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@link1", sLink1);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@link2", sLink2);				
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_yn", parmVoteYN);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_start", sVoteStart);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_end", sVoteEnd);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_disp_type", "");
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@sum_yn", parmSumYn);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@sum_content", parmSumContent);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@sum_html_use", parmSumHtmlUse);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@disp_start_date", sParmStartDate);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@disp_end_date", sParmEndData);

				
				// 글쓰기 입력 데이타 INSERT
				if (SqlHelper.ExecuteNonQuery (dbSqlConn, CommandType.StoredProcedure, "nbsp_write_boarddata_" + sTarBoardNo, sqlParm) > 0)
				{
					string sFileTrans = "insert into NB_FileData_" + sTarBoardNo + " (idx_no, fidx_no, file_name, file_ext, file_down, file_size, file_desc) ";
					sFileTrans += "select " + parmNewIdxNo + ", fidx_no, file_name, file_ext, file_down, file_size, file_desc from NB_FileData_" + sSrcBoardNo + " where idx_no = '" + sIdxNo + "'";

					SqlHelper.ExecuteNonQuery (dbSqlConn, CommandType.Text, sFileTrans);
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg(Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}		
		}

		private void WNRdoMMStart_Click(object sender, System.EventArgs e)
		{
			if (WNDdlGroupList.SelectedIndex > -1 && WNDdlBoardList.SelectedIndex > -1)
			{
				string sMngEmail = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();

				if (ChkAlert.Checked && NBUtil.StrEmptyChk (sMngEmail))
				{
					NBCmnUtil.ViewAlertMsg(Page, "관리자 메일이 설정 되어 있어야 작업 후 글쓴이에게 메일로 알림 기능이 가능 합니다.");
				}
				else
				{
					DoMoveItem (WNDdlBoardList.SelectedValue);
				}
			}
			else
			{
				NBCmnUtil.ViewAlertMsg(Page, "이동할 게시판을 선택해 주세요.");
			}
		}

		
	}
}
