using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Web.UI;
using BoardLib;

namespace NeBoard.Common
{
	public struct stImgSize
	{
		public stImgSize(int dfltWidth, int dfltHeight)
		{
            this.Width = dfltWidth;
			this.Height = dfltHeight;
		}		

		public int Width;
		public int Height;
	}

	public class DrawImage : Page
	{
		private string mBoardNo = string.Empty;
		private string mImgName = string.Empty;
		private bool mThumbFlag = false;
		private int mImgWidth = 0;
		private int mImgHeight = 0;

		Image.GetThumbnailImageAbort thumbCB;
                
		private void Page_Load(object sender, EventArgs e)
		{
			thumbCB = new Image.GetThumbnailImageAbort(ThumbnailCallback);

			GetQryStr();
			
            DoDrawPic();
		}

		private void GetQryStr()
		{
			mBoardNo = NBCmnUtil.QStrLoad("bno");
			mImgName = NBCmnUtil.QStrLoad("img");
			mThumbFlag = NBUtil.ConvStrToBool(NBCmnUtil.QStrLoad("tf"));
			mImgWidth = NBUtil.ConvStrToInt(NBCmnUtil.QStrLoad("iw"));
			mImgHeight = NBUtil.ConvStrToInt(NBCmnUtil.QStrLoad("ih"));
		}

		private void DoDrawPic()
		{
			// Խ ȣ ̹ ̸  
			if (NBUtil.StrEmptyChk(mBoardNo) || NBUtil.StrEmptyChk(mImgName))
				return;

			// ̹  ü
			stImgSize ImgSize = new stImgSize(0, 0);
			// ̹   ̹ ü
			Image objImg = null;
			//  ̹  ü
			// Image objThumbImg = null;
			//  
			bool bThumbTrans = false;
			// ̹  
			string sBoardDataPath = string.Empty;
			// ̹ ü 
			string sImgFilePath = string.Empty;

			//̹  ޸𸮽Ʈ
			System.IO.MemoryStream oMemStream = null;

			
			// ̹  θ Ѵ.
			if (mBoardNo.Equals ("1000000"))
				// ȸ ̹
				sBoardDataPath = NBUtil.GetUploadRootPath() + "\\NB_MemPic";
			else
				// Խ ε ̹
				sBoardDataPath = NBUtil.GetUploadRootPath() + "\\NB_BoardData_" + mBoardNo;

			// ̹  ü 
			sImgFilePath = sBoardDataPath.Trim() + "\\" + mImgName;


			try
			{
				objImg = Image.FromFile(sImgFilePath);

				if ( mThumbFlag && (mImgWidth != 0 || mImgHeight != 0) )				
				{
					int nOrigWidth = 0;
					int nOrigHeight = 0;

                    nOrigWidth = objImg.Width;
					nOrigHeight = objImg.Height;

					if (mImgWidth > 0 && mImgHeight > 0)
					{
						// Ѵ ũⰡ Ǿ     Ѵ.
						ImgSize.Width = mImgWidth;
						ImgSize.Height = mImgHeight;

						bThumbTrans = true;
					}
					else if (mImgWidth > 0 && mImgHeight == 0)
					{
						//  ũ⸸ Ѿ 

						if (mImgWidth < objImg.Width)
						{
							//   ũⰡ  ̹ ũ⺸ 
							// ũ ڵ 缭 ̹ ũ⸦  Ѵ.
							ImgSize.Width = mImgWidth;
							ImgSize.Height = GetRatioHeight (nOrigWidth, nOrigHeight, mImgWidth);

							bThumbTrans = true;
						}
					}
					else if (mImgWidth == 0 && mImgHeight > 0)
					{
						//  ũ⸸ Ѿ  

						if (mImgHeight < objImg.Height)
						{
							//   ũⰡ  ̹ ũ⺸ 
							//  ũ ڵ 缭 ̹ ũ⸦  Ѵ.                            
							ImgSize.Width = GetRatioHeight (nOrigWidth, nOrigHeight, mImgHeight);
							ImgSize.Height = mImgHeight;

							bThumbTrans = true;
						}
					}
					else
					{
						return;
					}
				}


				// ContentType 
				Response.ContentType = "Image/" + GetImageFormat(sImgFilePath);
				Response.AddHeader ("Content-Disposition", "attachment;filename=" + Server.UrlPathEncode(mImgName));


				//̹  ޸𸮽Ʈ
				oMemStream = new System.IO.MemoryStream();

				if (bThumbTrans)
				{
					Bitmap imgTmp = new Bitmap(objImg, ImgSize.Width, ImgSize.Height);
					imgTmp.Save (oMemStream, objImg.RawFormat);

					imgTmp.Dispose();
					objImg.Dispose();
				}
				else
				{
					objImg.Save(oMemStream, objImg.RawFormat);

					objImg.Dispose();
				}

				Response.BinaryWrite(oMemStream.ToArray());
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				if (objImg != null)
                    objImg.Dispose();				
				
				oMemStream = null;
			}
		}

		private ImageCodecInfo GetEncoderInfo(string mimeType)
		{
			ImageCodecInfo[] imgEncInfo = ImageCodecInfo.GetImageEncoders();
			
			for(int nCnt = 0; nCnt < imgEncInfo.Length; ++nCnt)
			{
				if(imgEncInfo[nCnt].MimeType == mimeType)
				{
					return imgEncInfo[nCnt];
				}
			}
			return null;
		}

		public bool ThumbnailCallback()
		{
			return false;
		}

		private string GetImageFormat(string sFilePath)
		{
			string sResult = string.Empty;
            string sFExt = Path.GetExtension (sFilePath);

			switch (sFExt.ToUpper())
			{
				case ".JPG":
				case ".JPEG":
					sResult = "JPEG";
					break;
				case ".GIF":
					sResult = "GIF";
					break;
				case ".PNG":
					sResult = "PNG";
					break;
				default:
					sResult = "PNG";
					break;                    
			}

			return sResult;
		}

		private int GetRatioWidth(int nOrigWidth, int OrigHeight, int nHeight)
		{
			int nSize = Convert.ToInt32(Math.Round(Convert.ToDouble(nHeight) / Convert.ToDouble(OrigHeight) * Convert.ToDouble(nOrigWidth), 0));
			return nSize;
		}

		private int GetRatioHeight(int nOrigWidth, int OrigHeight, int nWidth)
		{
			int nSize = Convert.ToInt32(Math.Round(Convert.ToDouble(nWidth) / Convert.ToDouble(nOrigWidth) * Convert.ToDouble(OrigHeight), 0));
            return nSize;
		}

		#region Web Form ̳ʿ  ڵ
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN:  ȣ ASP.NET Web Form ̳ʿ ʿմϴ.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// ̳  ʿ ޼Դϴ.
		///  ޼  ڵ   ʽÿ.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Load += new EventHandler(this.Page_Load);
		}
		#endregion
	}
}
