﻿using System;
using System.Configuration;
using System.Text;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using BoardLib;

namespace NeBoard
{
	public abstract class BoardList : UserControl
	{
		#region 페이지에서 사용하는 컨트롤 선언
		// 페이지 컨트롤
		protected HyperLink lnk_HomeBtn;
		protected HyperLink lnk_AdminBtn;
		protected HyperLink lnk_LoginBtn;
		protected HyperLink lnk_LogoutBtn;
		protected HyperLink lnk_SignupBtn;
		protected HyperLink lnk_MyinfoBtn;
		protected HyperLink lnk_MemoBoxBtn;
		protected HyperLink lnk_WriteBtn;
		protected HyperLink lnk_GoListBtn;
		protected HyperLink lnk_Admutil;
		protected HyperLink lnk_RssLnk;
		protected HyperLink lnk_MuAllSelect;
		protected HyperLink lnk_MuAllClear;
		protected HyperLink lnk_MuSelListen;
		protected HyperLink lnk_MuRndListen;
		protected Literal WNLtrPaging;
		protected Literal ltr_BoardListBind;
		protected HtmlTable HTTblOuterTable;
		protected DropDownList WNDdlCatList;
		protected DropDownList WNDdlTransBoard;
		// 페이지 설정 구조체 선언
		public NBLib.PageQryStr mPageQryInfo;
		public NBLib.CurBoardCfg mBoardCfg;
		// 검색 관련 바인딩 문자
		public string
			NB_NameOpt_ChkState,
            NB_SubjectOpt_ChkState,
            NB_ContentOpt_ChkState,
            NB_SearchText,
			NB_SearchUrl;
        // 게시판 바인딩 문자
		public string 
			BoardTitleContent,
			NBTotalRecordCount,
			NBCurrPageNum,
			NBTotalPageNum;
		// DB 관련 작업 처리
		private data_proc do_data_proc;

		#endregion

		public string
			gBoardNo,					// 게시판 코드
			gViewMode;					// 게시판 작동 모드

		public string BoardNo
		{
			set
			{
				gBoardNo = value;
			}

			get
			{
				return gBoardNo;
			}
		}

		public string ViewMode
		{
			set
			{
				gViewMode = value;
			}

			get
			{
				return gViewMode;
			}
		}

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				do_init_set();
			}
			catch(Exception E)
			{
				Response.Clear();
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
                do_data_proc.Dispose();
			}
		}

		
		/// <summary>
		/// 초기 설정 및 기본 데이타 세팅
		/// </summary>
		private void do_init_set()
		{
			try
			{
				// 전역 데이타 로드
				if ( nb_utils.GetGlobalValue (ref mPageQryInfo, ref mBoardCfg, gBoardNo, gViewMode) )
				{
					do_data_proc = new data_proc(mPageQryInfo.sBoardNo);

					// 게시판 타이틀 설정
					NBUtil.SetDisplayType(ref BoardTitleContent, mBoardCfg.bnd_boardtitle_view, mBoardCfg.bnd_boardtitle_cont.Replace("[BRD_NAME]", mBoardCfg.bnc_board_name));

					// 검색에 사용되는 URL을 설정
					if (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.SearchBoard))
                        NB_SearchUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "LIST", "1", "1", "##ST##", "##SO##", "", "", mPageQryInfo.sCatName);

					// 검색 선택 옵션에 따라 검색 필드의 옵션을 설정
					NBUtil.SetSearchStatus (mPageQryInfo, ref NB_NameOpt_ChkState, ref NB_SubjectOpt_ChkState, ref NB_ContentOpt_ChkState, ref NB_SearchText);

					// 같은 그룹에 다른 게시판이 있을경우 게시판 리스트를 바인딩
					do_data_proc.SetOtherBoardList (mPageQryInfo.sBoardNo, ref WNDdlTransBoard);

					// 버튼의 표시 여부를 설정 한다.
					set_pagebutton ();

					// 가장 외곽 테이블 디자인 세팅
					NBUtil.SetBoardListTblCfg(mBoardCfg, HTTblOuterTable);

					// 카테고리 항목 바인드
					NBUtil.SetCatListBind (mPageQryInfo.sBoardNo, mBoardCfg.bnc_category_use, ref WNDdlCatList, mPageQryInfo) ;

					// 리스트 보기 설정이 정상이면 게시판 리스트를 표시
					if (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.ViewList))
						BoardListBind();

					Page.DataBind();
				}
			}
			catch (Exception E)
			{
				throw E;
			}
		}

		
		/// <summary>
		/// 페이지 버튼 설정
		/// </summary>
		private void set_pagebutton()
		{
			//-- 버튼의 링크 설정
			if ( NBUtil.StrEmptyChk(lnk_AdminBtn.NavigateUrl) )
			{
				lnk_AdminBtn.Attributes["onclick"] = "BoardList_Admin('" + ConfigurationSettings.AppSettings["NeAdminPath"] + "/Default.aspx" + "', '" + mPageQryInfo.sBoardNo + "');";
			}

			if ( NBUtil.StrEmptyChk(lnk_MemoBoxBtn.NavigateUrl) )
				lnk_MemoBoxBtn.NavigateUrl = "javascript:BoardList_Memobox();";

			if ( NBUtil.StrEmptyChk(lnk_HomeBtn.NavigateUrl) )
				lnk_HomeBtn.NavigateUrl = mBoardCfg.bnc_homebtn_url;

			if ( NBUtil.StrEmptyChk(lnk_GoListBtn.NavigateUrl) )
				lnk_GoListBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "LIST");

			if ( NBUtil.StrEmptyChk(lnk_WriteBtn.NavigateUrl) )
				lnk_WriteBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "WRITE", mPageQryInfo, "");

			if ( NBUtil.StrEmptyChk(lnk_LoginBtn.NavigateUrl) )
				lnk_LoginBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "LOGIN", mPageQryInfo);

			if ( NBUtil.StrEmptyChk(lnk_LogoutBtn.NavigateUrl) )
				lnk_LogoutBtn.NavigateUrl = "javascript:NBLogoutProc();";

			if ( NBUtil.StrEmptyChk(lnk_MyinfoBtn.NavigateUrl) )
				lnk_MyinfoBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "MYINFO", mPageQryInfo);

			if ( NBUtil.StrEmptyChk(lnk_SignupBtn.NavigateUrl) )
				lnk_SignupBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "JOIN", mPageQryInfo);

			if ( NBUtil.StrEmptyChk(lnk_Admutil.NavigateUrl) )
				lnk_Admutil.NavigateUrl = "javascript:NB_GetChk('" + mPageQryInfo.sBoardNo + "');";

			if ( NBUtil.StrEmptyChk(lnk_RssLnk.NavigateUrl) )
				lnk_RssLnk.NavigateUrl = ConfigurationSettings.AppSettings["NeBoardPath"] + "/Common/BoardRss.aspx?bno=" + mPageQryInfo.sBoardNo;

			// 음악 게시판 버튼 NavigateUrl 설정
			if (NBUtil.isUseChk (mBoardCfg.bnc_musicboard_use))
			{
				if (lnk_MuSelListen != null)
                    lnk_MuSelListen.NavigateUrl = "javascript:NBMusicPlayer(escape('" + mBoardCfg.bnc_musicplayer_skin + "'), '" + mPageQryInfo.sBoardNo + "', false);";
				if (lnk_MuRndListen != null)
                    lnk_MuRndListen.NavigateUrl = "javascript:NBMusicPlayer(escape('" + mBoardCfg.bnc_musicplayer_skin + "'), '" + mPageQryInfo.sBoardNo + "', false);";
			}				


			//-- 버튼의 표시 여부 결정
			NBLib.PageBtnView stBtnView = NBUtil.GetBtnViewSet (mBoardCfg) ;

			lnk_HomeBtn.Visible = stBtnView.home_btn;
			lnk_WriteBtn.Visible = stBtnView.write_btn;
			lnk_AdminBtn.Visible = stBtnView.admin_btn;
			lnk_LoginBtn.Visible = stBtnView.login_btn;
			lnk_LogoutBtn.Visible = stBtnView.logout_btn;
			lnk_SignupBtn.Visible = stBtnView.signup_btn;
			lnk_MyinfoBtn.Visible = stBtnView.myinfo_btn;
			lnk_MemoBoxBtn.Visible = stBtnView.memo_box;
			lnk_RssLnk.Visible = stBtnView.rss_btn;

			// 음악 게시판 관련 버튼
			if (lnk_MuAllSelect != null)
                lnk_MuAllSelect.Visible = stBtnView.listen_btn;
			if (lnk_MuAllClear != null)
                lnk_MuAllClear.Visible = stBtnView.listen_btn;
			if (lnk_MuSelListen != null)
                lnk_MuSelListen.Visible = stBtnView.listen_btn;
			if (lnk_MuRndListen != null)
                lnk_MuRndListen.Visible = stBtnView.listen_btn;

			if (NBUtil.isAdminLogin(mBoardCfg.bps_level_info)) lnk_Admutil.Visible = true;
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다.
		///		이 메서드의 내용을 코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.Load += new EventHandler(this.Page_Load);
		}
		#endregion

		/// <summary>
		/// 게시판 리스트 바인딩
		/// </summary>
		private void BoardListBind()
		{
			try
			{
				StringBuilder sbListDesignTxt = new StringBuilder();
                
				bool bResult = NBUtil.BoardListBind(ref sbListDesignTxt, mPageQryInfo.sBoardNo, mBoardCfg, mPageQryInfo);

				ltr_BoardListBind.Text = sbListDesignTxt.ToString();

				if ( bResult )
				{
					// 게시판 페이징
					WNLtrPaging.Text = NBUtil.GetPagingStr(mPageQryInfo.sBoardNo, mBoardCfg, mPageQryInfo, ref NBTotalRecordCount, ref NBCurrPageNum, ref NBTotalPageNum);
				}
				else
				{
					WNLtrPaging.Text = "&nbsp;";
				}
			}
			catch(Exception E)
			{
				throw E;
			}
		}
	}
}
