﻿using System;
using System.Configuration;
using System.Collections;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using BoardLib;
using System.Xml;

namespace NeBoard
{
	public abstract class BoardView : UserControl
	{
		#region Controls
		protected HyperLink lnk_HomeBtn;
		protected HyperLink lnk_AdminBtn;
		protected HyperLink lnk_LoginBtn;
		protected HyperLink lnk_LogoutBtn;
		protected HyperLink lnk_SignupBtn;
		protected HyperLink lnk_MyinfoBtn;
		protected HyperLink lnk_MemoBoxBtn;
		protected HyperLink lnk_WriteBtn;
		protected HyperLink lnk_GoListBtn;
		protected HyperLink lnk_Admutil;
		protected HyperLink lnk_RssLnk;
		protected HyperLink lnk_ReplyBtn;
		protected HyperLink lnk_ModifyBtn;
		protected HyperLink lnk_DeleteBtn;

        protected Literal ltr_CmmtListBind;
		protected Label WNLblReadCnt;
		protected Label WNLblVoteCnt;
		protected Label WNLblWriteday;
		protected Label WNLblIpAddress;
		protected ImageButton WBImgVote;
		protected HtmlTable HTTblOuterTable;
		protected Label WNLblSubject;
		protected Label WNLblName;
		protected Label WNLblEmail;
		protected Label WNLblLink1;
		protected Label WNLblLink2;
		protected HtmlTableRow HTTrFile;
		protected HtmlTableRow HTTrLink1;
		protected HtmlTableRow HTTrLink2;
		protected Label WNLblHomepg;
		protected HtmlTableRow HTTrHomepg;
		protected Label WNLblContent;
		protected HtmlTable HTTblPrevCont;
		protected HtmlTableCell HTTdPrevCont;
		protected HtmlTable HTTblNextCont;
		protected HtmlTableRow HTTrNextCont;
		protected HtmlTableCell HTTdNextCont;
		protected HtmlTableRow HTTrOuterBoardList;	
		protected HtmlTableRow HTTrOuterCmtList;
		protected HtmlTableRow HTTrOuterCmtWrite;
		protected HtmlTable HTTblBoardList;
		protected Literal WNLtrPaging;
		protected HtmlTable HTTblPaging;
		protected HtmlTable HTTblCmtTable;
		protected HtmlTableCell HTTdUpFile;
		
		protected TextBox WNTxtCmtContent;
		protected TextBox WNTxtCmtName;
		protected TextBox WNTxtCmtPwd;
		protected HtmlImage HTCmtPassImg;

		protected ImageButton WBImgCmtOk;
		protected Label WNLblCmtMbName;

		protected Literal ltr_BoardListBind;

		public NBLib.PageQryStr mPageQryInfo;	// QueryString으로 넘어온 결과 로드

		public NBLib.CurBoardCfg mBoardCfg;

		public string BoardTitleContent;
		public string MemSignImg;
		public string MusicPlayFile;
		public string MusicPlayDesc;

		public BoardQryLib QryLib;

		protected bool chkPass = false;

		// DB 관련 작업 처리
		private data_proc do_data_proc;

		#endregion

		public string
			gBoardNo,					// 게시판 코드
			gViewMode;					// 게시판 작동 모드

		public string BoardNo
		{
			set
			{
				gBoardNo = value;
			}

			get
			{
				return gBoardNo;
			}
		}

		public string ViewMode
		{
			set
			{
				gViewMode = value;
			}

			get
			{
				return gViewMode;
			}
		}

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				do_init_set();
			}
			catch(Exception E)
			{
				Response.Clear();
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				do_data_proc.Dispose();
			}
		}

		/// <summary>
		/// 초기 설정 적용
		/// </summary>
		private void do_init_set()
		{
			try
			{
				// 전역 데이타 로드
				if ( nb_utils.GetGlobalValue (ref mPageQryInfo, ref mBoardCfg, gBoardNo, gViewMode) )
				{
					do_data_proc = new data_proc(mPageQryInfo.sBoardNo);
					
					QryLib = new BoardQryLib(mPageQryInfo.sBoardNo);

					// 게시판 타이틀 설정
					NBUtil.SetDisplayType(ref BoardTitleContent, mBoardCfg.bnd_boardtitle_view, mBoardCfg.bnd_boardtitle_cont.Replace("[BRD_NAME]", mBoardCfg.bnc_board_name));

					// 글 보기 권한이 있는지 체크
					if ( !chk_contview_allow() )
					{
						NBCmnUtil.ViewMsgGoUrl (Page, NBUtil.GetBoardTransLink(mPageQryInfo.sBoardNo, "LIST"), "글보기 권한이 없거나 올바른 글 번호가 아닙니다.");
					}
					else
					{

						// 비밀글 체크
						if(!IsPostBack)
						{
							if( NBUtil.isUseChk(mBoardCfg.bnc_private_use) && !chkPass)
							{
								if(!chk_private())
								{
									// 비밀글 인증이 안된 상태라면 비밀글 인증 페이지로 이동
									string sRequestQry = Request.Url.Query;
									Response.Redirect("Common/PrivateWin.aspx" + sRequestQry, false);
									return;
								}
								else
								{
									chkPass = true;
								}
							}
						}

						// 버튼의 표시 여부를 설정 한다.
						set_pagebutton();			

						set_page_display();

						BoardDataBind();

						if (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.ViewCmmt))
                            CmmtBind();

						NBUtil.SetBoardListTblCfg (mBoardCfg, HTTblOuterTable);
					}
				}
			}
			catch(Exception E)
			{
				throw E;
			}				
		}

		/// <summary>
		/// 글보기 허용 가능한 상태인지 검사
		/// </summary>
		/// <returns></returns>
		private bool chk_contview_allow()
		{
			bool bResult = false;
			
			if ( NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.ViewContent) )
			{
                if ( !NBUtil.StrEmptyChk(mPageQryInfo.sBoardNo) && !NBUtil.StrEmptyChk(mPageQryInfo.sIdxNo) )
					bResult = true;
			}

			return bResult;
		}
		
		/// <summary>
		/// 비밀글 여부를 체크하고 비밀글일 경우 올바른 인증을 거치고 접속했는지 검사
		/// </summary>
		/// <returns></returns>
		private bool chk_private()
		{
			SqlConnection dbSqlConn = null;

			bool bResult = false;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				string sPrivateYN = SqlHelper.ExecuteScalar (dbSqlConn, CommandType.StoredProcedure, "nbsp_chk_private_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", mPageQryInfo.sIdxNo)).ToString();

				if( NBUtil.isUseChk(sPrivateYN) )
				{
					if(NBUtil.isAdminLogin(mBoardCfg.bps_level_info))
					{
						bResult = true;
					}
					else
					{
						if(Request.UrlReferrer != null)
						{
							string[] aRefs= Request.UrlReferrer.AbsoluteUri.Split('/');
							string sRef = aRefs[aRefs.Length - 1];

							if(sRef.ToUpper().StartsWith(NBLib.PrivateAllowURL))
								return true;
						}
					}
				}
				else
				{
					bResult = true;
				}
			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}

			return bResult;
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다.
		///		이 메서드의 내용을 코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.WBImgVote.Click += new ImageClickEventHandler(this.WBImgVote_Click);
			this.WBImgCmtOk.Click += new ImageClickEventHandler(this.WBImgCmtOk_Click);
			this.Load += new EventHandler(this.Page_Load);

		}
		#endregion

		/// <summary>
		/// 페이지 버튼 설정
		/// </summary>
		private void set_pagebutton()
		{
			//-- 버튼의 링크 설정
			if ( NBUtil.StrEmptyChk(lnk_AdminBtn.NavigateUrl) )
			{
				lnk_AdminBtn.Attributes["onclick"] = "BoardList_Admin('" + ConfigurationSettings.AppSettings["NeAdminPath"] + "/Default.aspx" + "', '" + mPageQryInfo.sBoardNo + "');";
			}

			if ( lnk_MemoBoxBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_MemoBoxBtn.NavigateUrl = "javascript:BoardList_Memobox()";

			if ( lnk_HomeBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_HomeBtn.NavigateUrl = mBoardCfg.bnc_homebtn_url;

			if ( lnk_GoListBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_GoListBtn.NavigateUrl = NBUtil.GetBoardTransLink_WithCat (mPageQryInfo.sBoardNo, mPageQryInfo.sCatName, mPageQryInfo);

			if ( lnk_WriteBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_WriteBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "WRITE", mPageQryInfo, "");

			if ( lnk_LoginBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_LoginBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "LOGIN", mPageQryInfo);

			if ( lnk_LogoutBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_LogoutBtn.NavigateUrl = "javascript:NBLogoutProc();";

			if ( lnk_MyinfoBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_MyinfoBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "MYINFO", mPageQryInfo);

			if ( lnk_SignupBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_SignupBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "JOIN", mPageQryInfo);

			if ( lnk_ReplyBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_ReplyBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "WRITE", mPageQryInfo.nGoPage.ToString(), NBUtil.ConvBoolToStr(mPageQryInfo.bSearchYN), mPageQryInfo.sSearchTxt, mPageQryInfo.nSearchOpt.ToString(), mPageQryInfo.sIdxNo, "1", mPageQryInfo.sCatName);

			if ( lnk_ModifyBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_ModifyBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "MODIFY", mPageQryInfo, mPageQryInfo.sIdxNo);

			if ( lnk_DeleteBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_DeleteBtn.NavigateUrl = "javascript:BoardView_Delete('" + NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "DELETE", mPageQryInfo, mPageQryInfo.sIdxNo) + "');";


			//-- 버튼의 표시 여부 결정
			NBLib.PageBtnView stBtnView = NBUtil.GetBtnViewSet (mBoardCfg) ;

			lnk_HomeBtn.Visible = stBtnView.home_btn;
			lnk_WriteBtn.Visible = stBtnView.write_btn;
			lnk_ModifyBtn.Visible = stBtnView.write_btn;
			lnk_AdminBtn.Visible = stBtnView.admin_btn;
			lnk_LoginBtn.Visible = stBtnView.login_btn;
			lnk_LogoutBtn.Visible = stBtnView.logout_btn;
			lnk_SignupBtn.Visible = stBtnView.signup_btn;
			lnk_MyinfoBtn.Visible = stBtnView.myinfo_btn;
			lnk_MemoBoxBtn.Visible = stBtnView.memo_box;
			lnk_ReplyBtn.Visible = stBtnView.replay_btn;
			lnk_DeleteBtn.Visible = stBtnView.delete_btn;

			//코멘트 박스 설정
			if (NBUtil.isLogin())
			{
				WNLblCmtMbName.Visible = true;
				WNLblCmtMbName.Text = "<b>" + Server.UrlDecode(Request.Cookies["MBNAME"].Value) + "</b>";//쿠키 디코딩 추가(2005.04.04)
			}

			WBImgCmtOk.Attributes.Add("onclick","return NB_Cmt_Ok()");
		}

		/// <summary>
		/// 페이지 보기 설정에 따라 설정을 한다.
		/// </summary>
		private void set_page_display()
		{
			bool bEmailDisp = false,		//이메일
				bReadCntDisp = false,		//조회수
				bVoteCntDisp = false,		//추천수
				bWritedayDisp = false,		//작성일
				bIpAddressDisp = false,		//IP
				bHomePageDisp = false;		//HomePage

			int nViewUseFlag = 0;

			
			if (NBUtil.isAdminLogin(mBoardCfg.bps_level_info))
			// 관리자 로그인 상태일때
			{
				nViewUseFlag = NBLib.ViewModeBit.AdminViewUseFlag;
			}
			// 일반 사용자 상태 일때 (비회원 포함)
			else
			{
                nViewUseFlag = NBLib.ViewModeBit.NormViewUseFlag;				
			}

			if (NBCmnUtil.ChkBitFlag (mBoardCfg.bnc_email_use, nViewUseFlag))
				bEmailDisp = true;

			if (NBCmnUtil.ChkBitFlag (mBoardCfg.bnc_hit_use, nViewUseFlag))
				bReadCntDisp = true;

			if (NBCmnUtil.ChkBitFlag (mBoardCfg.bnc_good_use, nViewUseFlag) && NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.GoodUse) && !NBUtil.isVoted(mPageQryInfo.sIdxNo))
				bVoteCntDisp = true;

			if (NBCmnUtil.ChkBitFlag (mBoardCfg.bnc_wdate_use, nViewUseFlag))
				bWritedayDisp = true;

			if (NBCmnUtil.ChkBitFlag (mBoardCfg.bnc_ip_use, nViewUseFlag))
				bIpAddressDisp = true;

			if (NBCmnUtil.ChkBitFlag (mBoardCfg.bnc_homepage_use, nViewUseFlag))
				bHomePageDisp = true;

			if (NBCmnUtil.ChkBitFlag (mBoardCfg.bnc_homepage_use, nViewUseFlag))
				bHomePageDisp = true;


			WBImgVote.Visible = bVoteCntDisp;
			HTTrHomepg.Visible = bHomePageDisp;
			WNLblEmail.Visible = bEmailDisp;
			WNLblReadCnt.Visible = bReadCntDisp;
			WNLblVoteCnt.Visible = bVoteCntDisp;
			WNLblWriteday.Visible = bWritedayDisp;
			WNLblIpAddress.Visible = bIpAddressDisp;

			if (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.CmmtWrite) && NBUtil.isUseChk(mBoardCfg.bnc_cmmt_use) )
			{
				HTTrOuterCmtWrite.Visible = true;				

				if (NBUtil.isLogin())
				{
                    WNLblCmtMbName.Visible = true;
					WNTxtCmtName.Visible = false;
					WNTxtCmtPwd.Visible = false;
					HTCmtPassImg.Visible = false;
				}
				else
				{
					WNLblCmtMbName.Visible = false;
					WNTxtCmtName.Visible = true;
					WNTxtCmtPwd.Visible = true;
					HTCmtPassImg.Visible = true;
				}
			}
			else
			{
                HTTrOuterCmtWrite.Visible = false;
			}
		}

		private void BoardDataBind()
		{
			SqlConnection dbSqlConn = null;

			try
			{
                DBUtil.DBConnection (ref dbSqlConn);

				string sDoHitCnt = string.Empty;

				if (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.ReadCntUse))
				{
					if ( !NBUtil.isVisitCounted(gBoardNo, mPageQryInfo.sIdxNo) )
						sDoHitCnt = "1";
				}

				SqlParameter[] sqlParm = new SqlParameter[2];
				sqlParm[0] = new SqlParameter ("@idx_no", SqlDbType.Int);
				sqlParm[0].Value = int.Parse(mPageQryInfo.sIdxNo);

				sqlParm[1] = new SqlParameter("@hit_update", SqlDbType.Char, 1);
				sqlParm[1].Value = sDoHitCnt;

				SqlDataReader drReadContent = SqlHelper.ExecuteReader (dbSqlConn, CommandType.StoredProcedure, "nbsp_view_boarddata_" + mPageQryInfo.sBoardNo, sqlParm);

				if (drReadContent.Read())
				{
					if (drReadContent["level_no1"].ToString() != "0")
					{
						if (!NBUtil.chkLvlRole(mBoardCfg.bps_level_info, NBLib.UserLvlRole.ViewReply))
						{
							NBCmnUtil.ViewMsgGoBack (Page, "답변글을 읽을 권한이 없습니다.");
                            return;
						}
					}

					WNLblReadCnt.Text = "&nbsp;&nbsp;Read : " + drReadContent["hit_cnt"].ToString();
					WNLblVoteCnt.Text = "&nbsp;&nbsp;Good : " + drReadContent["good_cnt"].ToString();
					WNLblWriteday.Text = "&nbsp;&nbsp;Date : " + DateTime.Parse(drReadContent["write_date"].ToString()).ToString("yyyy-MM-dd(ddd) HH:mm:ss");
					WNLblIpAddress.Text = "&nbsp;&nbsp;IP : " + get_ip_hid(drReadContent["writer_ip"].ToString());

					bool bVoteYn = NBUtil.ConvStrToBool(drReadContent["vote_yn"].ToString());

					// -- 제목 표시
					string sSubject = "";

					if (mBoardCfg.bnc_category_use.CompareTo("1") == 0 && !NBUtil.StrEmptyChk(drReadContent["cat_name"].ToString()))
					{
						sSubject = "[" + drReadContent["cat_name"].ToString() + "] ";
					}

					sSubject += DoEncDisplayText (drReadContent["subject"].ToString(), false, false);

					WNLblSubject.Text = sSubject;
					
					// -- 이메일 표시
					if (drReadContent["email"].ToString() != "")
						WNLblEmail.Text = "[" + "<a href=\"mailto:" + drReadContent["email"].ToString() + "\">" + drReadContent["email"].ToString() + "</a>]";


					// -- 글쓴이 표시
					if (NBUtil.isUseChk(mBoardCfg.bgc_mempic_use) && !NBUtil.StrEmptyChk(drReadContent["mempic_name"].ToString()))
					{
						WNLblName.Text = "<img src=\"Common/DrawImage.aspx?bno=1000000&img=" + Server.UrlEncode(drReadContent["mempic_name"].ToString()) + "&tf=0&iw=0&ih=0\" align=\"absmiddle\" border=\"0\">";
					}
					else
					{
						// bool bWriterWithID_Use = (int.Parse(mBoardCfg.bnc_writer_with_id) & NBLib.ViewModeBit.ListViewFlag) == NBLib.ViewModeBit.ListViewFlag;

						bool bWriterWithID_Use = false;

						if (NBUtil.isAdminLogin (mBoardCfg.bps_level_info))
						{
							bWriterWithID_Use = (NBUtil.ConvStrToInt (mBoardCfg.bnc_writer_with_id) & NBLib.ViewModeBit.AdminViewUseFlag) == NBLib.ViewModeBit.AdminViewUseFlag;
						}
						else
						{
							bWriterWithID_Use = (NBUtil.ConvStrToInt (mBoardCfg.bnc_writer_with_id) & NBLib.ViewModeBit.NormViewUseFlag) == NBLib.ViewModeBit.NormViewUseFlag;
						}
						

						// -- 글쓴이 표시
						if (!NBUtil.StrEmptyChk (drReadContent["guest_no"].ToString()))
						{
							string sWriterName = string.Empty;

							if(!NBUtil.StrEmptyChk (drReadContent["nick_name"].ToString()))
							{
								sWriterName = drReadContent["nick_name"].ToString();
							}
							else
							{
								sWriterName = drReadContent["mem_name"].ToString();
							}

							if (bWriterWithID_Use)
							{
								sWriterName += " [" + drReadContent["mem_id"].ToString() + "]";
							}

							WNLblName.Text = DoEncDisplayText(sWriterName, false, false);
						}
						else
						{
							WNLblName.Text = DoEncDisplayText(drReadContent["writer"].ToString(), false, false);
						}
					}


					if (WNLblName.Text.Length > 0)
					{
						string sScriptParm = string.Empty;

						sScriptParm = "'" + mPageQryInfo.sBoardNo + "', ";

						if (!NBUtil.StrEmptyChk (drReadContent["writer"].ToString()))
							sScriptParm += "'" + drReadContent["writer"].ToString() + "', ";
						else
							sScriptParm += "'', ";

						if (NBUtil.isLogin() && !NBUtil.StrEmptyChk (drReadContent["guest_no"].ToString()))
							sScriptParm += "'" + drReadContent["guest_no"].ToString() + "', ";
						else
							sScriptParm += "'', ";

						if (!NBUtil.StrEmptyChk (drReadContent["email"].ToString()))
							sScriptParm += "'" + drReadContent["email"].ToString() + "'";
						else
							sScriptParm += "'' ";


						WNLblName.Text = "<a href=\"javascript:void(0);\" onclick=\"viewNamePopUp(" + sScriptParm + ");\">" + WNLblName.Text + "</a>";
                        
					}


					// -- 홈페이지 표시
					if (drReadContent["homepage"].ToString() != "")
					{
						string sTmpHomepg = drReadContent["homepage"].ToString().ToLower().Replace("http://","");						
						WNLblHomepg.Text = "<a href=\"http://" + sTmpHomepg + "\" target=\"_blank\">http://" + sTmpHomepg + "</a>";
					}
					else
					{
						HTTrHomepg.Visible = false;
					}


					string sLinkUrl = string.Empty;

					// -- 링크1 표시
					if (drReadContent["link1"].ToString() != "")
					{
						sLinkUrl = drReadContent["link1"].ToString();

						if (!sLinkUrl.ToUpper().StartsWith ("HTTP://"))
						{
							sLinkUrl = "http://" + Server.HtmlEncode(sLinkUrl);
						}

						WNLblLink1.Text = "<a href=\"" + sLinkUrl + "\" target='_blank'>" + Server.HtmlEncode(drReadContent["link1"].ToString()) + "</a>";
					}
					else
					{
						HTTrLink1.Visible = false;
					}

					// -- 링크2 표시
					if (drReadContent["link2"].ToString() != "")
					{
						sLinkUrl = drReadContent["link2"].ToString();

						if (!sLinkUrl.ToUpper().StartsWith ("HTTP://"))
						{
							sLinkUrl = "http://" + Server.HtmlEncode(sLinkUrl);
						}

						WNLblLink2.Text = "<a href=\"" + sLinkUrl + "\" target='_blank'>" + Server.HtmlEncode(drReadContent["link2"].ToString()) + "</a>";
					}
					else
					{
						HTTrLink2.Visible = false;
					}


					// -- 내용 표시
					string sTmpContent = drReadContent["content"].ToString();

					if ( !NBUtil.StrEmptyChk(sTmpContent) )
					{
						sTmpContent = DoEncDisplayText(sTmpContent.Trim(), NBUtil.ConvStrToBool(drReadContent["html_use"].ToString()), bVoteYn);

						if (NBUtil.isUseChk(mBoardCfg.bnc_voteboard_use) && bVoteYn)
						{
                            // 투표 게시물이면 투표 항목을 표시 하고 투표 진행 버튼 표시
							StringReader sSrcCont = new StringReader(drReadContent["content"].ToString());
							XmlTextReader xmlRead = new XmlTextReader(sSrcCont);
							xmlRead.WhitespaceHandling = WhitespaceHandling.None;


							
							StringWriter swItem = new StringWriter();
							string sRdoTag = "<input type=\"radio\" name=\"NBVoteItemSelect\" id=\"NBVoteItemSelect_#ID#\" value=\"#ID#\">";
							
							string sVoteGraph = "<table width=\"100%\" height=\"10\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\">";
							sVoteGraph += "<tr>";
							sVoteGraph += "<td width=\"15\">";
							sVoteGraph += "</td>";
                            sVoteGraph += "<td>";
							sVoteGraph += "<table width=\"[GRAPH_WIDTH]%\" height=\"100%\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\">";
							sVoteGraph += "<tr>";
							sVoteGraph += "<td class=\"nb_vote_graph\"><img src=\"Common/Images/spare.gif\" border=\"0\" width=\"1\" height=\"1\"></td>";
							sVoteGraph += "</tr>";
							sVoteGraph += "</table>";
							sVoteGraph += "</td>";
							sVoteGraph += "<td width=\"100\" class=\"nb_vote_text\">[GRAPH_WIDTH]% ([GRAPH_COUNT]명)</td>";
							sVoteGraph += "</tr>";
                            sVoteGraph += "</table>";

							ArrayList arrVoteItem = new ArrayList();
							string[] VoteItem = null;
							string sItemCont = string.Empty;
							int nItemSumCount = 0;
							
							int nTmpCnt = 0;

							while (xmlRead.Read())
							{
								if (xmlRead.LocalName.Equals("item"))
								{
									VoteItem = new string[2];

                                    VoteItem[1] = xmlRead.GetAttribute("count");

									nItemSumCount += NBUtil.ConvStrToInt(xmlRead.GetAttribute("count"));
									sItemCont = xmlRead.ReadString();									
									
									if (DateTime.Now.ToString("yyyy-MM-dd").CompareTo(drReadContent["vote_start"].ToString()) >= 0 && DateTime.Now.ToString("yyyy-MM-dd").CompareTo(drReadContent["vote_end"].ToString()) <= 0)
										VoteItem[0] = sRdoTag.Replace("#ID#", nTmpCnt.ToString()) + " " + sItemCont;
									else
										VoteItem[0] = sItemCont;

									nTmpCnt++;

									arrVoteItem.Add (VoteItem);
								}
							}


							if (nTmpCnt > 0)
							{
								foreach (string[] aVoteContent in arrVoteItem)
								{
									double nPercentWidth = 0.0;

									if (nItemSumCount > 0)
									{
										nPercentWidth = (Convert.ToDouble(aVoteContent[1]) / nItemSumCount) * 100.0;
									}

									if (nPercentWidth < 1.0)
										nPercentWidth = 0.0;
									else
                                        nPercentWidth = Math.Round(nPercentWidth, 2);

									swItem.WriteLine(aVoteContent[0] + "<br>");
									swItem.WriteLine(sVoteGraph.Replace("[GRAPH_COUNT]", aVoteContent[1]).Replace("[GRAPH_WIDTH]", nPercentWidth.ToString())  + "<br><br>");
								}
							}


							xmlRead.Close();
							sSrcCont.Close();

							if (!NBUtil.StrEmptyChk(swItem.ToString()))
							{
								sTmpContent += "<br><br><br>" + swItem.ToString();

								if (DateTime.Now.ToString("yyyy-MM-dd").CompareTo(drReadContent["vote_start"].ToString()) >= 0 && DateTime.Now.ToString("yyyy-MM-dd").CompareTo(drReadContent["vote_end"].ToString()) <= 0)
                                    sTmpContent += "<br><br><a href=\"javascript:NB_DoVote('" + mPageQryInfo.sBoardNo + "', '" + drReadContent["idx_no"].ToString() + "', '" + mBoardCfg.bnc_revote_limit + "');\">[투표하기]</a>";
							}
						}
					}

					WNLblContent.Text = sTmpContent.Trim();


					// -- Sign 추가
					if (NBUtil.isUseChk(mBoardCfg.bgc_mempic_use) && !NBUtil.StrEmptyChk(drReadContent["memsign_name"].ToString()))
					{
						MemSignImg = "<img src=\"Common/DrawImage.aspx?bno=1000000&img=" + Server.UrlEncode(drReadContent["memsign_name"].ToString()) + "&tf=0&iw=0&ih=0\" align=\"absmiddle\" border=\"0\">";
					}

                    // -- 이전글 / 다음글 표시

					if (!mPageQryInfo.bSearchYN)
					{
						//이전글 다음글
						string sTmpNumm = drReadContent["ref_no"].ToString();
						PrevNextContBind(sTmpNumm);
					}
					else
					{
						HTTblPrevCont.Visible = false;
						HTTblNextCont.Visible = false;
					}

					// -- 글 리스트 바인팅
					if (mBoardCfg.bnc_listview_use.CompareTo("1") == 0)
					{
						BoardListBind ();
					}
					else
					{
						HTTrOuterBoardList.Visible = false;
						HTTblPaging.Visible = false;
					}


					// 음악 게시판의 경우 파일을 바인딩 하고 파일 표시는 안해준다.
					if (NBUtil.isUseChk(mBoardCfg.bnc_fileupdown_use) && NBUtil.isUseChk (mBoardCfg.bnc_musicboard_use))
					{
						DoUpFileBind(true);
						HTTrFile.Visible = false;
					}
					else
					{
						// 파일 표시 시작
						if (NBUtil.isUseChk (mBoardCfg.bnc_fileupdown_use))
							DoUpFileBind(false);
						else
							HTTrFile.Visible = false;
					}
				}
				else
				{
					throw new Exception("글이 삭제되었거나, 링크가 잘못되었습니다.");
				}

			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}

		/// <summary>
		/// 업로드 파일을 표시해 준다.
		/// </summary>
		private void DoUpFileBind(bool bMusic)
		{
			SqlConnection dbSqlConn = null;

			try
			{
                DBUtil.DBConnection (ref dbSqlConn);

				int nCnt = 0;
                string sPlayMusicFile = string.Empty;
				string sPlayMusicFileDesc = string.Empty;
				string sAttachFiles = string.Empty;

				SqlDataReader drFileInfo = SqlHelper.ExecuteReader(dbSqlConn, CommandType.StoredProcedure, "nbsp_sel_filedata_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", int.Parse(mPageQryInfo.sIdxNo)));

				HTTdUpFile.InnerHtml = string.Empty;
				StringBuilder sbFileUp = null;

				while (drFileInfo.Read())
				{
					if ( !NBUtil.StrEmptyChk(drFileInfo["file_name"].ToString()) )
					{
						string sFileName = drFileInfo["file_name"].ToString() + drFileInfo["file_ext"].ToString();
						sAttachFiles = "Common/NB_FileDown.aspx?bno=" + mPageQryInfo.sBoardNo + "&bidx=" + mPageQryInfo.sIdxNo + "&fidx=" + drFileInfo["fidx_no"].ToString() + "&fname=" + Server.UrlEncode(sFileName);

						if (nCnt.Equals(0))
						{
							sPlayMusicFile = sAttachFiles;
							sPlayMusicFileDesc = drFileInfo["file_desc"].ToString();
						}

						sbFileUp = new StringBuilder();
						if (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.FileDownload))
						{
							sbFileUp.Append("<a class=\"NB_FileDown\" href=\"" + sAttachFiles + "\" target=\"_self\">");
							sbFileUp.Append(sFileName);
							sbFileUp.Append("</a>");
						}
						else
						{
							sbFileUp.Append("<span title='다운로드 권한이 없습니다.'>");
							sbFileUp.Append(sFileName);
							sbFileUp.Append("</span>");
						}
                        sbFileUp.Append(" <span class=\"NB_FileDown_Info\">(size:" + NBCmnUtil.ByteToKB_Format(int.Parse(drFileInfo["file_size"].ToString())) + "KB,");
						sbFileUp.Append(" down:" + NBUtil.ConvStrToInt (drFileInfo["file_down"].ToString()).ToString("#,##0") + ")</span> ");
						sbFileUp.Append("<span class=\"NB_FileDown_Desc\">" + drFileInfo["file_desc"].ToString() + "</span>");
						sbFileUp.Append("<br>");
						
						HTTdUpFile.InnerHtml += sbFileUp.ToString();

						nCnt++;
					}
				}

				if (nCnt > 0)
				{
					if (bMusic)
					{
						MusicPlayFile = "http://" + Request.Url.Host + "/NeBoard/" + Server.UrlEncode(sPlayMusicFile);
						MusicPlayDesc = sPlayMusicFileDesc.Replace("|", " - ");
					}
				}
				else
				{
					HTTrFile.Visible = false;
				}
			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}


		//이전글, 다음글
		private void PrevNextContBind(string sCurrNum)
		{
			SqlConnection dbSqlConn = null;

			try
			{	
				DBUtil.DBConnection (ref dbSqlConn);

				int nCurrNum = 0;
				
				if (!NBUtil.StrEmptyChk(sCurrNum))
					nCurrNum = int.Parse(sCurrNum);
				
				SqlDataReader drNavi = SqlHelper.ExecuteReader (dbSqlConn, CommandType.StoredProcedure, "nbsp_pre_next_cont_" + mPageQryInfo.sBoardNo, new SqlParameter("@curr_num", nCurrNum));

				if (drNavi.Read())
				{
					HTTdNextCont.InnerHtml = "<a href=\"" + NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "VIEW", mPageQryInfo, drNavi["pre_idx"].ToString()) + "\">" + Server.HtmlEncode(drNavi["pre_subject"].ToString()) + "</a>";
					HTTdPrevCont.InnerHtml = "<a href=\"" + NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "VIEW", mPageQryInfo, drNavi["next_idx"].ToString()) + "\">" + Server.HtmlEncode(drNavi["next_subject"].ToString()) + "</a>";
				}
				else
				{
					HTTdNextCont.Visible = false;
					HTTdPrevCont.Visible = false;
				}
			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}


		/// <summary>
		/// 게시판 리스트 바인딩
		/// </summary>
		private void BoardListBind()
		{
			try
			{
				StringBuilder sbListDesignTxt = new StringBuilder();
                
				bool bResult = NBUtil.BoardListBind(ref sbListDesignTxt, mPageQryInfo.sBoardNo, mBoardCfg, mPageQryInfo);

				if ( bResult )
				{
					ltr_BoardListBind.Text = sbListDesignTxt.ToString();
					
					// 게시판 페이징
					string
						sTotalRecordCnt = string.Empty,
						sCurrPageNum = string.Empty,
						sTotlaPageNum = string.Empty;

					WNLtrPaging.Text = NBUtil.GetPagingStr(mPageQryInfo.sBoardNo, mBoardCfg, mPageQryInfo, ref sTotalRecordCnt, ref sCurrPageNum, ref sTotlaPageNum);
				}
				else
				{
					WNLtrPaging.Text = "&nbsp;";
				}
			}
			catch(Exception E)
			{
				throw E;
			}
		}


		#region 코멘트
		/// <summary>
		/// 코멘트 정렬 설정
		/// </summary>
		/// <returns></returns>
		private string sCmmtSortStr()
		{
			string sSortStr = "ASC";

			if ( NBUtil.isUseChk (mBoardCfg.bnc_cmmt_sort) )
				sSortStr = "DESC";

			return sSortStr;
		}

		private void CmmtBind()
		{
			SqlConnection dbSqlConn = null;

			try
			{
				//코멘트 사용일 경우에만 코멘트를 바인딩 한다.
				if ( NBUtil.isUseChk (mBoardCfg.bnc_cmmt_use) )
				{	
					DBUtil.DBConnection (ref dbSqlConn);

					DataSet dsCmmtData = SqlHelper.ExecuteDataset (dbSqlConn, CommandType.StoredProcedure, "nbsp_get_cmmtdata_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", int.Parse(mPageQryInfo.sIdxNo)));

					DataTable dtCmmtData = dsCmmtData.Tables[0];

					dsCmmtData.Dispose();
					dbSqlConn.Close();

					DataRow[] drCmmtData = dtCmmtData.Select("", "write_date " + sCmmtSortStr());

					string sCmmtDesignTxt = NBCmnUtil.TextFileRead (Server.MapPath(mBoardCfg.bnd_skin_path + "/CmmtDesign.htm"));

					if ( !NBUtil.StrEmptyChk(sCmmtDesignTxt) )
					{
						StringBuilder sbCmmtDesign = new StringBuilder(sCmmtDesignTxt);

						string sRepeatStr = NBCmnUtil.GetDesignTag_Str (sbCmmtDesign.ToString(), NBLib.NBCmmtDesignTag.Cmmt_Repeat_S, NBLib.NBCmmtDesignTag.Cmmt_Repeat_E);

						string sResultRowData = string.Empty;

						for (int nCmmtCnt = 0; nCmmtCnt < drCmmtData.Length; nCmmtCnt++)
						{
							string sRepeatResultStr = sRepeatStr;
							string sCmmtWriterName = string.Empty;

							
							// -- 글쓴이 표시
							if (NBUtil.isUseChk(mBoardCfg.bgc_mempic_use) && !NBUtil.StrEmptyChk(drCmmtData[nCmmtCnt]["mempic_name"].ToString()))
							{
								sCmmtWriterName = "<img src=\"Common/DrawImage.aspx?bno=1000000&img=" + Server.UrlEncode(drCmmtData[nCmmtCnt]["mempic_name"].ToString()) + "&tf=0&iw=0&ih=0\" align=\"absmiddle\" border=\"0\">";
							}
							else
							{
								// -- 글쓴이 표시
								sCmmtWriterName = Server.HtmlEncode(drCmmtData[nCmmtCnt]["writer_name"].ToString());
							}

							sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBCmmtDesignTag.Writer_Name, sCmmtWriterName);
							sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBCmmtDesignTag.Write_Date, DateTime.Parse(drCmmtData[nCmmtCnt]["write_date"].ToString()).ToString("yyyy-MM-dd HH:mm:ss"));
							sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBCmmtDesignTag.Write_IP, get_ip_hid(drCmmtData[nCmmtCnt]["writer_ip"].ToString()));
							sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBCmmtDesignTag.Del_Link, "javascript:NB_Cmt_Del('" + mPageQryInfo.sBoardNo + "', '" + drCmmtData[nCmmtCnt]["idx_no"].ToString() + "', '" + drCmmtData[nCmmtCnt]["cmmt_idx"].ToString() + "');");
							sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBCmmtDesignTag.Cmmt_Content, Server.HtmlEncode(drCmmtData[nCmmtCnt]["cmmt_cont"].ToString()).Replace("\r\n", "<br>"));

							sResultRowData += sRepeatResultStr;
						}

						NBCmnUtil.GetDesignTagReplace(ref sbCmmtDesign, NBLib.NBCmmtDesignTag.Cmmt_Repeat_S, NBLib.NBCmmtDesignTag.Cmmt_Repeat_E, sResultRowData);

						ltr_CmmtListBind.Text = sbCmmtDesign.ToString();
					}
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}

		private string get_ip_hid(string sSrcIP)
		{
			string sResult = string.Empty;

			if (!NBUtil.StrEmptyChk (sSrcIP))
			{
				string[] arrSrcIP = sSrcIP.Split('.');

				if (arrSrcIP.Length == 4)
				{
                    sResult = string.Join(".", arrSrcIP, 0, 3) + ".xxx";
				}
			}

			return sResult;
		}

		private bool cmmt_input_valid()
		{
			if (!NBUtil.isUseChk(mBoardCfg.bnc_cmmt_use) || !NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.CmmtWrite))
			{
				NBCmnUtil.ViewAlertMsg (Page, "코멘트 쓰기 권한이 없습니다.");
				return false;
			}

			if (WNTxtCmtName.Visible && WNTxtCmtName.Enabled)
			{
				if (NBUtil.StrEmptyChk (WNTxtCmtName.Text))
				{
					NBCmnUtil.ViewAlertMsg (Page, "코멘트 작성자를 입력해 주세요.");
					return false;
				}
			}
			else
			{
				if (NBUtil.StrEmptyChk (WNLblCmtMbName.Text))
				{
					NBCmnUtil.ViewMsgAndCopy (Page, @"로그아웃 되었습니다. 다시 로그인해 주세요.\n\n작성 내용은 클립보드에 복사 되었습니다.\n\nctrl+v로 붙여넣기 하시면 됩니다.", WNTxtCmtContent.ClientID);
					return false;
				}
			}

			if (WNTxtCmtPwd.Visible && WNTxtCmtPwd.Enabled)
			{
				if (NBUtil.StrEmptyChk (WNTxtCmtPwd.Text))
				{
					NBCmnUtil.ViewAlertMsg (Page, "코멘트의 비밀번호를 입력해 주세요.");
					return false;
				}
			}

			if (WNTxtCmtContent.Visible && WNTxtCmtContent.Enabled)
			{
				if (NBUtil.StrEmptyChk (WNTxtCmtContent.Text))
				{
					NBCmnUtil.ViewAlertMsg (Page, "코멘트의 내용을 입력해 주세요.");
					return false;
				}
			}

			return true;
		}

		private void WBImgCmtOk_Click(object sender, ImageClickEventArgs e)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				if (!cmmt_input_valid())
					return;

				if ( NBUtil.DoWriterLimitChk(mBoardCfg.bnc_writer_limit, WNTxtCmtName.Text) )
					return;

				string sCmmt_GuestNo = string.Empty;
				string sCmmt_WriterName = string.Empty;
				string sCmmt_Pwd = string.Empty;
				
				if (NBUtil.StrEmptyChk(WNTxtCmtName.Text) && NBUtil.StrEmptyChk(WNTxtCmtPwd.Text) && !NBUtil.StrEmptyChk(WNLblCmtMbName.Text))
				{
					//쿠키 디코딩 추가(2005.04.04)
					sCmmt_GuestNo = Server.UrlDecode(Request.Cookies["MBNO"].Value).Trim();
					sCmmt_WriterName = Server.UrlDecode(Request.Cookies["MBNAME"].Value).Trim().Replace("'","''");
					sCmmt_Pwd = string.Empty;
				}
				else
				{
					sCmmt_GuestNo = string.Empty;
					sCmmt_WriterName = WNTxtCmtName.Text.Trim().Replace("'", "''");
					sCmmt_Pwd = WNTxtCmtPwd.Text.Trim().Replace("'", "''");
				}
                
				SqlParameter[] sqlParm = new SqlParameter[6];
				sqlParm[0] = new SqlParameter ("@idx_no", int.Parse(mPageQryInfo.sIdxNo));
				sqlParm[1] = new SqlParameter("@guest_no", sCmmt_GuestNo);
				sqlParm[2] = new SqlParameter("@writer_name", sCmmt_WriterName);
				sqlParm[3] = new SqlParameter("@writer_ip", Request.UserHostAddress);
				sqlParm[4] = new SqlParameter("@pwd", sCmmt_Pwd);
				sqlParm[5] = new SqlParameter("@cmmt_cont", WNTxtCmtContent.Text);
				

				DBUtil.DBConnection (ref dbSqlConn);

				if (SqlHelper.ExecuteNonQuery (dbSqlConn, CommandType.StoredProcedure, "nbsp_cmmt_insert_" + mPageQryInfo.sBoardNo, sqlParm) > 0)
				{
					if (NBUtil.isUseChk (mBoardCfg.bnc_cmmt_alert))
						NBUtil.AdminAlertMail ("C", mPageQryInfo.sBoardNo, mPageQryInfo.sIdxNo, "", WNTxtCmtContent.Text, mBoardCfg, mPageQryInfo);

					if (NBUtil.isUseChk (mBoardCfg.bnc_cmmtmail_use))
						CmmtAlertMailSend (mPageQryInfo.sIdxNo, sCmmt_WriterName, WNTxtCmtContent.Text);

					if (NBUtil.isLogin())
						NBUtil.DoPointApply (mBoardCfg.bpd_cmmt_write_point, sCmmt_GuestNo);

					Response.Redirect(NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "VIEW", mPageQryInfo, mPageQryInfo.sIdxNo), false);
				}
				else
					NBCmnUtil.ViewAlertMsg (Page, "코멘트를 작성하는 도중 오류가 발생하였습니다.");
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}

		// 코멘트를 달 경우 메일로 받기를 설정한 원본글 작성자에게 메일 발송
		private void CmmtAlertMailSend(string sSourceBoardIdx, string sCmmtWriter, string sCmmtContent)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				string sAlertMailStr = NBUtil.getAlertMailStr (Server.MapPath("Common/AlertMail.xml"), "/MailMsg/CmmtAlertMail");

				if ( !NBUtil.StrEmptyChk (sAlertMailStr) )
				{
					DBUtil.DBConnection (ref dbSqlConn);
                    
					// 원본글 내용 읽어 오기
					string sSource_Email = string.Empty;		//설정글 이메일
					string sSource_Subject = string.Empty;		//설정글 제목
					string sSource_Writeday = string.Empty;		//설정글 작성일
					string sCmmtMail_YN = string.Empty;		//코멘트 알림

					SqlDataReader drSrcDataQry = SqlHelper.ExecuteReader (dbSqlConn, CommandType.StoredProcedure, "nbsp_get_board_mail_data_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", mPageQryInfo.sIdxNo));
                
					if (drSrcDataQry.Read())
					{
						sSource_Email = drSrcDataQry["email"].ToString();
						sSource_Subject = drSrcDataQry["subject"].ToString();
						sSource_Writeday = drSrcDataQry["write_date"].ToString();
						sCmmtMail_YN = drSrcDataQry["cmmtmail_yn"].ToString();
					}
                    
					drSrcDataQry.Close();
					dbSqlConn.Close();


					if ( !NBUtil.StrEmptyChk (sSource_Email) && NBUtil.isUseChk(sCmmtMail_YN) )
					{
						//메일내용대치
						sAlertMailStr = sAlertMailStr.Replace("##ORIG_WDATE##", sSource_Writeday.Trim());
						sAlertMailStr = sAlertMailStr.Replace("##ORIG_SUBJECT##", Server.HtmlEncode (sSource_Subject));
						sAlertMailStr = sAlertMailStr.Replace("##BOARD_LINK##", "http://" + Request.Url.Host + NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "VIEW", mPageQryInfo, sSourceBoardIdx));
						sAlertMailStr = sAlertMailStr.Replace("##CMMT_WRITER##", Server.HtmlEncode (sCmmtWriter));
						sAlertMailStr = sAlertMailStr.Replace("##CMMT_CONTENT##", Server.HtmlEncode(sCmmtContent).Replace("\r\n", "<br>"));

						string sMailTitle = string.Empty;			// 메일 내용

						sMailTitle = "[" + mBoardCfg.bnc_board_name + "] 게시물에 코멘트가 등록되었습니다.";

						NBUtil.SendMail (sSource_Email, sSource_Email, "", "", sMailTitle, sAlertMailStr, "1");
					}
				}
			}
			catch
			{
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}			
		}
		#endregion


		/// <summary>
		/// 글 추천
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void WBImgVote_Click(object sender, ImageClickEventArgs e)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				if (SqlHelper.ExecuteNonQuery (dbSqlConn, CommandType.StoredProcedure, "nbsp_do_board_recommend_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", mPageQryInfo.sIdxNo)) > 0)
				{
					Response.Cookies["BOARD_VOTE_NUM"].Value += Server.UrlEncode(mPageQryInfo.sIdxNo) + ";";//쿠키 인코딩 추가(2005.04.04)
					Response.Cookies["BOARD_VOTE_NUM"].Expires = DateTime.Now.AddMinutes (20);

					WBImgVote.Visible = false;

					WNLblVoteCnt.Text = "&nbsp;&nbsp;Good : " + (int.Parse(WNLblVoteCnt.Text.Split(':')[1]) + 1).ToString();
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}

		private string DoEncDisplayText(string sSrcText, bool bHtmlUse, bool bVoteYn)
		{
			string sResult = sSrcText;

			if (NBUtil.isUseChk(mBoardCfg.bnc_voteboard_use) && bVoteYn)
			{
				StringReader sSrcCont = new StringReader(sSrcText);
				XmlTextReader xmlRead = new XmlTextReader(sSrcCont);
				xmlRead.WhitespaceHandling = WhitespaceHandling.None;

				while (xmlRead.Read())
				{
					if (xmlRead.LocalName.Equals("content"))
					{
						sResult = xmlRead.ReadString();
						break;
					}
				}

				xmlRead.Close();
				sSrcCont.Close();                
			}


			// HTML/TEXT 구분에 따른 내용 내용 REPLACE
			if (!bHtmlUse)
			{
				sResult = Server.HtmlEncode (sResult);
				sResult = sResult.Replace("\r\n","<br>");
			}
			

			// 검색일 경우 검색 키워드를 REPLACE
			//if (mPageQryInfo.bSearchYN)
			//	sResult = sResult.Replace(mPageQryInfo.sSearchTxt, "<span class='SearchHeighlight'>" + mPageQryInfo.sSearchTxt + "</span>");

			// URL이 포함되어 있을경우 자동링크 설정
			if (NBUtil.isUseChk(mBoardCfg.bnc_autolink_use))
			{
				string sMatchFilter = @"((http|ftp|https)):\/\/[\w]+(\.[\w]+)+([\w\-\.,@?^=%&:/~\+#]*[\w\-\@?^=%&/~\+#])(\s+)?";
				sResult = Regex.Replace (sResult, sMatchFilter, new MatchEvaluator (NBUtil.CapText));
			}

			// 파일 링크 관련 처리
			MatchCollection oMC = NBUtil.GetUpFileTag (sResult);

            if (oMC != null && oMC.Count > 0)
            {
				string sFileIndex = string.Empty;
				string sReplaceTag = string.Empty;
            	DataTable dtUpFiles = NBUtil.GetUpFileCnt(mPageQryInfo.sBoardNo, mPageQryInfo.sIdxNo);

				DataRow[] drImgFile = dtUpFiles.Select("", "fidx_no ASC");

				
					foreach (Match mcItem in oMC)
					{
						if (drImgFile.Length > 0)
						{
							sReplaceTag = string.Empty;
							sFileIndex = mcItem.Value.Split('_')[1].Substring(0, mcItem.Value.Split('_')[1].Length - 1);

							for (int drCnt = 0; drCnt < drImgFile.Length; drCnt++)
							{
								if ( sFileIndex.Equals(drImgFile[drCnt]["fidx_no"].ToString()) )
								{
									string sFileName = drImgFile[drCnt]["file_name"].ToString() + drImgFile[drCnt]["file_ext"].ToString();
									if ( NBUtil.isImgType(drImgFile[drCnt]["file_ext"].ToString()) )
									{
										// 업로드 파일 중 이미지 파일이 있으면
                                        sReplaceTag = "<a href=\"javascript:void(0);\" onclick=\"NB_ClientWinOpen('Common/FullSizeImg.aspx?bno=" + mPageQryInfo.sBoardNo + "&img=" + Server.UrlEncode(sFileName) + "', 'FullImgWin', 'width=300, height=250,scrollbars=yes');\" onfocus=\"this.blur()\">";
										sReplaceTag += "<img src=\"Common/DrawImage.aspx?bno=" + mPageQryInfo.sBoardNo + "&img=" + Server.UrlEncode(sFileName) + "&tf=1&iw=" + mBoardCfg.bnc_img_thumb_width + "&ih=" + mBoardCfg.bnc_img_thumb_height + "\" align=\"absmiddle\">";
										sReplaceTag += "</a>";

									}
									else
									{
										sReplaceTag = "<a href=\"Common/NB_FileDown.aspx?bno=" + mPageQryInfo.sBoardNo + "&bidx=" + mPageQryInfo.sIdxNo + "&fidx=" + drImgFile[drCnt]["fidx_no"].ToString() + "&fname=" + Server.UrlEncode(sFileName) + "\" target=\"_self\">";
										sReplaceTag += sFileName;
										sReplaceTag += "</a>";
									}

									if ( !NBUtil.StrEmptyChk(drImgFile[drCnt]["file_desc"].ToString()) )
										sReplaceTag = "<span title=\"" + drImgFile[drCnt]["file_desc"].ToString().Replace("'", "").Replace("\"", "").Replace("<br>", "\r\n") + "\">" + sReplaceTag + "</span>";

									break;
								}

							}

						}

						sResult = sResult.Replace(mcItem.Value, sReplaceTag);
					}

            }

			// 투표 보여 주기 처리

			return sResult;
		}
	}
}
