﻿using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using BoardLib;
using NeBoard.Common;
using System.Text.RegularExpressions;
using System.Xml;

namespace NeBoard
{
	public abstract class BoardWrite : UserControl
	{
		#region Controls
		protected HyperLink lnk_HomeBtn;
		protected HyperLink lnk_AdminBtn;
		protected HyperLink lnk_LoginBtn;
		protected HyperLink lnk_LogoutBtn;
		protected HyperLink lnk_SignupBtn;
		protected HyperLink lnk_MyinfoBtn;
		protected HyperLink lnk_MemoBoxBtn;

		protected HtmlTable HTTblOuterTable;
		protected HtmlTable HTTblBoardList;
		protected HtmlTableRow HTTrEmail;
		protected HtmlTableRow HTTrHomePage;
		protected HtmlTableRow HTTrLoginName;
		protected HtmlTableRow HTTrLogoutName;
		protected HtmlTableRow HTTrUpload;
		protected HtmlTableRow HTTrRefLink;

		protected TextBox WNTxtName;
		protected TextBox WNTxtEmail;
		protected TextBox WNTxtHomepage;
		protected TextBox WNTxtSubject;
		protected CheckBox WNChkHtml;
		protected CheckBox WNChkAlert;
		protected CheckBox WNChkCmmtAlert;
		protected CheckBox WNChkSecret;
		protected CheckBox WNChkVote;
		protected CheckBox WNChkNotice;
		protected CheckBox WNChkSum;
		protected CheckBox WNChkSumHtml;
		protected CheckBox WNChkASync;
		protected HtmlInputFile HNFleUpFile1;
		protected TextBox WNTxtLink1;
		protected TextBox WNTxtLink2;
		protected ImageButton WBImgSave;
		protected ImageButton WBImgCancel;
		protected TextBox WNTxtContent;
		protected TextBox WNTxtSumContent;
		protected TextBox WNTxtVoteStart;
		protected TextBox WNTxtVoteEnd;
		protected TextBox WNTxtPwd;
		protected Label WNLblMbName;
		protected Literal ltr_FileUpListBind;

		protected HtmlInputHidden HidStartUploadDate;
		protected HtmlInputHidden HidStartDeleteDate;
		
		protected DropDownList WNDdlCatList;
		public NBLib.PageQryStr mPageQryInfo;	// QueryString으로 넘어온 결과 로드

		public NBLib.CurBoardCfg mBoardCfg;
		public NBLib.RefContentInfo mRefContInfo;

		public string BoardTitleContent;

		// DB 관련 작업 처리
		private data_proc do_data_proc;
		#endregion

		public string
			gBoardNo,					// 게시판 코드
			gViewMode;					// 게시판 작동 모드

		public string BoardNo
		{
			set
			{
				gBoardNo = value;
			}

			get
			{
				return gBoardNo;
			}
		}

		public string ViewMode
		{
			set
			{
				gViewMode = value;
			}

			get
			{
				return gViewMode;
			}
		}

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				do_init_set();
			}
			catch(Exception E)
			{
				Response.Clear();
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
			}
			finally
			{
				do_data_proc.Dispose();
			}
		}

		

		/// <summary>
		/// 게시판 환경 설정 내용을 적용한다.
		/// </summary>
		private void do_init_set()
		{
			try
			{
				if (nb_utils.GetGlobalValue (ref mPageQryInfo, ref mBoardCfg, gBoardNo, gViewMode))
				{
					do_data_proc = new data_proc(mPageQryInfo.sBoardNo);

					// 게시판 타이틀 설정
					NBUtil.SetDisplayType(ref BoardTitleContent, mBoardCfg.bnd_boardtitle_view, mBoardCfg.bnd_boardtitle_cont.Replace("[BRD_NAME]", mBoardCfg.bnc_board_name));

					// 버튼의 클라이언트 스크립트 정의
					set_pagebutton();

					// 게시판 사용 권한 설정
					PermissionSetting();

					// 환경 설정에 따른 버튼의 표시 여부를 결정 한다.
					set_page_display();

					// 전체 테이블의 레이아웃을 디자인 설정에 맞도록 구성한다.
					NBUtil.SetBoardListTblCfg (mBoardCfg, HTTblOuterTable);

					//** 로그인 / 로그아웃 상태에 따른 상태 설정 **
					if (NBUtil.isLogin())
					{
						// 로그인 상태일 경우 .. 쿠키 디코딩 추가(2005.04.04)
						WNLblMbName.Text = Server.UrlDecode(Request.Cookies["MBNAME"].Value).Trim().Replace("<","&lt;").Replace(">","&gt;");
						WNTxtEmail.Text = Server.UrlDecode(Request.Cookies["MBEMAIL"].Value).Trim();
						WNTxtHomepage.Text = Server.UrlDecode(Request.Cookies["MBHOMEPG"].Value).Trim();
				
						HTTrLoginName.Visible = true;
						HTTrLogoutName.Visible = false;
					}
					else
					{
						// 비회원 일때
						HTTrLoginName.Visible = false;
						HTTrLogoutName.Visible = true;
					}

					// 카테고리 사용 여부에 따른 설정
					if ( NBUtil.isUseChk(mBoardCfg.bnc_category_use) )
					{
						NBUtil.LoadCatList(WNDdlCatList, mPageQryInfo.sBoardNo);

						if (WNDdlCatList.Items.Count > 0)
						{
							WNDdlCatList.Enabled = true;
							WNDdlCatList.Visible = true;
						}
						else
						{
							WNDdlCatList.Enabled = false;
							WNDdlCatList.Visible = false;	
						}
					}
					else
					{
						WNDdlCatList.Enabled = false;
						WNDdlCatList.Visible = false;
					}


					// 답변글일 경우 처리
					if (NBUtil.isReplyYn(mPageQryInfo))
					{
						RefContentBind();						
					}

					//** 답변글 작성이고 부모글이 비밀글일 경우 **
					if( mRefContInfo.PrivateYn )
					{
						WNTxtPwd.Enabled = false;
						WNTxtPwd.Style.Add("background-color", "#eaeaea");
						WNChkSecret.Checked = true;
						WNChkSecret.Enabled = false;
					}

					if ( WNChkVote != null && mRefContInfo.VoteYn )
					{
                        WNChkVote.Enabled = false;
						WNChkVote.Visible = false;
					}
					
					if (!IsPostBack)
					{
                        // 글쓰기 기본값 입력
						if (!NBUtil.StrEmptyChk(mBoardCfg.bnc_default_cont))
							WNTxtContent.Text = mBoardCfg.bnc_default_cont;
					}

					// 파일 업로드 필드 추가
					DoFileUpListBind();

                    set_ToolTip();					
				}
			}
			catch (Exception E)
			{
				throw E;
			}
		}

		private void set_ToolTip()
		{
			WNChkHtml.ToolTip = "본문에 HTML 태그를 사용할지 결정 합니다.";
			WNChkAlert.ToolTip = "답변글이 등록되면 이메일로 알려드립니다.";
			WNChkCmmtAlert.ToolTip = "코멘트가 등록되면 이메일로 알려드립니다.";
			WNChkSecret.ToolTip = "현재 게시물을 비밀글로 작성 합니다.";
			WNChkNotice.ToolTip = "현재 게시물을 공지글로 작성 합니다.";
			WNChkVote.ToolTip = "투표글을 작성 합니다.\n투표 시작/종료 시각을 입력 하시고,\n내용에서 투표 항목을 입력 하시면 됩니다.";
			WNChkSum.ToolTip = "RSS의 본문 내용에 들어갈 내용을 따로 입력하고 싶으실 경우 사용 합니다.";
			WNChkASync.ToolTip = "게시물의 등록 시각과 삭제 시작을 예약할 수 있습니다.";
		}

		/// <summary>
		/// 글쓰기 파일 입력 필드
		/// </summary>
		private void DoFileUpListBind()
		{
			if ( NBUtil.isFileUpUse (mBoardCfg.bnc_fileupdown_use, NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.FileUpload)) && !NBUtil.StrEmptyChk(mBoardCfg.bnc_file_up_cnt) && int.Parse(mBoardCfg.bnc_file_up_cnt) > 0 )
			{
				string sFileUpDesignTxt = NBCmnUtil.TextFileRead (HttpContext.Current.Server.MapPath(mBoardCfg.bnd_skin_path + "/FileUpDesign.htm"));

				if ( !NBUtil.StrEmptyChk(sFileUpDesignTxt) )
				{
					sFileUpDesignTxt = sFileUpDesignTxt.Replace (NBLib.NBFileUpDesignTag.FileUp_Count, mBoardCfg.bnc_file_up_cnt);

					StringBuilder sbFileUpDesign = new StringBuilder(sFileUpDesignTxt);

                    string sRepeatStr = NBCmnUtil.GetDesignTag_Str (sbFileUpDesign.ToString(), NBLib.NBFileUpDesignTag.FileUpRepeat_S, NBLib.NBFileUpDesignTag.FileUpRepeat_E);

					string sResultRowData = string.Empty;

					for (int nFileUpCnt = 0; nFileUpCnt < int.Parse(mBoardCfg.bnc_file_up_cnt); nFileUpCnt++)
					{
						string sRepeatResultStr = sRepeatStr;

						sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBFileUpDesignTag.FileUpPlace_ID, "FileUpPlace_" + nFileUpCnt.ToString());

						if (nFileUpCnt == 0)
						{
							sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBFileUpDesignTag.FileUpPlace_Style, "display : block;");
						}
						else
						{
							sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBFileUpDesignTag.FileUpPlace_Style, "display : none;");
						}

						sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBFileUpDesignTag.FileUp_Input, "<input type=\"file\" name=\"NBFileUp_File\" size=\"44\" class=\"inputbox\" onchange=\"ViewPreImg(this, 'PreImg_" + nFileUpCnt.ToString() + "');\">");
						sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBFileUpDesignTag.FileUp_Desc, "<input type=\"text\" name=\"NBFileUp_Desc\" size=\"44\" class=\"inputbox\">");
						sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBFileUpDesignTag.FileUp_InTag, "#FileViewLink_" + nFileUpCnt.ToString() + "#");
						sRepeatResultStr = sRepeatResultStr.Replace (NBLib.NBFileUpDesignTag.PreImg_ID, "PreImg_" + nFileUpCnt.ToString());

						sResultRowData += sRepeatResultStr;
					}

					NBCmnUtil.GetDesignTagReplace(ref sbFileUpDesign, NBLib.NBFileUpDesignTag.FileUpRepeat_S, NBLib.NBFileUpDesignTag.FileUpRepeat_E, sResultRowData);

					ltr_FileUpListBind.Text = sbFileUpDesign.ToString();
				}
			}
		}
        
		/// <summary>
		/// 페이지 버튼 설정
		/// </summary>
		private void set_pagebutton()
		{
			//-- 버튼의 링크 설정
			if ( NBUtil.StrEmptyChk(lnk_AdminBtn.NavigateUrl) )
			{
				lnk_AdminBtn.Attributes["onclick"] = "BoardList_Admin('" + ConfigurationSettings.AppSettings["NeAdminPath"] + "/Default.aspx" + "', '" + mPageQryInfo.sBoardNo + "');";
			}

			if ( lnk_MemoBoxBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_MemoBoxBtn.NavigateUrl = "javascript:BoardList_Memobox()";

			if ( lnk_HomeBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_HomeBtn.NavigateUrl = mBoardCfg.bnc_homebtn_url;

			if ( lnk_LoginBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_LoginBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "LOGIN", mPageQryInfo);

			if ( lnk_LogoutBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_LogoutBtn.NavigateUrl = "javascript:NBLogoutProc();";

			if ( lnk_MyinfoBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_MyinfoBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "MYINFO", mPageQryInfo);

			if ( lnk_SignupBtn.NavigateUrl.Trim().Length.Equals(0) )
				lnk_SignupBtn.NavigateUrl = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "JOIN", mPageQryInfo);

			//-- 버튼의 표시 여부 결정
			NBLib.PageBtnView stBtnView = NBUtil.GetBtnViewSet (mBoardCfg) ;

			lnk_HomeBtn.Visible = stBtnView.home_btn;

			lnk_AdminBtn.Visible = stBtnView.admin_btn;

			lnk_LoginBtn.Visible = stBtnView.login_btn;

			lnk_LogoutBtn.Visible = stBtnView.logout_btn;

			lnk_SignupBtn.Visible = stBtnView.signup_btn;

			lnk_MyinfoBtn.Visible = stBtnView.myinfo_btn;

			lnk_MemoBoxBtn.Visible = stBtnView.memo_box;

			WBImgSave.Attributes.Add("onclick", "return BoardWrite_ValidationChk()");

			WNTxtContent.Attributes["onkeydown"] = "NBInputInsertBR (this);";
            WNTxtContent.Attributes["onkeyup"] = "NBRemoveShiftBR (this);";
			WNTxtContent.ToolTip = "Shift + Enter : <BR>";

			WNTxtSumContent.Attributes["onkeydown"] = "NBInputInsertBR (this);";
			WNTxtSumContent.Attributes["onkeyup"] = "NBRemoveShiftBR (this);";
			WNTxtSumContent.ToolTip = "Shift + Enter : <BR>";
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: 이 호출은 ASP.NET Web Form 디자이너에 필요합니다.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		///		디자이너 지원에 필요한 메서드입니다.
		///		이 메서드의 내용을 코드 편집기로 수정하지 마십시오.
		/// </summary>
		private void InitializeComponent()
		{
			this.WNChkSecret.CheckedChanged += new EventHandler(this.WNChkSecret_CheckedChanged);
			this.WBImgSave.Click += new ImageClickEventHandler(this.WBImgSave_Click);
			this.WBImgCancel.Click += new ImageClickEventHandler(this.WBImgCancel_Click);
			this.Load += new EventHandler(this.Page_Load);
		}
		#endregion

		private void WBImgCancel_Click(object sender, ImageClickEventArgs e)
		{
			mPageQryInfo.bReplyYN = false;
			NBCmnUtil.ViewMsgGoUrl (Page, NBUtil.GetBoardTransLink_WithCat (mPageQryInfo.sBoardNo, mPageQryInfo.sCatName, mPageQryInfo), "");
		}

		/// <summary>
		/// 회원의 권한 설정에 따른 환경 설정
		/// </summary>
		private void PermissionSetting()
		{
			if ( !NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.WriteModify) )
				NBCmnUtil.ViewMsgGoUrl (Page, NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "LIST"), "글쓰기 권한이 없습니다.");

			if ( mPageQryInfo.bReplyYN && !NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.ReplyWrite) )
				NBCmnUtil.ViewMsgGoUrl (Page, NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "LIST"), "답변 글쓰기 권한이 없습니다.");
		}

		/// <summary>
		/// 비밀글로 설정할 경우 회원 이라도 암호를 넣도록 한다.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void WNChkSecret_CheckedChanged(object sender, EventArgs e)
		{
			if(WNChkSecret.Checked)
			{
				if (NBUtil.isLogin())
				{
					HTTrLoginName.Visible = false;
					HTTrLogoutName.Visible = true;

					WNTxtName.Text = Server.UrlDecode(Request.Cookies["MBNAME"].Value);//쿠키 디코딩 추가(2005.04.04)
				}

				if(WNTxtPwd.Visible && WNTxtPwd.Enabled && !NBUtil.StrEmptyChk (WNTxtPwd.Text))
				{
                    WNTxtPwd.Attributes["value"] = WNTxtPwd.Text;
				}
			}
		}

		private void set_page_display()
		{ 
			// homepg_disp : 홈페이지 사용 여부에 따라 홈 버튼의 보기 여부를 결정한다.
			if ((int.Parse(mBoardCfg.bnc_homepage_use) & NBLib.ViewModeBit.WriteUseFlag) == NBLib.ViewModeBit.WriteUseFlag)
			{
				HTTrHomePage.Visible = true;

				if (NBUtil.isLogin())
				{
					if (!NBUtil.StrEmptyChk(NBCmnUtil.GetCookieValue("MBHOMEPG")))
                        WNTxtHomepage.Text = NBCmnUtil.GetCookieValue("MBHOMEPG");
				}
			}
			else
				HTTrHomePage.Visible = false;

			// email_disp : 이메일 사용 여부에 따라 이메일 버튼의 보기 여부를 결정한다.
			if ((int.Parse(mBoardCfg.bnc_email_use) & NBLib.ViewModeBit.WriteUseFlag) == NBLib.ViewModeBit.WriteUseFlag)
			{
				HTTrEmail.Visible = true;

				// 답변 메일의 사용 여부에 따라 답변 메일의 사용 설정을 한다.
				if ( NBUtil.isUseChk(mBoardCfg.bnc_replymail_use) )
				{
					WNChkAlert.Visible = true;
				}
				else
				{
					WNChkAlert.Checked = false;
					WNChkAlert.Visible = false;
				}

				// 코멘트 메일 사용 여부에 따라 코멘트 메일 사용 설정
				if ( NBUtil.isUseChk(mBoardCfg.bnc_cmmtmail_use) )
				{
					WNChkCmmtAlert.Visible = true;
				}
				else
				{
					WNChkCmmtAlert.Checked = false;
					WNChkCmmtAlert.Visible = false;
				}
			}
			else
			{
				HTTrEmail.Visible = false;

				WNChkAlert.Checked = false;
				WNChkAlert.Visible = false;

				WNChkCmmtAlert.Checked = false;
				WNChkCmmtAlert.Visible = false;
			}

			// Upload : 파일 업로드 사용 여부에 따라 파일 업로드 보기 여부를 결정한다.
			if ( NBUtil.isFileUpUse (mBoardCfg.bnc_fileupdown_use, NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.FileUpload)) )
                HTTrUpload.Visible = true;
			else
				HTTrUpload.Visible = false;

			// Link : 참조 링크 사용 여부에 따라 참조 링크 보기 여부를 결정 한다.
			if (NBUtil.isUseChk(mBoardCfg.bnc_sitelink_use))
				HTTrRefLink.Visible = true;
			else
				HTTrRefLink.Visible = false;

			//Notice : 공지글 사용 여부와 권한에 따라 공지글 설정의 보기 여부를 결정 한다.
			if (NBUtil.isUseChk(mBoardCfg.bnc_notice_use) && NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.NoticeWrite) )
			{
				// 부모글이 공지글일 경우에는 답변글을 작성할 수 없다.
				if (mPageQryInfo.bReplyYN)
					WNChkNotice.Visible = false;
				else
					WNChkNotice.Visible = true;
			}
			else
			{
				WNChkNotice.Checked = false;
				WNChkNotice.Visible = false;
			}

			if (mPageQryInfo.bReplyYN)
			{
				// 답변글에는 요약 게시판 내용을 입력할 수 없습니다.
				WNChkSum.Checked = false;
				WNChkSum.Visible = false;
			}
			else
			{
				WNChkSum.Attributes["onclick"] = "NBSumContent_Display(this);";
			}

            // 비밀글 사용 여부에 따라 비밀글 작성 설정을 한다.
			if ( NBUtil.isUseChk(mBoardCfg.bnc_private_use) )
			{
				if (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.PrivateWrite) )
                    WNChkSecret.Visible = true;
				else
				{
					WNChkSecret.Checked = false;
					WNChkSecret.Visible = false;
				}
			}
			else
			{
				WNChkSecret.Checked = false;
				WNChkSecret.Visible = false;
			}


			// 투표 사용 여부에 따라 투표 설정을 한다.
			if (  NBUtil.isUseChk(mBoardCfg.bnc_voteboard_use) && NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.VoteWrite) )
			{
				WNChkVote.Visible = true;
				WNChkVote.Attributes["onclick"] = "NBVote_Display(this, '" + WNTxtContent.ClientID + "');";
			}
			else
			{
				if (WNChkVote != null)
				{
					WNChkVote.Checked = false;
					WNChkVote.Visible = false;
				}
			}

            // HTML 사용 여부에 따라 HTML 사용 체크 박스 설정
			if ( mBoardCfg.bnc_html_use.Equals("1") ||  mBoardCfg.bnc_html_use.Equals("2") || mBoardCfg.bnc_html_use.Equals("3") )
			{
				WNChkHtml.Visible = true;
			}
			else
			{
				WNChkHtml.Checked = false;
				WNChkHtml.Visible = false;
			}

			// 예약 등록/삭제 기능 설정
			if ( NBUtil.isUseChk (mBoardCfg.bnc_async_update_use) )
			{
				WNChkASync.Visible = true;
				WNChkASync.Attributes["onclick"] = "NBAsyncWin(this, '" + HidStartUploadDate.ClientID + "', '" + HidStartDeleteDate.ClientID + "');";
			}
			else
			{
				WNChkASync.Checked = false;
				WNChkASync.Visible = false;
			}
		}

		/// <summary>
		/// 답변글일경우 부모글의 내용을 읽어 온다.
		/// </summary>
		private void RefContentBind()
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				BoardQryLib oQryLib = new BoardQryLib (mPageQryInfo.sBoardNo);

				SqlDataReader drRefContent = SqlHelper.ExecuteReader ( dbSqlConn, CommandType.StoredProcedure, "nbsp_ref_content_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", mPageQryInfo.sIdxNo) );

				if (drRefContent.Read())
				{
					mRefContInfo.PrivateYn = NBUtil.ConvStrToBool(drRefContent["private_yn"].ToString());
					mRefContInfo.NoticeYn = NBUtil.ConvStrToBool(drRefContent["notice_yn"].ToString());
					mRefContInfo.VoteYn = NBUtil.ConvStrToBool(drRefContent["vote_yn"].ToString());
					mRefContInfo.Pwd = drRefContent["pwd"].ToString();
					mRefContInfo.RefNo = int.Parse (drRefContent["ref_no"].ToString());
					mRefContInfo.LevelNo1 = int.Parse (drRefContent["level_no1"].ToString());
					mRefContInfo.LevelNo2 = int.Parse (drRefContent["level_no2"].ToString());

					if (mRefContInfo.NoticeYn)
					{
						NBCmnUtil.ViewMsgGoBack (Page, "공지글에는 답변을 달 수 없습니다.");
						return;
					}

					
					string sRefContent = drRefContent["content"].ToString();

					// 파일 링크 관련 처리
					MatchCollection oMC = NBUtil.GetUpFileTag (drRefContent["content"].ToString());

					if (oMC != null && oMC.Count > 0)
					{
						foreach (Match mcItem in oMC)
						{
							sRefContent = sRefContent.Replace(mcItem.Value, "");
						}
					}

					WNTxtContent.Text = NBUtil.RefContConv (sRefContent);

					WNTxtSubject.Text = drRefContent["subject"].ToString();

					if (NBUtil.isUseChk(mBoardCfg.bnc_category_use))
					{
						if (!NBUtil.StrEmptyChk(drRefContent["cat_code"].ToString()))
						{
							NBCmnUtil.DdlLst_Chk(WNDdlCatList, drRefContent["cat_code"].ToString());
							WNDdlCatList.Enabled = false;
						}
					}					
				}
			}
			catch(Exception E)
			{
				throw E;
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}


		/// <summary>
		/// 게시물을 작성하기 전에 게시물의 내용이 제한사항에 걸리지 않는지 확인한다.
		/// </summary>
		/// <returns></returns>
		private bool DoInputValidChk()
		{
			try
			{
				if (HTTrLogoutName.Visible)
				{
					if ( NBUtil.StrEmptyChk(WNTxtName.Text) )
					{
						NBCmnUtil.ViewAlertMsg (Page, "이름을 입력해 주세요.");
						return true;
					}

					if ( WNTxtPwd.Enabled && NBUtil.StrEmptyChk(WNTxtPwd.Text) )
					{
						NBCmnUtil.ViewAlertMsg (Page, "비밀번호를 입력해 주세요.");
						return true;
					}
				}

				if (HTTrEmail.Visible)
				{
					if ( NBUtil.StrEmptyChk(WNTxtEmail.Text) || NBCmnUtil.ValidChk_Email (WNTxtEmail.Text) )
					{
						NBCmnUtil.ViewAlertMsg (Page, "이메일 주소를 정확히 입력해 주세요.");
						return true;
					}
				}

				if ( NBUtil.StrEmptyChk (WNTxtSubject.Text) )
				{
					NBCmnUtil.ViewAlertMsg (Page, "제목을 입력해 주세요.");
					return true;
				}

				// 관리자가 아닌경우에는 글/파일 업로드 제한 체크를 한다.
				if ( !NBUtil.isAdminLogin(mBoardCfg.bps_level_info) )
				{
					if ( WNChkHtml.Checked && NBUtil.DoHtmlTagChk (NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.AdvHtmlUse), mBoardCfg.bnc_html_use, mBoardCfg.bnc_use_htmltag, WNTxtContent.Text) )
						return true;

					if( NBUtil.DoWordChk (mBoardCfg.bnc_badword_use, mBoardCfg.bnc_badword_word, WNTxtSubject.Text, WNTxtContent.Text) )
						return true;

					// File Input을 HttpPostedFile 배열로 변환
					HttpFileCollection upfile_coll = Request.Files;

					if( NBUtil.isFileUpUse (mBoardCfg.bnc_fileupdown_use, NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.FileUpload)) && NBUtil.DoFileChk (mBoardCfg.bnc_fileup_ext_use, mBoardCfg.bnc_fileup_ext, mBoardCfg.bnc_fileup_size, upfile_coll) )
						return true;
				
					if( NBUtil.DoWriterLimitChk (mBoardCfg.bnc_writer_limit, WNTxtName.Text) )
						return true;
				}

				if ( mRefContInfo.NoticeYn )
				{
					throw new Exception ("공지글에는 답변글을 등록 할 수 없습니다.");
				}
			}
			catch (Exception E)
			{
				NBCmnUtil.ViewAlertMsg (Page, E.Message);
				return true;
			}

			return false;
		}

		private string GetContentParse(string sCont)
		{
			string sResult = string.Empty;

			if (NBUtil.isUseChk(mBoardCfg.bnc_voteboard_use) && WNChkVote != null && WNChkVote.Checked)
			{
				// 투표 게시판으로 사용하고 있으면
				string sVoteSep = "--투표항목--";
				string sVoteContent = string.Empty;
				string sVoteItem = string.Empty;
				string[] arrVoteCont = null;
				string[] arrVoteItem = null;

				Regex regVote = new Regex(sVoteSep);
				arrVoteCont = regVote.Split(sCont);

				if (arrVoteCont.Length.Equals(2))
				{
					sVoteContent = arrVoteCont[0].Trim();
					sVoteItem = arrVoteCont[1].Trim();

					arrVoteItem = sVoteItem.Split(';');

					if (arrVoteItem.Length > 1)
					{
						// XML 데이타 생성
						StringWriter swXmlCont = new StringWriter();

						XmlTextWriter xmlWr = new XmlTextWriter(swXmlCont);
						xmlWr.Formatting = Formatting.Indented;

						xmlWr.WriteStartDocument();

						xmlWr.WriteStartElement ("vote");
							
						xmlWr.WriteStartElement ("content");
						xmlWr.WriteCData (sVoteContent);
						xmlWr.WriteEndElement ();

						xmlWr.WriteStartElement ("sepitem");
						xmlWr.WriteCData (sVoteSep);
						xmlWr.WriteEndElement ();

						xmlWr.WriteStartElement ("voteitems");

						foreach (string sItem in arrVoteItem)
						{
							if (!NBUtil.StrEmptyChk(sItem))
							{
								xmlWr.WriteStartElement ("item");
								xmlWr.WriteAttributeString ("count", "0");
								xmlWr.WriteCData(sItem);
								xmlWr.WriteEndElement();
							}
						}
							
						xmlWr.WriteEndElement();

						xmlWr.WriteEndElement();

						xmlWr.WriteEndDocument();

						xmlWr.Flush();

						sResult = swXmlCont.ToString();

						xmlWr.Close();
						swXmlCont.Close();						
					}
					else
					{
						throw new Exception ("투표 항목을 입력해 주세요.");
					}
                    										
				}
				else
				{
					throw new Exception (sVoteSep + " 구분자가 없습니다.");
				}
			}
			else
			{
				sResult = sCont;
			}

			return sResult;
		}

		private void WBImgSave_Click(object sender, ImageClickEventArgs e)
		{
			SqlConnection dbSqlConn = null;
			do_data_proc = new data_proc(mPageQryInfo.sBoardNo);

			try
			{
				if (DoInputValidChk())
					return;

				NBLib.FileInfo[] oUpFileInfo = null;

				string
					parmNewIdxNo = string.Empty,
					parmGuestNo = string.Empty,
					parmWriter = string.Empty,
					parmCatCode = string.Empty,
					parmPwd = string.Empty,
					parmAgreeYN = string.Empty,
                    parmPrivateYN = string.Empty,
					parmVoteYN = string.Empty,
					parmSumYn = string.Empty,
					parmSumHtmlUse = string.Empty,
					parmSumContent = string.Empty,
					parmDispStartDate = string.Empty,
					parmDispEndDate = string.Empty;
				int 
					parmLevelNo1 = 0,
					parmLevelNo2 = 0;


				DBUtil.DBConnection (ref dbSqlConn);

				parmNewIdxNo = SqlHelper.ExecuteScalar(dbSqlConn, CommandType.StoredProcedure, "nbsp_get_new_idx_" + mPageQryInfo.sBoardNo).ToString();

				
				if (NBUtil.isLogin())
				{
					//쿠키 디코딩 추가(2005.04.04)
					parmGuestNo = Server.UrlDecode(Request.Cookies["MBNO"].Value);
					parmWriter = Server.UrlDecode(Request.Cookies["MBNAME"].Value);
				}
				else
					parmWriter = WNTxtName.Text;

				if (WNDdlCatList.Visible && WNDdlCatList.SelectedIndex > -1)
					parmCatCode = WNDdlCatList.SelectedValue;

				if(mRefContInfo.PrivateYn)
					parmPwd = mRefContInfo.Pwd;
				else
				{
					if(WNChkSecret.Checked)
						parmPwd = WNTxtPwd.Text;
					else
					{
						if (NBUtil.isLogin())
							parmPwd = do_data_proc.GetLoginMemPwd (NBCmnUtil.GetCookieValue("MBNO"));
						else
							parmPwd = WNTxtPwd.Text;
					}
				}

				if ( NBUtil.isReplyYn (mPageQryInfo) )
				{
					parmLevelNo1 = mRefContInfo.LevelNo1 + 1;
					parmLevelNo2 = mRefContInfo.LevelNo2 + 1;
				}

				if (mBoardCfg.bnc_agree_use.Equals ("1") )
					parmAgreeYN = "0";
				else
					parmAgreeYN = "1";

				if (!WNChkSecret.Enabled || WNChkSecret.Checked)
					parmPrivateYN = "1";
				else
					parmPrivateYN = "0";


				if (WNChkVote != null)
				{
					if (!WNChkVote.Enabled || WNChkVote.Checked)
						parmVoteYN = "1";
					else
						parmVoteYN = "0";
				}
				else
				{
					parmVoteYN = "0";
				}

				if (WNChkSum.Checked)
				{
                    parmSumYn = "1";
                    parmSumHtmlUse = NBUtil.ConvBoolToStr (WNChkSum.Checked);
                    parmSumContent = WNTxtSumContent.Text;
				}

				if (WNChkASync.Checked)
				{
					parmDispStartDate = HidStartUploadDate.Value;
					parmDispEndDate = HidStartDeleteDate.Value;
				}
                
				int nTmpArrIdx = 0;
				SqlParameter[] sqlParm = new SqlParameter[32];
				sqlParm[nTmpArrIdx] = new SqlParameter("@new_idx_no", int.Parse(parmNewIdxNo));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@reply_yn", NBUtil.ConvBoolToStr(NBUtil.isReplyYn (mPageQryInfo)));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@curr_ref_no", mRefContInfo.RefNo);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@curr_level_no2", mRefContInfo.LevelNo2);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@guest_no", parmGuestNo);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@writer", parmWriter);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@email", WNTxtEmail.Text);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@homepage", WNTxtHomepage.Text);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@writer_ip", Request.UserHostAddress);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@cat_code", parmCatCode);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@subject", WNTxtSubject.Text);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@content", GetContentParse(WNTxtContent.Text));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@html_use", NBUtil.ConvBoolToStr (WNChkHtml.Checked));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@pwd", parmPwd);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@level_no1", parmLevelNo1);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@level_no2", parmLevelNo2);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@replymail_yn", NBUtil.ConvBoolToStr (WNChkAlert.Checked));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@cmmtmail_yn", NBUtil.ConvBoolToStr (WNChkCmmtAlert.Checked));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@agree_yn", parmAgreeYN);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@private_yn", parmPrivateYN);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@notice_yn", NBUtil.ConvBoolToStr (WNChkNotice.Checked));
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@link1", WNTxtLink1.Text);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@link2", WNTxtLink2.Text);				
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_yn", parmVoteYN);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_start", WNTxtVoteStart.Text);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_end", WNTxtVoteEnd.Text);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@vote_disp_type", "");
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@sum_yn", parmSumYn);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@sum_content", parmSumContent);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@sum_html_use", parmSumHtmlUse);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@disp_start_date", parmDispStartDate);
				++nTmpArrIdx;
				sqlParm[nTmpArrIdx] = new SqlParameter("@disp_end_date", parmDispEndDate);

				
				// 글쓰기 입력 데이타 INSERT
				if (SqlHelper.ExecuteNonQuery (dbSqlConn, CommandType.StoredProcedure, "nbsp_write_boarddata_" + mPageQryInfo.sBoardNo, sqlParm) > 0)
				{
					if ( NBUtil.isFileUpUse (mBoardCfg.bnc_fileupdown_use, NBUtil.chkLvlRole (mBoardCfg.bps_level_info, NBLib.UserLvlRole.FileUpload)) )
					{
						HttpFileCollection upfile_coll = Request.Files;

						oUpFileInfo = NBUtil.DoFileUpload(mPageQryInfo.sBoardNo, upfile_coll);					
				
						string[] arrFileDesc = Request.Form.GetValues("NBFileUp_Desc");

						for (int nFIdxNo = 0; nFIdxNo < oUpFileInfo.Length; nFIdxNo++)
						{
							string parmFileDesc = string.Empty;

							if ( !NBUtil.StrEmptyChk(oUpFileInfo[nFIdxNo].FileName) )
								parmFileDesc = arrFileDesc[nFIdxNo];

							SqlParameter[] sqlFileParm = new SqlParameter[7];
							sqlFileParm[0] = new SqlParameter("@idx_no", int.Parse(parmNewIdxNo));
							sqlFileParm[1] = new SqlParameter("@fidx_no", nFIdxNo.ToString());
							sqlFileParm[2] = new SqlParameter("@file_name", oUpFileInfo[nFIdxNo].FileName);
							sqlFileParm[3] = new SqlParameter("@file_ext", oUpFileInfo[nFIdxNo].FileExt);
							sqlFileParm[4] = new SqlParameter("@file_size", oUpFileInfo[nFIdxNo].FileSize);
							sqlFileParm[5] = new SqlParameter("@file_desc", parmFileDesc);
							sqlFileParm[6] = new SqlParameter("@file_chg", "0");

							SqlHelper.ExecuteNonQuery (dbSqlConn, CommandType.StoredProcedure, "nbsp_update_filedata_" + mPageQryInfo.sBoardNo, sqlFileParm);
						}
					}

					//답변달기일 경우에는 원본글 작성자에게 메일을 발송한다.
					if (mPageQryInfo.bReplyYN)
					{
						if ( NBUtil.isUseChk (mBoardCfg.bnc_replymail_use) )
							AlertMailSend(mPageQryInfo.sIdxNo, parmNewIdxNo.Trim(), parmWriter, WNTxtSubject.Text, GetContentParse(WNTxtContent.Text), NBUtil.ConvBoolToStr (WNChkHtml.Checked));
					}

					if (NBUtil.isUseChk (mBoardCfg.bnc_write_alert))
						NBUtil.AdminAlertMail ("B", mPageQryInfo.sBoardNo, parmNewIdxNo, WNTxtSubject.Text, WNTxtContent.Text, mBoardCfg, mPageQryInfo);

					
					string sTransLink = string.Empty;

					if (mPageQryInfo.bReplyYN)
					{
						// 답변 쓰기 포인트 적용
						if (NBUtil.isLogin())
                            NBUtil.DoPointApply (mBoardCfg.bpd_reply_write_point, parmGuestNo);

						if(mRefContInfo.PrivateYn)
							sTransLink = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, 1, mPageQryInfo);
						else
							sTransLink = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "VIEW", mPageQryInfo, parmNewIdxNo);
					}
					else
					{
						// 글쓰기 포인트 적용
						if (NBUtil.isLogin())
							NBUtil.DoPointApply (mBoardCfg.bpd_write_point, parmGuestNo);

						sTransLink = NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, 1, mPageQryInfo);
					}

					if ( NBUtil.StrEmptyChk (mBoardCfg.bnc_afterwrite_url) )
					{
						if (sTransLink.Length > 0)
						{
							Response.Redirect (sTransLink, false);
						}
						else
						{
							Response.Redirect (NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, 1, mPageQryInfo), false);
						}
					}
					else
					{
                        Response.Redirect (mBoardCfg.bnc_afterwrite_url, false);
					}
				}
				else
				{					
					throw new Exception("게시판에 글을 등록하는 도중 오류가 발생하였습니다.");					
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewMsgGoUrl(Page, Request.Url.ToString(), E.Message);
			}
			finally
			{
				do_data_proc.Dispose();
				DBUtil.DBConnDispose (ref dbSqlConn);
			}		
		}

		

		//답변글 메일로 받기를 설정한 원본글 작성자에게 메일 발송
		private void AlertMailSend(string sSourceBoardIdx, string sNewBoardIdx, string newWriter, string newSubject, string newContent, string newHtmlUse)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				string sAlertMailStr = NBUtil.getAlertMailStr (Server.MapPath("Common/AlertMail.xml"), "/MailMsg/AlertMail");

				if ( !NBUtil.StrEmptyChk (sAlertMailStr) )
				{
					DBUtil.DBConnection (ref dbSqlConn);

                    
					// 원본글 내용 읽어 오기
					string sSource_Email = string.Empty;		//설정글 이메일
					string sSource_Subject = string.Empty;		//설정글 제목
					string sSource_Writeday = string.Empty;		//설정글 작성일
					string sReplyMail_YN = string.Empty;		//답변 메일 작성

					SqlDataReader drSrcDataQry = SqlHelper.ExecuteReader (dbSqlConn, CommandType.StoredProcedure, "nbsp_alert_mail_data_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", sSourceBoardIdx));
                
					if (drSrcDataQry.Read())
					{
						sSource_Email = drSrcDataQry["email"].ToString();
						sSource_Subject = drSrcDataQry["subject"].ToString();
						sSource_Writeday = drSrcDataQry["write_date"].ToString();
						sReplyMail_YN = drSrcDataQry["replymail_yn"].ToString();
					}
                    
					drSrcDataQry.Close();
					dbSqlConn.Close();


					if (NBUtil.isUseChk (sReplyMail_YN))
					{
						// 새글 내용 읽어 오기					
						string sNew_Name = string.Empty;			//답변글 작성자
						string sNew_Subject = string.Empty;			//답변글 제목
						string sNew_Content = string.Empty;			//답변글 내용
						string sNew_HtmlUse = string.Empty;			//답변글 HTML 사용 여부

						sNew_Name = newWriter;
						sNew_Subject = newSubject;
						sNew_Content = newContent;
						sNew_HtmlUse = newHtmlUse;
                    
						if ( !NBUtil.StrEmptyChk (sSource_Email) )
						{
							//메일내용대치
							sAlertMailStr = sAlertMailStr.Replace("##ORIG_WDATE##", sSource_Writeday.Trim());
							sAlertMailStr = sAlertMailStr.Replace("##ORIG_SUBJECT##", Server.HtmlEncode (sSource_Subject));
							sAlertMailStr = sAlertMailStr.Replace("##BOARD_LINK##", "http://" + Request.Url.Host + NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "VIEW", mPageQryInfo, sNewBoardIdx));
							sAlertMailStr = sAlertMailStr.Replace("##RE_WRITER##", Server.HtmlEncode (sNew_Name));
							sAlertMailStr = sAlertMailStr.Replace("##RE_SUBJECT##", Server.HtmlEncode (sNew_Subject));
							if (NBUtil.isUseChk (sNew_HtmlUse))
								sAlertMailStr = sAlertMailStr.Replace("##RE_CONTENT##", sNew_Content.Replace("\r\n", "<br>"));
							else
								sAlertMailStr = sAlertMailStr.Replace("##RE_CONTENT##", Server.HtmlEncode(sNew_Content).Replace("\r\n", "<br>"));

							string sMailTitle = string.Empty;			// 메일 내용

							sMailTitle = "[" + mBoardCfg.bnc_board_name + "]게시판에 답변이 등록되었습니다.";

							NBUtil.SendMail (sSource_Email, sSource_Email, "", "", sMailTitle, sAlertMailStr, "1");
						}
					}
				}
			}
			catch
			{
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}			
		}
	}
}
