﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.Web.UI;
using System.Web.UI.WebControls;
using BoardLib;

namespace NeBoard
{
	/// <summary>
	/// 게시물 삭제 페이지
	/// =================================================== potato@dotnetpia.co.kr ==
	/// 글 읽기 페이지에서 게시물 삭제를 클릭하면 
	/// 비밀번호를 체크하여 글을 삭제한다.
	/// 만약 최고관리자, 게시판 운영자, 글 작성자(회원 로그인 후 작성한 글)일 경우
	/// 비밀번호 확인없이 삭제처리
	/// </summary>
	public abstract class Delete : UserControl
	{
		#region Controls
		protected ImageButton btn_del_ok;
		protected HyperLink lnk_delete_cancel;
		protected TextBox txt_pwd;
		#endregion

		public NBLib.PageQryStr mPageQryInfo;
		public NBLib.CurBoardCfg mBoardCfg;

		public string BoardTitleContent;

		public string
			gBoardNo,					// 게시판 코드
			gViewMode;					// 게시판 작동 모드

		public string BoardNo
		{
			set
			{
				gBoardNo = value;
			}

			get
			{
				return gBoardNo;
			}
		}

		public string ViewMode
		{
			set
			{
				gViewMode = value;
			}

			get
			{
				return gViewMode;
			}
		}

		private void Page_Load(object sender, EventArgs e)
		{
			try
			{
				// 전역 데이타 로드
				if (!nb_utils.GetGlobalValue (ref mPageQryInfo, ref mBoardCfg, gBoardNo, gViewMode))
					return;

				do_button_set();

				NBUtil.SetDisplayType(ref BoardTitleContent, mBoardCfg.bnd_boardtitle_view, mBoardCfg.bnd_boardtitle_cont.Replace("[BRD_NAME]", mBoardCfg.bnc_board_name));

				if (!Page.IsPostBack)
					do_admin_del();
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewMsgGoBack (Page, E.Message);
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			InitializeComponent();
			base.OnInit(e);
		}
		
		private void InitializeComponent()
		{
			this.btn_del_ok.Click += new ImageClickEventHandler(this.btn_del_ok_Click);
			this.Load += new EventHandler(this.Page_Load);
		}
		#endregion

		/// <summary>
		/// 버튼의 클라이언트 스크립트 설정
		/// </summary>
		private void do_button_set()
		{
			btn_del_ok.Attributes.Add("onclick","return NB_DeleteOk()");
			lnk_delete_cancel.NavigateUrl = NBUtil.GetBoardTransLink_WithCat (mPageQryInfo.sBoardNo, mPageQryInfo.sCatName, mPageQryInfo);
		}

        /// <summary>
        /// 관리자/글작성자를 체크하여 만약 일치하면 
        /// 비밀번호 확인없이 글 삭제
        /// </summary>
		private void do_admin_del()
		{
			if ( NBUtil.isLogin() )
			{
				if ( NBUtil.isAdminLogin(mBoardCfg.bps_level_info) )
				{
					if (NBUtil.DeleteOk(mPageQryInfo.sBoardNo, mPageQryInfo.sIdxNo))
						Response.Redirect(NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "1", mPageQryInfo), false);
				}
				else
				{
					SqlConnection dbSqlConn = null;

					try
					{
						DBUtil.DBConnection (ref dbSqlConn);

						string sWriterGuestNo = SqlHelper.ExecuteScalar (dbSqlConn, CommandType.StoredProcedure, "nbsp_writer_guest_no_" + mPageQryInfo.sBoardNo, new SqlParameter("@idx_no", mPageQryInfo.sIdxNo)).ToString();

						if ( sWriterGuestNo.Equals(Server.UrlDecode(Request.Cookies["MBNO"].Value)) ) //쿠키 디코딩 추가(2005.04.04)
						{
							if (NBUtil.DeleteOk(mPageQryInfo.sBoardNo, mPageQryInfo.sIdxNo))
								Response.Redirect(NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "1", mPageQryInfo), false);
						}
					}
					catch(Exception E)
					{
						throw E;
					}
					finally
					{
						DBUtil.DBConnDispose (ref dbSqlConn);
					}
				}
			}
		}

		/// <summary>
		/// 삭제 버튼 이벤트
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void btn_del_ok_Click(object sender, ImageClickEventArgs e)
		{
			SqlConnection dbSqlConn = null;

			try
			{
				DBUtil.DBConnection (ref dbSqlConn);

				string sContentPwd = SqlHelper.ExecuteScalar (dbSqlConn, CommandType.StoredProcedure, "nbsp_get_board_pwd_" + mPageQryInfo.sBoardNo,  new SqlParameter("@idx_no", mPageQryInfo.sIdxNo)).ToString();

				if (!NBUtil.StrEmptyChk (sContentPwd))
				{
					if ( sContentPwd.Equals (txt_pwd.Text) )
					{
						if (NBUtil.DeleteOk(mPageQryInfo.sBoardNo, mPageQryInfo.sIdxNo))
                            Response.Redirect(NBUtil.GetBoardTransLink (mPageQryInfo.sBoardNo, "1", mPageQryInfo), false);
					}
					else						
					{
						throw new Exception("비밀번호가 틀렸습니다.");
					}
				}
				else
				{
					throw new Exception("삭제하려는 게시물이 존제하지 않습니다.");
				}
			}
			catch(Exception E)
			{
				NBCmnUtil.ViewMsgGoBack (Page, E.Message);
			}
			finally
			{
				DBUtil.DBConnDispose (ref dbSqlConn);
			}
		}
	}
}
